SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

CREATE SCHEMA IF NOT EXISTS `heroku_3eb85e4f7505b47` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `heroku_3eb85e4f7505b47` ;

-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`teacher`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`teacher` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`teacher` (
  `id_teacher` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_teacher`))
ENGINE = InnoDB;

CREATE UNIQUE INDEX `id_edmodo_UNIQUE` ON `heroku_3eb85e4f7505b47`.`teacher` (`id_edmodo` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`subject_competence`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`subject_competence` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`subject_competence` (
  `teacher_id` INT NOT NULL,
  `title` VARCHAR(45) NOT NULL,
  `subject_competence_teacher_id` INT NULL,
  `subject_competence_title` VARCHAR(45) NULL,
  `edmodo_group` VARCHAR(45) NOT NULL,
  `initial_date` DATE NOT NULL,
  `final_date` DATE NOT NULL,
  `description` VARCHAR(100) NULL,
  `non_academic_days` VARCHAR(5800) NULL,
  `each_positive_weight` INT(3) NOT NULL DEFAULT 0,
  `each_negative_weight` INT(3) NOT NULL DEFAULT 0,
  `max_positive_weight` INT(3) NOT NULL DEFAULT 0,
  `max_negative_weight` INT(3) NOT NULL DEFAULT 0,
  PRIMARY KEY (`teacher_id`, `title`),
  CONSTRAINT `fk_subject_competence_teacher1`
    FOREIGN KEY (`teacher_id`)
    REFERENCES `heroku_3eb85e4f7505b47`.`teacher` (`id_teacher`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_subject_competence_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id` , `subject_competence_title`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB;

CREATE INDEX `fk_subject_competence_teacher1_idx` ON `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` ASC);

CREATE INDEX `fk_subject_competence_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`subject_competence` (`subject_competence_teacher_id` ASC, `subject_competence_title` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (
  `teacher_id_teacher` INT NOT NULL,
  `name` VARCHAR(50) NOT NULL COMMENT 'Because Edmodo not provides a way to get the badge name without an user.',
  `description` VARCHAR(140) NULL COMMENT 'Because Edmodo not provides a way to get the badge name without an user.',
  `edmodo_id` VARCHAR(45) NOT NULL,
  `type` BIT NOT NULL DEFAULT 1 COMMENT '0: Negative\n1: Positive',
  PRIMARY KEY (`teacher_id_teacher`, `name`),
  CONSTRAINT `fk_behaviour_attitude_aspect_teacher1`
    FOREIGN KEY (`teacher_id_teacher`)
    REFERENCES `heroku_3eb85e4f7505b47`.`teacher` (`id_teacher`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_behaviour_attitude_aspect_teacher1_idx` ON `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher` ASC);

CREATE UNIQUE INDEX `edmodo_id_UNIQUE` ON `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`edmodo_id` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`assignment`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`assignment` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`assignment` (
  `id_assignment` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `associated_weight` INT(3) NOT NULL DEFAULT 0,
  `type` TINYINT(1) NOT NULL DEFAULT 0 COMMENT '0: online grade\n1: offline grade\n2: online assignment\n3: offlie assignment',
  `date` DATE NOT NULL,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id_assignment`),
  CONSTRAINT `fk_assignment_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_assignment_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`assignment` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`evaluable_item`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item` (
  `assignment_id_fk` INT NOT NULL,
  `name` VARCHAR(30) NOT NULL,
  `associated_weight` INT(3) NOT NULL DEFAULT 0,
  PRIMARY KEY (`assignment_id_fk`, `name`),
  CONSTRAINT `fk_evaluable_item_assignment1`
    FOREIGN KEY (`assignment_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_evaluable_item_assignment1_idx` ON `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`student` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`student` (
  `id_student` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_student`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`evaluable_item_student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_student` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_student` (
  `student_id_fk` INT NOT NULL,
  `score` DOUBLE NULL,
  `evaluable_item_assignment_id_fk` INT NOT NULL,
  `evaluable_item_name_fk` VARCHAR(30) NOT NULL,
  PRIMARY KEY (`student_id_fk`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`),
  CONSTRAINT `fk_alumnoHasevaluable_item_alumno`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_evaluable_item_student_evaluable_item1`
    FOREIGN KEY (`evaluable_item_assignment_id_fk` , `evaluable_item_name_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk` , `name`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_alumnoHasevaluable_item_alumno_idx` ON `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk` ASC);

CREATE INDEX `fk_evaluable_item_student_evaluable_item1_idx` ON `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`evaluable_item_assignment_id_fk` ASC, `evaluable_item_name_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`bonus_penalization`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`bonus_penalization` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`bonus_penalization` (
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `student_id_fk` INT NOT NULL,
  `score` DOUBLE NOT NULL,
  `reason` VARCHAR(45) NULL,
  PRIMARY KEY (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`),
  CONSTRAINT `fk_subject_competence_has_alumno_alumno`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_bonus_penalization_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_subject_competence_has_alumno_alumno2_idx` ON `heroku_3eb85e4f7505b47`.`bonus_penalization` (`student_id_fk` ASC);

CREATE INDEX `fk_bonus_penalization_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`calification`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`calification` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`calification` (
  `assignment_id_fk` INT NOT NULL,
  `student_id_fk` INT NOT NULL,
  `bonus_penalization` DOUBLE NULL DEFAULT 0.0,
  `reason_bonus_penalization` VARCHAR(45) NULL,
  `optional_comment` VARCHAR(45) NULL,
  `visible_student` BIT(1) NOT NULL DEFAULT 1 COMMENT '0: NO\n1: YES',
  `visible_parent` BIT(1) NOT NULL DEFAULT 1 COMMENT '0: NO\n1: YES',
  PRIMARY KEY (`assignment_id_fk`, `student_id_fk`),
  CONSTRAINT `fk_assignment_has_alumno_assignment1`
    FOREIGN KEY (`assignment_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_assignment_has_alumno_alumno1`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_assignment_has_alumno_alumno1_idx` ON `heroku_3eb85e4f7505b47`.`calification` (`student_id_fk` ASC);

CREATE INDEX `fk_assignment_has_alumno_assignment1_idx` ON `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`aspect_student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`aspect_student` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`aspect_student` (
  `student_id_fk` INT NOT NULL,
  `aspect_teacher_id_fk` INT NOT NULL,
  `aspect_name_fk` VARCHAR(50) NOT NULL,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `date` DATE NOT NULL,
  PRIMARY KEY (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`),
  CONSTRAINT `fk_alumno_has_behaviour_attitude_aspect_alumno1`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_aspect_student_behaviour_attitude_aspect1`
    FOREIGN KEY (`aspect_teacher_id_fk` , `aspect_name_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher` , `name`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_aspect_student_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_alumno_has_behaviour_attitude_aspect_alumno1_idx` ON `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk` ASC);

CREATE INDEX `fk_aspect_student_behaviour_attitude_aspect1_idx` ON `heroku_3eb85e4f7505b47`.`aspect_student` (`aspect_teacher_id_fk` ASC, `aspect_name_fk` ASC);

CREATE INDEX `fk_aspect_student_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`aspect_student` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`evaluation_period`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluation_period` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluation_period` (
  `id_evaluation_period` INT NOT NULL AUTO_INCREMENT,
  `initial_date` DATE NOT NULL,
  `final_date` DATE NOT NULL,
  `percentage` INT(3) NOT NULL DEFAULT 0,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id_evaluation_period`),
  CONSTRAINT `fk_evaluation_period_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_evaluation_period_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`evaluation_period` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`absence`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`absence` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`absence` (
  `student_absence_student_id_fk` INT NOT NULL,
  `student_absence_subject_competence_teacher_id_fk` INT NOT NULL,
  `student_absence_subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `dates` VARCHAR(5500) NULL,
  PRIMARY KEY (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`),
  CONSTRAINT `fk_student_has_subject_competence_student1`
    FOREIGN KEY (`student_absence_student_id_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_student_has_subject_competence_subject_competence1`
    FOREIGN KEY (`student_absence_subject_competence_teacher_id_fk` , `student_absence_subject_competence_title_fk`)
    REFERENCES `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_student_has_subject_competence_student1_idx` ON `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk` ASC);

CREATE INDEX `fk_student_has_subject_competence_subject_competence1_idx` ON `heroku_3eb85e4f7505b47`.`absence` (`student_absence_subject_competence_teacher_id_fk` ASC, `student_absence_subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_3eb85e4f7505b47`.`parent`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`parent` ;

CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`parent` (
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_edmodo`))
ENGINE = InnoDB
COMMENT = 'The purpose of this table is to keep parent\'s favourite lang /* comment truncated */ /*uage system.*/';

CREATE UNIQUE INDEX `id_edmodo_UNIQUE` ON `heroku_3eb85e4f7505b47`.`parent` (`id_edmodo` ASC);

USE `heroku_3eb85e4f7505b47` ;

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`assignment_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`assignment_view` (`id_assignment` INT, `id_edmodo` INT, `associated_weight` INT, `type` INT, `date` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`evaluation_period_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluation_period_view` (`id_evaluation_period` INT, `initial_date` INT, `final_date` INT, `percentage` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`calification_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`calification_view` (`assignment_id_fk` INT, `student_id_fk` INT, `bonus_penalization` INT, `reason_bonus_penalization` INT, `optional_comment` INT, `visible_student` INT, `visible_parent` INT, `teacher_id` INT, `title` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`evaluable_item_student_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_student_view` (`student_id_fk` INT, `score` INT, `evaluable_item_assignment_id_fk` INT, `evaluable_item_name_fk` INT, `teacher_id` INT, `title` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`bonus_penalization_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`bonus_penalization_view` (`subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT, `student_id_fk` INT, `score` INT, `reason` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`aspect_student_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`aspect_student_view` (`student_id_fk` INT, `aspect_teacher_id_fk` INT, `aspect_name_fk` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT, `date` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`evaluable_item_assignment_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_assignment_view` (`subject_competence_title_fk` INT, `subject_competence_teacher_id_fk` INT, `assignment_id_fk` INT, `name` INT, `associated_weight` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect_view` (`teacher_id_teacher` INT, `name` INT, `description` INT, `edmodo_id` INT, `type` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`absence_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`absence_view` (`student_absence_student_id_fk` INT, `student_absence_subject_competence_teacher_id_fk` INT, `student_absence_subject_competence_title_fk` INT, `dates` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_3eb85e4f7505b47`.`subject_competence_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_3eb85e4f7505b47`.`subject_competence_view` (`teacher_id` INT, `title` INT, `subject_competence_teacher_id` INT, `subject_competence_title` INT, `edmodo_group` INT, `initial_date` INT, `final_date` INT, `description` INT, `non_academic_days` INT, `each_positive_weight` INT, `each_negative_weight` INT, `max_positive_weight` INT, `max_negative_weight` INT);

-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`assignment_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`assignment_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`assignment_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `assignment_view` AS SELECT * FROM assignment;

-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`evaluation_period_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`evaluation_period_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluation_period_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `evaluation_period_view` AS SELECT * FROM evaluation_period;


-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`calification_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`calification_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`calification_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `calification_view` AS SELECT calification.*,subject_competence.teacher_id,subject_competence.title FROM calification,subject_competence
;

-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`evaluable_item_student_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_student_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_student_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `evaluable_item_student_view` AS SELECT evaluable_item_student.*,subject_competence.teacher_id,subject_competence.title FROM evaluable_item_student,subject_competence;


-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`bonus_penalization_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`bonus_penalization_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`bonus_penalization_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `bonus_penalization_view` AS SELECT * FROM bonus_penalization;


-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`aspect_student_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`aspect_student_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`aspect_student_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `aspect_student_view` AS SELECT * FROM aspect_student
;

-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`evaluable_item_assignment_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_assignment_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`evaluable_item_assignment_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `evaluable_item_assignment_view` AS SELECT assignment.subject_competence_title_fk,assignment.subject_competence_teacher_id_fk,evaluable_item.* FROM evaluable_item,assignment WHERE assignment_id_fk=id_assignment;

-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `behaviour_attitude_aspect_view` AS SELECT * FROM behaviour_attitude_aspect;


-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`absence_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`absence_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`absence_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `absence_view` AS SELECT * FROM absence;


-- -----------------------------------------------------
-- View `heroku_3eb85e4f7505b47`.`subject_competence_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_3eb85e4f7505b47`.`subject_competence_view` ;
DROP TABLE IF EXISTS `heroku_3eb85e4f7505b47`.`subject_competence_view`;
USE `heroku_3eb85e4f7505b47`;
CREATE  OR REPLACE VIEW `subject_competence_view` AS SELECT * FROM subject_competence;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`teacher`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`teacher` (`id_teacher`, `id_edmodo`, `id_language`) VALUES (1, '9bed44e99', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`teacher` (`id_teacher`, `id_edmodo`, `id_language`) VALUES (11, 'other123', 1);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`subject_competence`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id`, `title`, `subject_competence_teacher_id`, `subject_competence_title`, `edmodo_group`, `initial_date`, `final_date`, `description`, `non_academic_days`, `each_positive_weight`, `each_negative_weight`, `max_positive_weight`, `max_negative_weight`) VALUES (1, 'Inglés de 4º', NULL, NULL, '582888', '2014-04-16', '2016-04-15', 'El inglés de cuarto.', '2014{19-0420-0426-0427-0403-0504-0510-0511-0517-0518-0524-0525-0531-0501-0607-0608-0614-0615-0621-0622-0628-0629-0605-0706-0712-0713-0719-0720-0726-0727-0702-0803-0809-0810-0816-0817-0823-0824-0830-0831-0806-0907-0913-0914-0920-0921-0927-0928-0904-1005-1011-1012-1018-1019-1025-1026-1001-1102-1108-1109-1115-1116-1122-1123-1129-1130-1106-1207-1213-1214-1220-1221-1227-1228-12}2015{03-0104-0110-0111-0117-0118-0124-0125-0131-0101-0207-0208-0214-0215-0221-0222-0228-0201-0307-0308-0314-0315-0321-0322-0328-0329-0304-0405-0411-0412-0418-0419-0425-0426-0402-0503-0509-0510-0516-0517-0523-0524-0530-0531-0506-0607-0613-0614-0620-0621-0627-0628-0604-0705-0711-0712-0718-0719-0725-0726-0701-0802-0808-0809-0815-0816-0822-0823-0829-0830-0805-0906-0912-0913-0919-0920-0926-0927-0903-1004-1010-1011-1017-1018-1024-1025-1031-1001-1107-1108-1114-1115-1121-1122-1128-1129-1105-1206-1212-1213-1219-1220-1226-1227-12}2016{02-0103-0109-0110-0116-0117-0123-0124-0130-0131-0106-0207-0213-0214-0220-0221-0227-0228-0205-0306-0312-0313-0319-0320-0326-0327-0302-0403-0409-0410-04}', 1, 1, 15, 15);
INSERT INTO `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id`, `title`, `subject_competence_teacher_id`, `subject_competence_title`, `edmodo_group`, `initial_date`, `final_date`, `description`, `non_academic_days`, `each_positive_weight`, `each_negative_weight`, `max_positive_weight`, `max_negative_weight`) VALUES (1, 'Mates de 2º', NULL, NULL, '582888', '2014-04-16', '2016-04-15', 'Las mates de segundo curso.', '2014{19-0420-0426-0427-0403-0504-0510-0511-0517-0518-0524-0525-0531-0501-0607-0608-0614-0615-0621-0622-0628-0629-0605-0706-0712-0713-0719-0720-0726-0727-0702-0803-0809-0810-0816-0817-0823-0824-0830-0831-0806-0907-0913-0914-0920-0921-0927-0928-0904-1005-1011-1012-1018-1019-1025-1026-1001-1102-1108-1109-1115-1116-1122-1123-1129-1130-1106-1207-1213-1214-1220-1221-1227-1228-12}2015{03-0104-0110-0111-0117-0118-0124-0125-0131-0101-0207-0208-0214-0215-0221-0222-0228-0201-0307-0308-0314-0315-0321-0322-0328-0329-0304-0405-0411-0412-0418-0419-0425-0426-0402-0503-0509-0510-0516-0517-0523-0524-0530-0531-0506-0607-0613-0614-0620-0621-0627-0628-0604-0705-0711-0712-0718-0719-0725-0726-0701-0802-0808-0809-0815-0816-0822-0823-0829-0830-0805-0906-0912-0913-0919-0920-0926-0927-0903-1004-1010-1011-1017-1018-1024-1025-1031-1001-1107-1108-1114-1115-1121-1122-1128-1129-1105-1206-1212-1213-1219-1220-1226-1227-12}2016{02-0103-0109-0110-0116-0117-0123-0124-0130-0131-0106-0207-0213-0214-0220-0221-0227-0228-0205-0306-0312-0313-0319-0320-0326-0327-0302-0403-0409-0410-04}', 1, 1, 5, 5);
INSERT INTO `heroku_3eb85e4f7505b47`.`subject_competence` (`teacher_id`, `title`, `subject_competence_teacher_id`, `subject_competence_title`, `edmodo_group`, `initial_date`, `final_date`, `description`, `non_academic_days`, `each_positive_weight`, `each_negative_weight`, `max_positive_weight`, `max_negative_weight`) VALUES (1, 'POIS', 1, 'Inglés de 4º', 'inventado2', '2014-04-01', '2015-05-20', 'Programación Orientada a la Integración de Sistemas.', '2014{05-0406-0412-0413-0419-0420-0423-0426-0427-0403-0504-0505-0510-0511-0517-0518-0524-0525-0531-0501-0607-0608-0614-0615-0621-0622-0628-0629-06}', 1, 1, 5, 5);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Participativo', 'Alumno que participa.', 'inventado1', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Hace deberes', 'Hace los deberes siempre.', 'inventado2', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'No trabaja', 'No trabaja en clase.', 'inventado3', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Hablador', 'Es muy hablador.', 'inventado4', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Trabaja en casa', 'Trabaja siempre en casa.', 'inventado5', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Participa en clase', 'Participa en clase continuamente.', 'inventado6', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Muy hablador', 'Normalmenete habla mucho.', 'inventado7', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'No para de hablar', 'No se contiene en clase.', 'inventado8', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Es muy activo', 'No para de trabajar.', 'inventado9', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Hace los deberes en casa', 'Trabaja a diario en casa.', 'inventado10', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'No trabaja en clase', 'No se esfuerza en clase.', 'inventado11', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (1, 'Es impaciente', 'Es muy impaciente con las calificaciones.', 'inventado12', 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`behaviour_attitude_aspect` (`teacher_id_teacher`, `name`, `description`, `edmodo_id`, `type`) VALUES (11, 'Es muy detallista', 'Se esfuerza en todos los trabajos y pruebas.', 'inventadoOtro1', 1);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`assignment`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1, 'other1', 20, 0, '2015-07-13', 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (11, 'other2', 20, 1, '2016-01-02', 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (21, 'other3', 50, 3, '2016-01-02', 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (31, 'other4', 20, 0, '2016-01-02', 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (41, 'other5', 20, 4, '2014-05-02', 1, 'Mates de 2º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (51, 'other6', 80, 1, '2015-04-20', 1, 'Mates de 2º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (61, 'other7', 20, 1, '2015-05-19', 1, 'Mates de 2º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (71, 'other8', 50, 0, '2014-03-20', 1, 'Mates de 2º');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (81, 'other9', 100, 3, '2014-05-20', 1, 'POIS');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (91, 'other10', 30, 1, '2014-08-14', 1, 'POIS');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (101, 'other11', 10, 0, '2015-05-19', 1, 'POIS');
INSERT INTO `heroku_3eb85e4f7505b47`.`assignment` (`id_assignment`, `id_edmodo`, `associated_weight`, `type`, `date`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (111, 'other12', 60, 1, '2015-05-20', 1, 'POIS');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`evaluable_item`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (1, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (1, 'Claridad de expresión', 30);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (11, 'Ortografía', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (21, 'Unidades en las fórmulas', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (21, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (31, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (31, 'Unidades en las fórmulas', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (41, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (41, 'Claridad de expresión', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (51, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (51, 'Claridad de expresión', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (61, 'Unidades en las fórmulas', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (61, 'Ortografía', 50);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (71, 'Claridad de expresión', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (81, 'Ortografía', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (91, 'Claridad de expresión', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (101, 'Claridad de expresión', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (111, 'Ortografía', 100);
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item` (`assignment_id_fk`, `name`, `associated_weight`) VALUES (1, 'Unidades en las fórmulas', 20);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`student`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (1, '3f14e6839', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (11, 'inventado2', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (21, 'inventado3', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (31, 'inventado4', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (41, 'inventado5', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (51, 'asa12cas', 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`student` (`id_student`, `id_edmodo`, `id_language`) VALUES (61, '12312gcax', 1);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`evaluable_item_student`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 8, 1, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 6, 1, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 7, 1, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 3, 1, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 4, 1, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 5, 1, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 6, 11, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 1, 11, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 10, 11, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 1, 21, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 3, 21, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 4, 21, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 1, 21, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 6, 21, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 8, 31, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 9, 31, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 10, 31, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 9, 31, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 6, 31, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 7, 41, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 8, 41, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 3, 41, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 4, 41, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 6, 41, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 7, 41, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 8, 51, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 9, 51, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 5, 51, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 2, 51, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 5, 51, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 6, 61, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 7, 61, 'Unidades en las fórmulas');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 8, 61, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 9, 61, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 5, 61, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 5, 71, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 3, 71, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 4, 81, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 5, 81, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 6, 91, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (51, 7, 91, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (61, 8, 91, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (1, 5, 101, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (11, 2, 101, 'Claridad de expresión');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (21, 8, 111, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (31, 7, 111, 'Ortografía');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluable_item_student` (`student_id_fk`, `score`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`) VALUES (41, 3, 111, 'Ortografía');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`bonus_penalization`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Inglés de 4º', 1, 1, 'Gran trabajador');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Inglés de 4º', 11, 0.2, 'Se esfuerza');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Inglés de 4º', 21, 0.6, 'Participa en clase');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Inglés de 4º', 31, -0.1, 'No se esfuerza');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Mates de 2º', 1, -0.3, 'No para de hablar');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Mates de 2º', 11, -0.2, 'Es un gran parlanchín');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'Mates de 2º', 21, 1.2, 'Avanza muchísimo');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'POIS', 1, 0.3, 'Por encima de la media');
INSERT INTO `heroku_3eb85e4f7505b47`.`bonus_penalization` (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`, `score`, `reason`) VALUES (1, 'POIS', 11, 0.5, 'Gran tabajo');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`calification`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (1, 1, 0.5, 'Muy trabajador', 'Trabaja mucho.', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (1, 11, 1, 'Activo', NULL, 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (1, 21, 1, 'Muy trabajador', NULL, 1, 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (11, 31, 0, 'Muy trabajador', 'Es muy trabajador.', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (11, 41, 0, 'Hace deberes', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (11, 51, -0.2, 'No estudia', 'Debe estudiar más.', 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (21, 61, 0, NULL, NULL, 1, 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (21, 1, 0, NULL, NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (21, 11, 0.2, 'Muy trabajador', 'Muy trabajador', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (31, 21, -0.3, 'Habla mucho', 'Habla mucho.', 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (31, 31, -0.4, 'No se esfuerza', 'No se esfuerza.', 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (41, 41, 1, 'Muy trabajador', 'Lo trabaja bien.', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (41, 51, 0.5, 'Muy trabajador', NULL, 1, 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (51, 61, 0.2, 'Se esfuerza', 'Es eficaz.', 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (61, 1, 0.1, 'Constante', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (61, 11, 0, NULL, NULL, 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (61, 21, -0.3, 'No trabaja', 'No trabaja nada', 1, 0);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (71, 51, -0.4, 'No trabaja', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (81, 61, 0.5, 'Muy trabajador', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (91, 61, 0.3, 'Muy trabajador', 'Se nota el trabajo diario.', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (91, 41, 0.2, 'Constante', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (101, 1, 0.1, 'Es eficaz', NULL, 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (101, 11, 0.1, 'Es atento', NULL, 0, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (111, 21, -0.2, 'Hablador', NULL, 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (111, 31, 0.5, 'Muy trabajador', 'Se nota el trabajo diario.', 1, 1);
INSERT INTO `heroku_3eb85e4f7505b47`.`calification` (`assignment_id_fk`, `student_id_fk`, `bonus_penalization`, `reason_bonus_penalization`, `optional_comment`, `visible_student`, `visible_parent`) VALUES (111, 41, 0.6, 'Muy trabajador', NULL, 1, 0);

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`aspect_student`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (1, 1, 'Participativo', 1, 'POIS', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (11, 1, 'Es muy activo', 1, 'Inglés de 4º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (21, 1, 'Trabaja en casa', 1, 'Mates de 2º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (1, 1, 'Hace deberes', 1, 'POIS', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (11, 1, 'Participa en clase', 1, 'Inglés de 4º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (21, 1, 'Participativo', 1, 'Inglés de 4º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (1, 1, 'No trabaja', 1, 'Inglés de 4º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (11, 1, 'Hace los deberes en casa', 1, 'Mates de 2º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (21, 1, 'Es muy activo', 1, 'POIS', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (1, 1, 'Hablador', 1, 'Mates de 2º', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (11, 1, 'No trabaja', 1, 'POIS', '2014-06-16');
INSERT INTO `heroku_3eb85e4f7505b47`.`aspect_student` (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `date`) VALUES (1, 1, 'Trabaja en casa', 1, 'Mates de 2º', '2014-06-16');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`evaluation_period`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (371, '2014-04-01', '2014-07-09', 30, 1, 'POIS');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (381, '2014-07-10', '2015-05-20', 30, 1, 'POIS');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1521, '2014-04-16', '2014-07-15', 20, 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1531, '2014-07-16', '2015-08-15', 20, 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1541, '2015-08-16', '2016-04-15', 30, 1, 'Inglés de 4º');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1551, '2014-04-16', '2015-01-06', 50, 1, 'Mates de 2º');
INSERT INTO `heroku_3eb85e4f7505b47`.`evaluation_period` (`id_evaluation_period`, `initial_date`, `final_date`, `percentage`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`) VALUES (1561, '2015-01-06', '2015-05-20', 20, 1, 'Mates de 2º');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`absence`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (1, 1, 'Inglés de 4º', '2014{17-0418-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (1, 1, 'Mates de 2º', '2014{17-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (1, 1, 'POIS', '2014{01-0408-0412-0415-0417-0418-0421-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (11, 1, 'Mates de 2º', '2014{20-0421-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (11, 1, 'POIS', '2014{19-0420-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (21, 1, 'Mates de 2º', '2014{20-0421-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (21, 1, 'POIS', '2014{20-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (31, 1, 'Inglés de 4º', '2014{17-0419-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (31, 1, 'Mates de 2º', '2014{22-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (31, 1, 'POIS', '2014{20-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (41, 1, 'Inglés de 4º', '2014{21-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (41, 1, 'Mates de 2º', '2014{22-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (41, 1, 'POIS', '2014{20-0422-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (51, 1, 'Mates de 2º', '2014{22-04}');
INSERT INTO `heroku_3eb85e4f7505b47`.`absence` (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`, `dates`) VALUES (61, 1, 'Mates de 2º', '2014{22-04}');

COMMIT;


-- -----------------------------------------------------
-- Data for table `heroku_3eb85e4f7505b47`.`parent`
-- -----------------------------------------------------
START TRANSACTION;
USE `heroku_3eb85e4f7505b47`;
INSERT INTO `heroku_3eb85e4f7505b47`.`parent` (`id_edmodo`, `id_language`) VALUES ('inventadoPadre1', 1);

COMMIT;

