package classcontrol.controller;

import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.Absence;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Sets some absence dates to a student or student group.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class AbsenceStudent3Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final String idEdmodoTeacher = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoTeacher == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }

        // 0. Get student's list and absences to apply
        final String[] studentList = this.request.getParameterValues(ConstantsForm.ATTEND_ABSENCES_STUDENTS);
        final int STUDENTS_LIST_SIZE = studentList == null ? 0 : studentList.length;
        final String absencesParameter = this.request.getParameter(ConstantsForm.ATTEND_ABSENCES);
        final byte SPLIT = 1;
        final Persistence myPersistence = new Persistence();
        final SubjectCompetence sc= ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);
        final String titleSubjectCompetence = sc.getTitle();
        // 1. 1 student
        final String mySeparator = ConstantsForm.SEPARATOR;
        final int LENGTH = mySeparator.length();
        if (STUDENTS_LIST_SIZE == SPLIT) {
            final String onlySelectedUser = studentList[0];
            // 1.1. Update absences directly.
            // 1.1.1. No absences -> Delete student-subject competence absences from database.
            // 1.1.1. Yes absences. -> Delete + Insert.
            myPersistence.updateAbsencesStudent(onlySelectedUser.substring(onlySelectedUser.indexOf(mySeparator) + LENGTH), idEdmodoTeacher, titleSubjectCompetence, DatesUtil.getDatabaseDates(absencesParameter));
        } else {
            // 2. 2 or more students
            // 2.1. No absences -> Nothing is modified
            if (STUDENTS_LIST_SIZE > SPLIT && absencesParameter != null && absencesParameter.length() > 1) {
                final List<Absence> mList = myPersistence.getAbsencesSubjectCompetence(sc.getTeacherId(), titleSubjectCompetence);
                final int ABSENCES_SIZE = mList.size();
                String currentIdEdmodoStudent;
                String mStudentAbsences;
                for (final String student : studentList) {
                    mStudentAbsences = "";
                    // 2.2. Get current student absence dates
                    currentIdEdmodoStudent = student.substring(student.indexOf(mySeparator) + LENGTH);
                    boolean find = false;
                    int counter = 0;
                    Absence currentAbsence;
                    while (!find && counter < ABSENCES_SIZE) {
                        currentAbsence = mList.get(counter);
                        if (currentAbsence.getStudentId() == myPersistence.getStudentId(currentIdEdmodoStudent)) {
                            mStudentAbsences = DatesUtil.getDatepickerDates(currentAbsence.getDates()).toString();
                            find = true;
                        }
                        counter++;
                    }
                    // 2.2.1. Add new absences dates to current student absence dates.
                    mStudentAbsences = (mStudentAbsences.length() > 1 ? mStudentAbsences + ConstantsForm.MULTI_DATE_SEPARATOR : "") + absencesParameter;
                    // 2.2.1.1. Validate and get database absences text.
                    // 2.2.1.1.1 Delete possible absence student-subject competence and insert new one
                    myPersistence.updateAbsencesStudent(currentIdEdmodoStudent, idEdmodoTeacher, titleSubjectCompetence, DatesUtil.getDatabaseDates(mStudentAbsences));
                }
            }
        }
        // Set redirect url
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/AttendSubjectCompetence.jsp" + '&' + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + subjectCompetenceSelected);
    }
}