package classcontrol.controller;

import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * Obtains all subject competence's behaviour attitude aspects and shows
 * selected student's behaviour attitude aspects or nothing if various students
 * are selected.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class AspectStudent2Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final String idEdmodoTeacher = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoTeacher == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        String myStudentReport = this.request.getParameter(Constants.PARAMETER_COMES_FROM_REPORT);
        if (myStudentReport != null) {
            final JSONObject mjson;
            try {
                mjson = new JSONArray(EdmodoAPI.users((String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), new String[]{myStudentReport})).getJSONObject(0);
                myStudentReport = mjson.getString(EdmodoAPI.API_FIRST_NAME_KEY) + ' ' + mjson.getString(EdmodoAPI.API_LAST_NAME_KEY) + ConstantsForm.SEPARATOR + myStudentReport;
            } catch (final JSONException ex) {
                throw new ControllerException();
            }
        }
        final String[] selectedStudents = myStudentReport != null ? new String[]{myStudentReport} : this.request.getParameterValues(ConstantsForm.ATTEND_ABSENCES_STUDENTS);

        final int SIZE = selectedStudents == null ? 0 : selectedStudents.length;
        if (SIZE == 0) {
            throw new ControllerException(CurrentLanguage.getString(Text.S_C_ATTEND_AT_LEAST_ONE, request));
        }
        final SubjectCompetence mySubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);
        if (SIZE == 1) {
            // Get all behaviour attitude aspects.
            final String onlySelectedUser = selectedStudents[0];
            final int possibleSeparator = onlySelectedUser.lastIndexOf(ConstantsForm.SEPARATOR);
            final String edmodoStudentId = onlySelectedUser.substring(possibleSeparator == -1 ? 0 : possibleSeparator + ConstantsForm.SEPARATOR.length());
            final Persistence mPersistence = new Persistence();
            try {
                // Class Control database aspects
                final List<StudentAspect> mList = mPersistence.getBAAspectsSubjectCompetenceStudent(idEdmodoTeacher, mySubjectCompetence.getTitle(), edmodoStudentId);
                final List<String> mAspectNames = new ArrayList<String>();
                for (final StudentAspect myStudentAspect : mList) {
                    mAspectNames.add(myStudentAspect.getName());
                }
                this.request.setAttribute(Constants.ATT_STUDENT_ASPECTS_LIST, mAspectNames);
                // Not show any absence if two or more students were selected.
            } catch (final Exception ex) {
                throw new ControllerException();
            }
        }
        new BehaviourAttitudeUtil().setRequestPositiveNegativeList(idEdmodoTeacher, request, true);
        this.request.setAttribute(Constants.ATT_STUDENT_ASPECTS_SELECTED_LIST, selectedStudents);
    }
}