package classcontrol.controller;

import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Sets behaviour attitude aspects to a student or student group.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class AspectStudent3Controller extends AbstractController {

    final static String mySeparator = ConstantsForm.SEPARATOR;
    final static int LENGTH = mySeparator.length();

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final String idEdmodoTeacher = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoTeacher == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }

        // 0. Get selected student's list and aspects list to apply
        final String[] studentList = this.request.getParameterValues(ConstantsForm.ATTEND_ABSENCES_STUDENTS);
        final int STUDENTS_LIST_SIZE = studentList == null ? 0 : studentList.length;
        final String[] positiveAspectsParameter = this.request.getParameterValues(ConstantsForm.CREATE_ASPECT_LIST_POSITIVE);
        final String[] negativeAspectsParameter = this.request.getParameterValues(ConstantsForm.CREATE_ASPECT_LIST_NEGATIVE);
        // Selected aspects name
        final ArrayList<String> mAspectsName = new ArrayList<String>();
        // Selected aspects edmodo id
        final ArrayList<String> mAspectsEdmodoId = new ArrayList<String>();
        int separatorIndex;
        int totalAspects = 0;
        if (positiveAspectsParameter != null) {
            for (final String positiveAspect : positiveAspectsParameter) {
                separatorIndex = positiveAspect.indexOf(mySeparator);
                mAspectsName.add(positiveAspect.substring(0, separatorIndex));
                mAspectsEdmodoId.add(positiveAspect.substring(separatorIndex + LENGTH));
                totalAspects++;
            }
        }
        if (negativeAspectsParameter != null) {
            for (final String negativeAspect : negativeAspectsParameter) {
                separatorIndex = negativeAspect.indexOf(mySeparator);
                mAspectsName.add(negativeAspect.substring(0, separatorIndex));
                mAspectsEdmodoId.add(negativeAspect.substring(separatorIndex + LENGTH));
                totalAspects++;
            }
        }
        final byte SPLIT = 1;
        final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);
        final String titleSubjectCompetence = mSubjectCompetence.getTitle();
        String edmodoStudentId;
        final String accessToken = (String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY);
        // 1. 1 student
        try {
            if (STUDENTS_LIST_SIZE >= SPLIT) {
                // If 1 student: no aspects -> all revoked (only current subject competence's aspects).
                ArrayList<Thread> mThreads;
                Thread mThread;
                if (STUDENTS_LIST_SIZE == SPLIT) {
                    edmodoStudentId = studentList[0];
                    edmodoStudentId = edmodoStudentId.substring(edmodoStudentId.indexOf(mySeparator) + LENGTH);
                    // 1. Delete all previous aspects.
                    final Persistence mPersistence = new Persistence();
                    final List<StudentAspect> mList = mPersistence.getBAAspectsSubjectCompetenceStudent(idEdmodoTeacher, mSubjectCompetence.getTitle(), edmodoStudentId);

                    mThreads = new ArrayList<Thread>();
                    for (final StudentAspect mStudentAspect : mList) {
                        mThread = new ThreadUpdater(accessToken, mStudentAspect.getEdmodoId(), edmodoStudentId, REVOKE_BADGE);
                        mThread.start();
                        mThreads.add(mThread);
                        //EdmodoAPI.revokeBadge(accessToken, mStudentAspect.getEdmodoId(), edmodoStudentId);
                    }
                    for (final Thread current : mThreads) {
                        current.join();
                    }
                    // 2. Award specified aspects (asynchronously)
                    mThreads = new ArrayList<Thread>();
                    for (int i = 0; i < totalAspects; i++) {
                        mThread = new ThreadUpdater(accessToken, mAspectsEdmodoId.get(i), edmodoStudentId, AWARD_BADGE);
                        mThread.start();
                        mThreads.add(mThread);
                    }
                    for (final Thread current : mThreads) {
                        current.join();
                    }
                    mPersistence.updateAspectsStudent(edmodoStudentId, idEdmodoTeacher, titleSubjectCompetence, mAspectsName, true);
                } else {
                    // If 2 or more students: no aspects -> Nothing is modified
                    mThreads = new ArrayList<Thread>();
                    for (final String student : studentList) {
                        mThread = new ThreadMultiUpdater(student, accessToken, idEdmodoTeacher, titleSubjectCompetence, mAspectsEdmodoId, mAspectsName, totalAspects);
                        mThread.start();
                        mThreads.add(mThread);
                    }
                    for (final Thread current : mThreads) {
                        current.join();
                    }
                }
            }
        } catch (final Exception ex) {
            throw new ControllerException();
        }
        // Set redirect url
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/BehaviourAttitudeSubjectCompetence.jsp" + '&' + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + subjectCompetenceSelected);
    }
    private final static byte AWARD_BADGE = 0;
    private final static byte REVOKE_BADGE = 1;

    /**
     * Makes an http request to set behaviour attitude aspects (Edmodo badges).
     */
    final class ThreadUpdater extends Thread {

        String accessToken;
        String badgeId;
        String studentEdmodoId;
        byte method;

        public ThreadUpdater(final String accessToken,
                final String badgeId, final String studentEdmodoId, final byte method) {
            super();
            this.accessToken = accessToken;
            this.studentEdmodoId = studentEdmodoId;
            this.badgeId = badgeId;
            this.method = method;
        }

        @Override
        public void run() {
            if (method == AWARD_BADGE) {
                EdmodoAPI.awardBadge(accessToken, badgeId, studentEdmodoId);
            } else {
                EdmodoAPI.revokeBadge(accessToken, badgeId, studentEdmodoId);
            }
        }
    }

    /**
     * Makes various http requests to set behaviour attitude aspects (Edmodo
     * badges).
     */
    final class ThreadMultiUpdater extends Thread {

        String student;
        String accessToken;
        String idEdmodoTeacher;
        String titleSC;
        ArrayList<String> mAspectsEdmodoId;
        ArrayList<String> mAspectsName;
        int totalAspects;

        public ThreadMultiUpdater(final String student, final String accessToken, final String idEdmodoTeacher, final String titleSC, final ArrayList<String> mAspectsEdmodoId, ArrayList<String> mAspectsName, final int totalAspects) {
            super();
            this.student = student;
            this.accessToken = accessToken;
            this.idEdmodoTeacher = idEdmodoTeacher;
            this.titleSC = titleSC;
            this.mAspectsEdmodoId = mAspectsEdmodoId;
            this.mAspectsName = mAspectsName;
            this.totalAspects = totalAspects;
        }

        @Override
        public void run() {
            final String edmodoStudentId = student.substring(student.indexOf(mySeparator) + LENGTH);
            String edmodoBadgeId;
            final List<StudentAspect> mList = new Persistence().getBAAspectsSubjectCompetenceStudent(idEdmodoTeacher, titleSC, edmodoStudentId);
            final int LIST_SIZE = mList.size();
            boolean find;
            int counter;
            for (int i = 0; i < totalAspects; i++) {
                edmodoBadgeId = mAspectsEdmodoId.get(i);
                find = false;
                counter = 0;
                // Insert only if not exists
                while (!find && counter < LIST_SIZE) {
                    if (edmodoBadgeId.compareTo(mList.get(counter).getEdmodoId()) == 0) {
                        find = true;
                    }
                    counter++;
                }
                if (!find) {
                    EdmodoAPI.awardBadge(accessToken, edmodoBadgeId, edmodoStudentId);
                }
            }
            new Persistence().updateAspectsStudent(edmodoStudentId, idEdmodoTeacher, titleSC, mAspectsName, false);
        }
    }
}