/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.text.Collator;
import java.util.List;
import javax.servlet.http.HttpServletRequest;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class AspectUtil {

    private final HttpServletRequest request;
    private static String ERROR_MSG;

    private AspectUtil() {
        this.request = null;
    }

    /**
     *
     * @param request Incoming request.
     */
    public AspectUtil(final HttpServletRequest request) {
        this.request = request;
        ERROR_MSG = CurrentLanguage.getString(Text.NO_VALID_ARGUMENT, this.request) + ": ";
    }
    /**
     *
     */
    public final static byte NEW_NAME = 0;
    /**
     *
     */
    public final static byte OLD_NAME = 1;

    /**
     * Returns a name
     *
     * @param idEdmodoUser
     * @return [NEW_NAME]:new name<br/>
     * [OLD_NAME]:old name
     * @throws ControllerException
     */
    public String[] getName(final String idEdmodoUser) throws ControllerException {
        final String name = this.request.getParameter(ConstantsForm.CREATE_ASPECT_NAME);
        String oldName = this.request.getParameter(ConstantsForm.MODIFY_ASPECT_HIDDEN_OLD_NAME);
        if (oldName != null) {
            oldName = oldName.toLowerCase();
        }
        if (name == null || name.length() == 0 || name.length() > ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_S_C_TITLE_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASPECT_NAME);
        }
        // 1. Check new aspect's name is repeated.
        final List<BehaviourAttitudeAspect> totalList = new BehaviourAttitudeUtil().getBehaviourAttitudeAspectsEdmodo(idEdmodoUser);
        final int SIZE_LIST = totalList.size();
        boolean isRepeated = false;
        int counter = 0;
        final String newNameLower = name.toLowerCase();
        String currentName;
        final Collator c = Collator.getInstance();
        c.setStrength(Collator.NO_DECOMPOSITION);
        while (!isRepeated && counter < SIZE_LIST) {
            currentName = totalList.get(counter).getName().toLowerCase();
            if (c.compare(currentName, newNameLower) == 0 && (oldName != null && oldName.compareTo(currentName) != 0)) {
                isRepeated = true;
            }
            counter++;
        }
        if (isRepeated) {
            throw new ControllerException(CurrentLanguage.getString(Text.BEHAVIOUR_ATTITUDE_ASPECT_REPEAT, this.request));
        }
        return new String[]{name, oldName};
    }

    /**
     *
     * @return @throws ControllerException 
     * @throws ControllerException
     */
    public String getDescription() throws ControllerException {
        final String description = this.request.getParameter(ConstantsForm.CREATE_ASPECT_DESCRIPTION);
        if (description == null || description.length() == 0 || description.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_DESCRIPTION_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASPECT_DESCRIPTION);
        }
        return description;
    }

    /**
     *
     * @param isMandatory
     * @return
     * @throws ControllerException
     */
    public String getUrlImg(final boolean isMandatory) throws ControllerException {
        final String url = this.request.getParameter(ConstantsForm.CREATE_ASPECT_URL);
        if (isMandatory && (url == null || url.length() == 0 || url.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_URL_MAX || !ImageUtil.isJpgJpegPngGif(url))) {
            throw new ControllerException(ERROR_MSG + CurrentLanguage.getString(Text.CBAA_VALID_URL_HINT, this.request));
        } else {
            if (!isMandatory && url.length() > 0 && (url.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_URL_MAX || !ImageUtil.isJpgJpegPngGif(url))) {
                throw new ControllerException(ERROR_MSG + CurrentLanguage.getString(Text.CBAA_VALID_URL_HINT, this.request));
            }
        }
        return url != null && url.length() == 0 ? null : url;
    }

    /**
     *
     * @return
     * @throws ControllerException
     */
    public byte getType() throws ControllerException {
        final String type = this.request.getParameter(ConstantsForm.CREATE_ASPECT_TYPE);
        final byte positiveType = ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX];
        final byte negativeType = ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NEGATIVE_INDEX];
        byte response = negativeType;
        try {
            response = Byte.parseByte(type);
        } catch (final Exception ex) {
        }
        if (response != positiveType && response != negativeType) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASPECT_TYPE);
        }
        return response;
    }
}