package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Assignment;
import classcontrol.entity.Calification;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluableItemStudentCalification;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.Student;
import classcontrol.entity.StudentCalificationReport;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONObject;

/**
 * Handles all assignment's bussiness logic.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class AssignmentUtil {

    private final HttpServletRequest request;

    private AssignmentUtil() {
        this.request = null;
    }

    /**
     *
     * @param request Incoming request.
     */
    public AssignmentUtil(final HttpServletRequest request) {
        this.request = request;
    }

    /**
     *
     * @return Selected assignment id.
     * @throws ControllerException If there is not any assignment selected as
     * parameter.
     */
    public int getSelectedAssignmentId() throws ControllerException {
        try {
            return Integer.parseInt(request.getParameter(Constants.PARAMETER_ASSIGNMENT_SELECTED));
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
    }

    /**
     * Retruns all specified assignment's data.
     *
     * @param selectedAssignmentId Assignment's id to get data.
     * @param edmodoGroup Edmodo id for a group.
     * @param teacherIdSC Subject competence's teacher id.
     * @param titleSC Subject competence's title.
     * @return all specified assignment's data.
     * @throws ControllerException If some arguemnts
     */
    public Assignment getSelectedAssignmentAllData(final int selectedAssignmentId, final String edmodoGroup, final int teacherIdSC, final String titleSC) throws ControllerException {
        final List<EvaluationPeriodAssignment> evaluationPeriodAssigments = this.getAllAssignmentsEvaluationperiod(edmodoGroup, teacherIdSC, titleSC, false);
        Assignment assignment = null;
        if (evaluationPeriodAssigments != null) {
            final int EVALUATION_PERIODS_SIZE = evaluationPeriodAssigments.size();
            boolean find = false;
            int counter = 0;
            int counterAux;
            Assignment auxAssignment;
            List<Assignment> auxList;
            int assignmentsSize;
            while (!find && counter < EVALUATION_PERIODS_SIZE) {
                auxList = evaluationPeriodAssigments.get(counter).getMyAssignmentsList();
                assignmentsSize = auxList.size();
                counterAux = 0;
                while (!find && counterAux < assignmentsSize) {
                    auxAssignment = auxList.get(counterAux);
                    if (auxAssignment.getIdAssignment() == selectedAssignmentId) {
                        assignment = auxAssignment;
                        find = true;
                    }
                    counterAux++;
                }
                counter++;
            }
        }
        return assignment;
    }

    /**
     * Gets all specific subject competence's assignments classified by subject
     * competence's evaluation periods.<br/>
     *
     * BE CAREFUL, if one assignment is repeated in evaluation periods that have
     * same interval days, it will only appear once.
     *
     * @param edmodoGroup
     * @param teacherIdSC
     * @param titleSC
     * @param setAttribute True if this method should set the list in a request
     * attribute. False otherwise.
     * @return All specific subject competence's assignments classified by
     * evaluation periods
     */
    public ArrayList<EvaluationPeriodAssignment> getAllAssignmentsEvaluationperiod(final String edmodoGroup, final int teacherIdSC, final String titleSC, final boolean setAttribute) throws ControllerException {
        // 1. Get Class Control database's assignments and create two lists: grades and assignments.
        try {
            byte type;
            final List<Assignment> myBDAssignments = new ArrayList<Assignment>();
            final List<Assignment> myBDGrades = new ArrayList<Assignment>();
            final Persistence mPersistence = new Persistence();
            final List<Assignment> myBDAssignmentsGrades = mPersistence.getAssignments(teacherIdSC, titleSC);
            final byte assignmentOnline = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_INDEX];
            final byte assignmentOffline = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_INDEX];
            for (final Assignment currentAssignment : myBDAssignmentsGrades) {
                type = currentAssignment.getType();
                if (type == assignmentOnline || type == assignmentOffline) {
                    myBDGrades.add(currentAssignment);
                } else {
                    myBDAssignments.add(currentAssignment);
                }
            }
            myBDAssignmentsGrades.clear();

            // 2. Get Edmodo's assignments (grades and assignments)
            // 2.1. Grades
            final HttpSession mSession = request.getSession();
            final String accessToken = (String) mSession.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY);
            final JSONArray gradesSetByAppForGroup = new JSONArray(EdmodoAPI.gradesSetByAppForGroup(accessToken, edmodoGroup));
            final int GRADES_LENGTH = gradesSetByAppForGroup.length();
            JSONObject mJSONObjectAux;
            // 2.1.1 Check Edmodo's grades for this subject competence:
            boolean find;
            int counter;
            final int DATABASE_GRADES = myBDGrades.size();
            Assignment mAssignment;
            for (int i = 0; i < GRADES_LENGTH; i++) {
                mJSONObjectAux = gradesSetByAppForGroup.getJSONObject(i);
                find = false;
                counter = 0;
                while (!find && counter < DATABASE_GRADES) {
                    mAssignment = myBDGrades.get(counter);
                    if (mAssignment.getEdmodoId().compareTo(mJSONObjectAux.getString(EdmodoAPI.API_GRADE_ID_KEY)) == 0) {
                        mAssignment.setTitle(mJSONObjectAux.getString(EdmodoAPI.API_TITLE_KEY));//Mandatory in Edmodo
                        mAssignment.setMaxGrade((int) mJSONObjectAux.optDouble(EdmodoAPI.API_GRADE_TOTAL_KEY, mAssignment.getMaxGrade()));//Optional in Edmodo
                        myBDAssignmentsGrades.add(mAssignment);
                        find = true;
                    }
                    counter++;
                }
            }


            // 2.2. Assignments
            // Check Edmodo's assignments for this subject competence:
            final JSONArray assignmentsSetByAppForTeacher = new JSONArray(EdmodoAPI.assignmentsByAppForUser(accessToken, mPersistence.getIdEdmodoTeacher(teacherIdSC)));
            final int ASSIGNMENTS_LENGTH = assignmentsSetByAppForTeacher.length();
            final int DATABASE_ASSIGNMENTS = myBDAssignments.size();
            // 2.1.1 Check Edmodo's grades for this subject competence:
            // Edmodo's date format format yyyy-MM-dd
            final SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            for (int i = 0; i < ASSIGNMENTS_LENGTH; i++) {
                mJSONObjectAux = assignmentsSetByAppForTeacher.getJSONObject(i);
                find = false;
                counter = 0;
                while (!find && counter < DATABASE_ASSIGNMENTS) {
                    mAssignment = myBDAssignments.get(counter);
                    if (mAssignment.getEdmodoId().compareTo(mJSONObjectAux.getString(EdmodoAPI.API_ASSIGNMENT_ID_KEY)) == 0) {
                        mAssignment.setTitle(mJSONObjectAux.getString(EdmodoAPI.API_ASSIGNMENT_TITLE_KEY));
                        mAssignment.setDescription(mJSONObjectAux.optString(EdmodoAPI.API_DESCRIPTION_KEY, mAssignment.getDescription()));
                        // setMaxGrade NO, In Classs Control, one you put a max score, you can not change it: mAssignment.setMaxGrade((int) mJSONObjectAux.optDouble(EdmodoAPI.API_GRADE_TOTAL_KEY, mAssignment.getMaxGrade()));
                        mAssignment.setDate(sdf.parse(mJSONObjectAux.getString(EdmodoAPI.API_ASSIGNMENT_DUE_DATE_KEY)));
                        myBDAssignmentsGrades.add(mAssignment);
                        find = true;
                    }
                    counter++;
                }
            }
            // 3. All current subject competence's periods:
            // 4. All current subject competence's assignments:
            // 5. Current subject competence (start and end date, positive and negative aspects' weight and associated subject competence's weight).
            final ArrayList<EvaluationPeriodAssignment> myEvaluationPeriodsAssignments = new ArrayList<EvaluationPeriodAssignment>();
            Date initialDateAux, finalDateAux, assignmentDateAux;
            int assignmentAuxId;
            ArrayList<Assignment> auxAssignmentsPeriod;
            final ArrayList<Integer> assignmentsAdded = new ArrayList<Integer>();
            final List<EvaluationPeriod> evaluationperiodsList = mPersistence.getEvaluationPeriodsSubjectCompetence(teacherIdSC, titleSC);
            for (final EvaluationPeriod myEvaluationPeriod : evaluationperiodsList) {
                auxAssignmentsPeriod = new ArrayList<Assignment>();
                initialDateAux = myEvaluationPeriod.getInitialDate();
                finalDateAux = myEvaluationPeriod.getFinalDate();
                for (final Assignment myAssignment : myBDAssignmentsGrades) {
                    assignmentDateAux = myAssignment.getDate();
                    assignmentAuxId = myAssignment.getIdAssignment();
                    if (!assignmentsAdded.contains(assignmentAuxId) && assignmentDateAux.compareTo(initialDateAux) >= 0 && assignmentDateAux.compareTo(finalDateAux) <= 0) {
                        auxAssignmentsPeriod.add(myAssignment);
                        assignmentsAdded.add(assignmentAuxId);
                    }
                }
                myEvaluationPeriodsAssignments.add(new EvaluationPeriodAssignment(myEvaluationPeriod, auxAssignmentsPeriod));
            }
            if (setAttribute) {
                request.setAttribute(Constants.ATT_LIST_ASSIGNMENTS, myEvaluationPeriodsAssignments);
            }
            return myEvaluationPeriodsAssignments;
        } catch (final Exception ex) {
            throw new ControllerException();
        }
    }

    /**
     * Returns all possible assignment's califications for a specific
     * assignment. If some user has not a calification, a new calification with
     * defalt values is returned.
     *
     * @param mData Subject competence's data.
     * @param assignmentId
     * @param edmodoGroupSC
     * @return All possible assignment's califications for a specific
     * assignment.
     */
    public List<StudentCalificationReport> getAssignmentCalifications(final EvaluableItemStudentCalification mData, final int assignmentId, final String edmodoGroupSC, final List<Student> subjectCompetenceMembers) {
        // 1. Get all assignment's user's califications.
        boolean findCalification;
        int auxIdStudent;
        int counter;
        Calification auxCalification = null;

        // 2. Get subject competence's data
        // BE CAREFULL, DO NOT REMOVE LIST ITEMS, IT IS BETTER ADD ITEMS IN LOCAL VARIABLES.
        final List<Calification> mAssignmentsCalification = mData.getCalifications();
        final List<Calification> mAssignmentsCalificationAux = new ArrayList<Calification>();
        for (final Calification current : mAssignmentsCalification) {
            if (current.getIdAssignment() == assignmentId) {
                mAssignmentsCalificationAux.add(current);
            }
        }
        final List<EvaluableItemStudent> mEvaluableItemStudent = mData.getEvaluableItemStudent();
        final List<EvaluableItemStudent> mEvaluableItemStudentAux = new ArrayList<EvaluableItemStudent>();
        for (final EvaluableItemStudent current : mEvaluableItemStudent) {
            if (current.getIdAssignment() == assignmentId) {
                mEvaluableItemStudentAux.add(current);
            }
        }

        // 3. Each student
        final int CALIFICATIONS_LENTGH = mAssignmentsCalificationAux.size();
        final byte VISIBLE_DEFAULT = ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_DEFAULT_INDEX];
        List<EvaluableItemStudent> auxStudentList;
        final List<StudentCalificationReport> myList = new ArrayList<StudentCalificationReport>();
        for (final Student mStudent : subjectCompetenceMembers) {
            // 1. Find the only calification for this student (if exists this calification)
            auxIdStudent = mStudent.getIdStudent();
            findCalification = false;
            counter = 0;
            while (!findCalification && counter < CALIFICATIONS_LENTGH) {
                auxCalification = mAssignmentsCalificationAux.get(counter);
                if (auxCalification.getStudentId() == auxIdStudent) {
                    findCalification = true;
                }
                counter++;
            }
            auxStudentList = new ArrayList<EvaluableItemStudent>();
            // 2. Find all possible evaluable item - student
            for (final EvaluableItemStudent currentEvalItemStudent : mEvaluableItemStudentAux) {
                if (currentEvalItemStudent.getIdStudent() == auxIdStudent) {
                    auxStudentList.add(currentEvalItemStudent);
                }
            }

            myList.add(new StudentCalificationReport(
                    mStudent, findCalification ? auxCalification : new Calification(
                    assignmentId, mStudent.getIdStudent(), 0,
                    "", "", VISIBLE_DEFAULT,
                    VISIBLE_DEFAULT), auxStudentList));
        }
        return myList;
    }
}