package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Assignment;
import classcontrol.entity.Calification;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluableItemStudentCalification;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.Student;
import classcontrol.entity.StudentCalificationReport;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class AssignmentUtil {

    private final HttpServletRequest request;
    //private static Persistence myPersistence;//Bad performance.

    private AssignmentUtil() {
        this.request = null;
        //myPersistence = new Persistence();
    }

    /**
     *
     * @param request Incoming request.
     */
    public AssignmentUtil(final HttpServletRequest request) {
        this.request = request;
        //myPersistence = new Persistence();
    }

    /**
     *
     * @return Selected assignment id.
     * @throws ControllerException If there is not any assignment selected as
     * parameter.
     */
    public int getSelectedAssignmentId() throws ControllerException {
        try {
            return Integer.parseInt(request.getParameter(Constants.PARAMETER_ASSIGNMENT_SELECTED));
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
    }

    /**
     *
     * @param selectedAssignmentId
     * @param edmodoGroup
     * @param teacherIdSC
     * @param titleSC
     * @return
     * @throws ControllerException
     */
    public Assignment getSelectedAssignmentAllData(final int selectedAssignmentId, final String edmodoGroup, final int teacherIdSC, final String titleSC) throws ControllerException {
        final List<EvaluationPeriodAssignment> evaluationPeriodAssigments = this.getAllAssignmentsEvaluationperiod(edmodoGroup, teacherIdSC, titleSC, false);
        Assignment assignment = null;
        if (evaluationPeriodAssigments != null) {
            final int EVALUATION_PERIODS_SIZE = evaluationPeriodAssigments.size();
            boolean find = false;
            int counter = 0;
            int counterAux;
            Assignment auxAssignment;
            List<Assignment> auxList;
            int assignmentsSize;
            while (!find && counter < EVALUATION_PERIODS_SIZE) {
                auxList = evaluationPeriodAssigments.get(counter).getMyAssignmentsList();
                assignmentsSize = auxList.size();
                counterAux = 0;
                while (!find && counterAux < assignmentsSize) {
                    auxAssignment = auxList.get(counterAux);
                    if (auxAssignment.getIdAssignment() == selectedAssignmentId) {
                        assignment = auxAssignment;
                        find = true;
                    }
                    counterAux++;
                }
                counter++;
            }
        }
        return assignment;
    }

    /**
     * Gets all specific subject competence's assignments classified by subject
     * competence's evaluation periods.<br/>
     *
     * BE CAREFUL, if one assignment is repeated, it will only appear once.
     *
     * @param edmodoGroup
     * @param teacherIdSC
     * @param titleSC
     * @param setAttribute True if this method should set the list in a request
     * attribute. False otherwise.
     * @return All specific subject competence's assignments classified by
     * evaluation periods
     */
    public ArrayList<EvaluationPeriodAssignment> getAllAssignmentsEvaluationperiod(final String edmodoGroup, final int teacherIdSC, final String titleSC, final boolean setAttribute) {
        // 1. Get Database's assignments and create two lists: drades and assignments.
        byte type;
        final List<Assignment> myBDAssignments = new ArrayList<Assignment>();
        final List<Assignment> myBDGrades = new ArrayList<Assignment>();
        final List<Assignment> myBDAssignmentsGrades = new Persistence().getAssignments(teacherIdSC, titleSC);
        for (final Assignment currentAssignment : myBDAssignmentsGrades) {
            type = currentAssignment.getType();
            if (type == ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_INDEX]
                    || type == ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_INDEX]) {
                myBDGrades.add(currentAssignment);
            } else {
                myBDAssignments.add(currentAssignment);
            }
        }
        myBDAssignmentsGrades.clear();

        // 2. Get Edmodo's assignments (grades and assignments)
        // 2.1. Grades
        final String gradesSetByAppForGroup = EdmodoAPI.gradesSetByAppForGroup(edmodoGroup);
        // Simulated
        final List<String[]> simulatedGradesSetByAppForGroup = new ArrayList<String[]>();

        // Comprobado que lo devuelve Edmodo 20/04/14: gradesSetByAppForGroup (ojo que un grupo puede tener varias asiganturas, por eso se compara con la base de datos)
        if (titleSC.compareTo("Inglés de 4º") == 0) {
            simulatedGradesSetByAppForGroup.add(new String[]{"other1", "Súper prueba", "10"});
            simulatedGradesSetByAppForGroup.add(new String[]{"other2", "Examen sorpresa", "10"});
            simulatedGradesSetByAppForGroup.add(new String[]{"other4", "Examen de palabras", "10"});
        } else {
            if (titleSC.compareTo("Mates de 2º") == 0) {
                simulatedGradesSetByAppForGroup.add(new String[]{"other6", "Primera evaluación", "10"});
                simulatedGradesSetByAppForGroup.add(new String[]{"other7", "Examen final", "10"});
                simulatedGradesSetByAppForGroup.add(new String[]{"other8", "Prueba de conocimientos", "10"});

            } else {
                if (titleSC.compareTo("POIS") == 0) {
                    simulatedGradesSetByAppForGroup.add(new String[]{"other10", "Trabajo optativo", "10"});
                    simulatedGradesSetByAppForGroup.add(new String[]{"other11", "Pruebas de acceso", "10"});
                    simulatedGradesSetByAppForGroup.add(new String[]{"other12", "Dictado", "10"});
                }
            }
        }
        // End-Simulated
        // 2.1.1 Compare if exist and if its data has changed.
        for (final Assignment myDBGrade : myBDGrades) {
            // TODO version 0.2-BETA
            // TODO: check if exists and if its data has changed.
            // if(allOk){
            for (final String[] currentSimulated : simulatedGradesSetByAppForGroup) {
                if (currentSimulated[0].compareTo(myDBGrade.getEdmodoId()) == 0) {
                    myDBGrade.setTitle(currentSimulated[1]);
                    myDBGrade.setMaxGrade(Integer.parseInt(currentSimulated[2]));
                    myBDAssignmentsGrades.add(myDBGrade);
                }//}else{Update or delete
            }
        }

        // 2.2. Assignments
        // Simulated
        // Comprobado que lo devuelve Edmodo 20/04/14:assignmentsByAppForUser(profesorEdmodoId)
        final List<String[]> simulatedAssignments = new ArrayList<String[]>();
        // Comprobado que lo devuelve Edmodo 20/04/14
        if (titleSC.compareTo("Inglés de 4º") == 0) {
            simulatedAssignments.add(new String[]{"other3", "Prueba ortográfica", "10", "Es una prueba de ortografía"});
        } else {
            if (titleSC.compareTo("Mates de 2º") == 0) {
                simulatedAssignments.add(new String[]{"other5", "Entrega de deberes del lunes", "10", "Es una entrega de deberes."});

            } else {
                if (titleSC.compareTo("POIS") == 0) {
                    simulatedAssignments.add(new String[]{"other9", "Explicación del tema", "10", "Los alumnos explican el tema"});
                }
            }
        }
        // End-Simulated
        String assignmentEdmodoId;
        String statusAssignment;
        for (final Assignment myDBAssignment : myBDAssignments) {
            assignmentEdmodoId = myDBAssignment.getEdmodoId();
            statusAssignment = EdmodoAPI.assignmentStatus(assignmentEdmodoId);
            // TODO: check if exists and if its data has changed.
            // if(allOk){
            for (final String[] currentSimulated : simulatedAssignments) {
                if (currentSimulated[0].compareTo(myDBAssignment.getEdmodoId()) == 0) {
                    myDBAssignment.setTitle(currentSimulated[1]);
                    myDBAssignment.setDescription(currentSimulated[3]);
                    myDBAssignment.setMaxGrade(Integer.parseInt(currentSimulated[2]));
                    myBDAssignmentsGrades.add(myDBAssignment);
                }//}else{Update or delete
            }
            //}else{Update or delete
        }
        // 1. All current subject competence's periods:
        // 2. All current subject competence's assignments:
        // 3. Current subject competence (start and end date, positive and negative aspects' weight and associated subject competence's weight).
        final ArrayList<EvaluationPeriodAssignment> myEvaluationPeriodsAssignments = new ArrayList<EvaluationPeriodAssignment>();
        // myBDAssignmentsGrades

        Date initialDateAux, finalDateAux, assignmentDateAux;
        int assignmentAuxId;
        ArrayList<Assignment> auxAssignmentsPeriod;
        final ArrayList<Integer> assignmentsAdded = new ArrayList<Integer>();
        final List<EvaluationPeriod> evaluationperiodsList = new Persistence().getEvaluationPeriodsSubjectCompetence(teacherIdSC, titleSC);
        for (final EvaluationPeriod myEvaluationPeriod : evaluationperiodsList) {
            auxAssignmentsPeriod = new ArrayList<Assignment>();
            initialDateAux = myEvaluationPeriod.getInitialDate();
            finalDateAux = myEvaluationPeriod.getFinalDate();
            for (final Assignment myAssignment : myBDAssignmentsGrades) {
                assignmentDateAux = myAssignment.getDate();
                assignmentAuxId = myAssignment.getIdAssignment();
                if (!assignmentsAdded.contains(assignmentAuxId) && assignmentDateAux.compareTo(initialDateAux) >= 0 && assignmentDateAux.compareTo(finalDateAux) <= 0) {
                    auxAssignmentsPeriod.add(myAssignment);
                    assignmentsAdded.add(assignmentAuxId);
                }
            }
            myEvaluationPeriodsAssignments.add(new EvaluationPeriodAssignment(myEvaluationPeriod, auxAssignmentsPeriod));
        }
        if (setAttribute) {
            request.setAttribute(Constants.ATT_LIST_ASSIGNMENTS, myEvaluationPeriodsAssignments);
        }
        return myEvaluationPeriodsAssignments;
    }

    /**
     * Returns all possible assignment's califications for a specific
     * assignment. If some user has not a calification, a new calification with
     * defalt values is returned.
     * @param mData Subject competence's data.
     * @param assignmentId
     * @param edmodoGroupSC
     * @return
     */
    public List<StudentCalificationReport> getAssignmentCalifications(final EvaluableItemStudentCalification mData, final int assignmentId, final String edmodoGroupSC) {
        // All students
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        final String allStudents = EdmodoAPI.members(new String[]{edmodoGroupSC});
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // 1. Get all assignment's user's califications.
        boolean findCalification;
        int auxIdStudent;
        int counter;
        Calification auxCalification = null;

        // 2. Get subject competence's data
        // BE CAREFULL, DO NOT REMOVE LIST ITEMS, IT IS BETTER ADD ITEMS IN LOCAL VARIABLES.
        final List<Calification> mAssignmentsCalification = mData.getCalifications();
        final List<Calification> mAssignmentsCalificationAux = new ArrayList<Calification>();
        for (final Calification current : mAssignmentsCalification) {
            if (current.getIdAssignment() == assignmentId) {
                mAssignmentsCalificationAux.add(current);
            }
        }
        final List<EvaluableItemStudent> mEvaluableItemStudent = mData.getEvaluableItemStudent();
        final List<EvaluableItemStudent> mEvaluableItemStudentAux = new ArrayList<EvaluableItemStudent>();
        for (final EvaluableItemStudent current : mEvaluableItemStudent) {
            if (current.getIdAssignment() == assignmentId) {
                mEvaluableItemStudentAux.add(current);
            }
        }

        // 3. Each student
        final int CALIFICATIONS_LENTGH = mAssignmentsCalificationAux.size();
        final byte VISIBLE_DEFAULT = ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_DEFAULT_INDEX];
        final List<Student> subjectCompetenceMembers = EdmodoAPI.getSimulatedStudents();
        List<EvaluableItemStudent> auxStudentList;
        final List<StudentCalificationReport> myList = new ArrayList<StudentCalificationReport>();
        for (final Student mStudent : subjectCompetenceMembers) {
            // 1. Find the only calification for this student (if exists this calification)
            auxIdStudent = mStudent.getIdStudent();
            findCalification = false;
            counter = 0;
            while (!findCalification && counter < CALIFICATIONS_LENTGH) {
                auxCalification = mAssignmentsCalificationAux.get(counter);
                if (auxCalification.getStudentId() == auxIdStudent) {
                    findCalification = true;
                }
                counter++;
            }
            auxStudentList = new ArrayList<EvaluableItemStudent>();
            // 2. Find all possible evaluable item - student
            for (final EvaluableItemStudent currentEvalItemStudent : mEvaluableItemStudentAux) {
                if (currentEvalItemStudent.getIdStudent() == auxIdStudent) {
                    auxStudentList.add(currentEvalItemStudent);
                }
            }



            myList.add(new StudentCalificationReport(
                    mStudent, findCalification ? auxCalification : new Calification(
                    assignmentId, mStudent.getIdStudent(), 0,
                    "", "", VISIBLE_DEFAULT,
                    VISIBLE_DEFAULT), auxStudentList));
        }
        return myList;
    }
}