package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.Persistence;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.utils.Constants;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletRequest;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class BehaviourAttitudeUtil {

    /**
     * Returns all subject competence behaviour attitude aspects list.
     * @param edmodoTeacherId Edmodo's teacher id.
     * @return all subject competence behaviour attitude aspects list.
     */
    public List<BehaviourAttitudeAspect> getBehaviourAttitudeAspectsEdmodo(final String edmodoTeacherId) {
        return new Persistence().getBAAspectsSubjectCompetence(edmodoTeacherId);
    }

    /**
     * Sets positive and negative behaviour attitude lists in request.
     *
     * @param idEdmodo
     * @param request
     */
    public void setRequestPositiveNegativeList(final String idEdmodo, final HttpServletRequest request) {
        final List<BehaviourAttitudeAspect> totalList = new BehaviourAttitudeUtil().getBehaviourAttitudeAspectsEdmodo(idEdmodo);
        // Positive aspects list
        final ArrayList<String> positiveList = new ArrayList<String>();
        // Negative aspects list
        final ArrayList<String> negativeList = new ArrayList<String>();
        byte currentType;
        String currentName;
        for (final BehaviourAttitudeAspect current : totalList) {
            currentType = current.getType();
            currentName = current.getName();
            if (currentType == ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX) {
                positiveList.add(currentName);
            } else {
                if (currentType == ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NEGATIVE_INDEX) {
                    negativeList.add(currentName);
                }
            }
        }
        // Send subject competence student's list.
        request.setAttribute(Constants.ATT_BEHAVIOUR_ATTITUDE_ASPECT_POSITIVE_LIST, positiveList);
        request.setAttribute(Constants.ATT_BEHAVIOUR_ATTITUDE_ASPECT_NEGATIVE_LIST, negativeList);
    }
}