package classcontrol.controller;

import classcontrol.utils.Constants;

/**
 * Front IController: Used by FrontIController servlet to instantiate the
 * appropriate {@link IController} class according to the incoming request.
 *
 * Attention: If controllers java class names changes, class's methods must be
 * changed too.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class ControllerFactory {

    /**
     * Returns controller Java fully qualified class name.
     *
     * Attention: If controllers java class names changes, this must be changed
     * too.
     *
     * @param id Controller id of {@link Constants}
     * @return Controller Java fully qualified class name.
     * @throws ControllerFactoryException If id not exists.
     */
    public static String getControllerByIdForm(final int id)
            throws ControllerFactoryException {
        final StringBuilder dev = new StringBuilder("classcontrol.controller.");
        switch (id) {
            case Constants.CONTROLLER_ID_CHANGE_LANGUAGE:
                dev.append("ChangeLanguage");
                break;
            case Constants.CONTROLLER_ID_SELECT_SUBJECT_COMPETENCE:
                dev.append("SelectSubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_VIEW_SUBJECT_COMPETENCE:
                dev.append("ViewSubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_CREATE_SUBJECT_COMPETENCE:
                dev.append("CreateSubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_CREATE_SUBJECT_COMPETENCE_2:
                dev.append("CreateSubjectCompetence2");
                break;
            case Constants.CONTROLLER_ID_CREATE_SUBJECT_COMPETENCE_3:
                dev.append("CreateSubjectCompetence3");
                break;
            case Constants.CONTROLLER_ID_DELETE_SUBJECT_COMPETENCE:
                dev.append("DeleteSubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_DELETE_SUBJECT_COMPETENCE_2:
                dev.append("DeleteSubjectCompetence2");
                break;
            case Constants.CONTROLLER_ID_SUBJECT_COMPETENCE:
                dev.append("SubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_MODIFY_SUBJECT_COMPETENCE:
                dev.append("ModifySubjectCompetence");
                break;
            case Constants.CONTROLLER_ID_MODIFY_SUBJECT_COMPETENCE_2:
                dev.append("ModifySubjectCompetence2");
                break;
            case Constants.CONTROLLER_ID_MODIFY_SUBJECT_COMPETENCE_3:
                dev.append("ModifySubjectCompetence3");
                break;
            case Constants.CONTROLLER_ID_DEFINE_ACADEMIC_DAYS:
                dev.append("DefineAcademicDays");
                break;
            case Constants.CONTROLLER_ID_DEFINE_ACADEMIC_DAYS_2:
                dev.append("DefineAcademicDays2");
                break;
            case Constants.CONTROLLER_ID_ABSENCE:
                dev.append("AbsenceAspectStudent");
                break;
            case Constants.CONTROLLER_ID_ABSENCE_2:
                dev.append("AbsenceStudent2");
                break;
            case Constants.CONTROLLER_ID_ABSENCE_3:
                dev.append("AbsenceStudent3");
                break;
            case Constants.CONTROLLER_ID_CREATE_ASPECT_B_A:
                dev.append("NewAspect");
                break;
            case Constants.CONTROLLER_ID_CREATE_ASPECT_B_A_2:
                dev.append("NewAspect2");
                break;
            case Constants.CONTROLLER_ID_ASPECT_STUDENT:
                dev.append("AbsenceAspectStudent");
                break;
            case Constants.CONTROLLER_ID_ASPECT_STUDENT_2:
                dev.append("AspectStudent2");
                break;
            case Constants.CONTROLLER_ID_ASPECT_STUDENT_3:
                dev.append("AspectStudent3");
                break;
            case Constants.CONTROLLER_ID_SELECT_ASSIGNMENT:
                dev.append("SelectAssignment");
                break;
            case Constants.CONTROLLER_ID_VIEW_ASSIGNMENT:
                dev.append("ViewAssignment");
                break;
            case Constants.CONTROLLER_ID_ATTEND_REPORT:
                dev.append("AttendReport");
                break;
            case Constants.CONTROLLER_ID_BEHAVIOUR_ATTITUDE_REPORT:
                dev.append("BehaviourAttitudeReport");
                break;
            case Constants.CONTROLLER_ID_EVALUATION_REPORT:
                dev.append("EvaluationReport");
                break;
            case Constants.CONTROLLER_ID_EVALUABLE_ITEM:
                dev.append("EvaluableItem");
                break;
            case Constants.CONTROLLER_ID_EVALUABLE_ITEM_2:
                dev.append("EvaluableItem2");
                break;
            case Constants.CONTROLLER_ID_TEACHER_ASPECTS:
                dev.append("TeacherAspects");
                break;
            case Constants.CONTROLLER_ID_MODIFY_ASPECT:
                dev.append("ModifyAspect");
                break;
            case Constants.CONTROLLER_ID_MODIFY_ASPECT_2:
                dev.append("ModifyAspect2");
                break;
            case Constants.CONTROLLER_ID_MODIFY_ASPECT_3:
                dev.append("ModifyAspect3");
                break;
            case Constants.CONTROLLER_ID_CREATE_ASSIGNMENT:
                dev.append("CreateAssignment");
                break;
            case Constants.CONTROLLER_ID_CREATE_ASSIGNMENT_2:
                dev.append("CreateAssignment2");
                break;
            case Constants.CONTROLLER_ID_EVALUATION_PERCENTAGE:
                dev.append("EvaluationPercentage");
                break;
            case Constants.CONTROLLER_ID_EVALUATION_PERCENTAGE_2:
                dev.append("EvaluationPercentage2");
                break;
            case Constants.CONTROLLER_ID_GENERATE_REPORTS:
                dev.append("GenerateReports");
                break;
            case Constants.CONTROLLER_ID_GENERATE_REPORTS_2:
                dev.append("GenerateReports2");
                break;
            case Constants.CONTROLLER_ID_CALIFICATE_ASSIGNMENT:
                dev.append("CalificateAssignment");
                break;
            case Constants.CONTROLLER_ID_EVALUATION_CALIFICATION:
                dev.append("EvaluationCalification");
                break;
            case Constants.CONTROLLER_ID_SIMULATED_CONTROLLER:
                dev.append("Simulated");
                break;
            case Constants.CONTROLLER_ID_PARENT_STUDENT:
                dev.append("ParentStudent");
                break;
            case Constants.CONTROLLER_ID_STUDENT_INDEX:
                dev.append("Student");
                break;

            default:
                throw new ControllerFactoryException("Unable to perform this action.");
        }
        return dev.append("Controller").toString();
    }
}