package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Assignment;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Date;
import javax.servlet.http.HttpSession;

/**
 *
 * Create subject / competence controller.<br/>
 * Sets initial and final dates in two request attributes.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public class CreateAssignment2Controller extends AbstractController {

    private String nextUrl = null;

    @Override
    public void execute() throws ControllerException {
        final HttpSession mySession = this.request.getSession();
        // Security
        final String idEdmodoUser = (String) mySession.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoUser == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int currentSC = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) mySession.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(currentSC);
        final String ERROR_MSG = CurrentLanguage.getString(Text.NO_VALID_ARGUMENT, this.request) + ": ";
        // 1. Get data:
        // 1.1. Title
        // No null
        // Min and max
        final String title = this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_TITLE);
        if (title == null || title.length() == 0 || title.length() > ConstantsDB.CREATE_ASSIGNMENT_TITLE_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_TITLE);
        }
        // 1.2. Date
        // No null // No before - after subject competence's initial and end dates.
        Date date;
        try {
            date = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DATE));
            if (date.before(mSubjectCompetence.getInitialDate())
                    || date.after(mSubjectCompetence.getFinalDate())) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_DATE);
        }
        // 1.3. Type
        // No null
        // Correct type
        byte type;
        final byte type1 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_INDEX];
        final byte type2 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_INDEX];
        final byte type3 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_ASSIGNMENT_INDEX];
        final byte type4 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_ASSIGNMENT_INDEX];
        try {
            type = Byte.parseByte(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_TYPE));
            if (type != type1 && type != type2 && type != type3 && type != type4) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_TYPE);
        }
        // 1.4. Maximum calification
        // No null
        // Min and max
        boolean showError = false;
        int calificationMax = ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION_MIN - 1;
        try {
            calificationMax = (int) Math.round(Double.parseDouble(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION)));
        } catch (final Exception ex) {
            showError = true;
        }
        if (showError || calificationMax < ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION_MIN || calificationMax > ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION);
        }
        // 1.5. Description
        String description = this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DESCRIPTION);
        int DES_SIZE;
        if (description != null) {
            DES_SIZE = description.length();
            description = DES_SIZE > ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX ? description.substring(0, DES_SIZE - ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX) : DES_SIZE == 0 ? null : description;
        }
        final String edmodoId = type == type1 || type == type2 ? EdmodoAPI.newGrade(title, calificationMax, idEdmodoUser)
                : type == type3 || type == type4 ? EdmodoAPI.createAssignment(title, description, date, calificationMax, idEdmodoUser) : null;
        final Persistence myPersistence = new Persistence();
        if (edmodoId != null) {
            myPersistence.insertAssignment(new Assignment(ConstantsDB.TABLE_NULL_ID,
                    title, description, type, edmodoId, calificationMax, ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MIN,
                    date, mSubjectCompetence.getTitle(), mSubjectCompetence.getTeacherId()));
        }
        // Set redirect url
        final String defineEvaluableItem = request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DEFINE_EVALUABLE_ITEMS);
        String evaluableItems = "/?" + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + currentSC + '&' + Constants.CONTROLLER_ID + '=';
        boolean evaluableItem = false;
        try {
            final boolean goEvaluableItem = Byte.parseByte(defineEvaluableItem)
                    == ConstantsForm.CREATE_ASSIGNMENT_DEFINE_EVALUABLE_ITEMS_YES;
            evaluableItems += goEvaluableItem
                    ? "" + Constants.CONTROLLER_ID_EVALUABLE_ITEM + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/Assignment/EvaluableItem.jsp" + '&' + Constants.PARAMETER_ASSIGNMENT_SELECTED + '=' + myPersistence.getAssignment(edmodoId).getIdAssignment() : "";
            evaluableItem = goEvaluableItem ? true : false;
        } catch (final Exception ex) {
        }
        if (!evaluableItem) {
            evaluableItems += "" + Constants.CONTROLLER_ID_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/AssignmentsSubjectCompetence.jsp";
        } else {
            nextUrl = evaluableItems;
        }
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, evaluableItems);
    }

    @Override
    public String getReturnPage() {
        final String url = request.getParameter(Constants.CONTROLLER_NEXT_URL);
        return nextUrl != null ? nextUrl : url == null ? HOME_URL : url;
    }
}