package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemUpdated;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.text.Collator;
import java.util.ArrayList;
import java.util.List;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;

/**
 * Creates, modifies or deletes all assignment's evaluable items.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class EvaluableItem2Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final int assignmentId = new AssignmentUtil(request).getSelectedAssignmentId();

        //final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) this.request.getSession().getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        // 1. Get all request's subject competence evaluable items.
        // Check total amount not exceed {@link ConstantsDB#TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT_MAX}
        // Check all evaluate item's name are different
        final String[] evaluableItemNames = request.getParameterValues(ConstantsForm.EVALUATE_ITEM_NAME);
        final String[] evaluableItemWeights = request.getParameterValues(ConstantsForm.EVALUATE_ITEM_WEIGHT);
        final String evaluableItemDeleted = request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DELETED_EVALUABLE_ITEMS);
        final ArrayList<String> evalItemsDeleted = new ArrayList<String>();
        // Check if some previous evaluable items were deleted.
        JSONArray mJson;
        try {
            mJson = new JSONArray(evaluableItemDeleted);
            final int evalItemsDeleted_1 = (mJson.length()) - 1;
            for (int i = evalItemsDeleted_1; i >= 0; i--) {
                evalItemsDeleted.add(mJson.getString(i));
            }
        } catch (final JSONException ex) {
            // No previous evaluable items were deleted
        }
        final Persistence mPersistence = new Persistence();
        final List<Integer> indexesToDelete = new ArrayList<Integer>();
        final List<EvaluableItem> oldEvaluableItems = mPersistence.getEvaluableItemsAssignment(assignmentId);
        final int OLD_ITEMS_SIZE = oldEvaluableItems.size();
        boolean find;
        int count;
        final Collator c = Collator.getInstance();
        c.setStrength(Collator.NO_DECOMPOSITION);
        EvaluableItem mEvaluableItemAux;
        for (final String deletedName : evalItemsDeleted) {
            find = false;
            count = 0;
            while (!find && count < OLD_ITEMS_SIZE) {
                mEvaluableItemAux = oldEvaluableItems.get(count);
                if (c.compare(deletedName, mEvaluableItemAux.getName()) == 0) {
                    indexesToDelete.add(0, count);
                }
                count++;
            }
        }
        for (final Integer index : indexesToDelete) {
            oldEvaluableItems.remove((int) index);
        }

        // Now we have old evaluable items that have not been deleted.
        // Let's update and add new ones if user has submit values:
        final ArrayList<EvaluableItemUpdated> myList = new ArrayList<EvaluableItemUpdated>();
        if (evaluableItemNames != null && evaluableItemWeights != null) {
            // Number of old evaluable items alive and must be update
            final int OLD_EVALUABLE_ITEM_SIZE = oldEvaluableItems.size();
            // EVALUABLE_ITEM_SIZE will be the total evaluable items
            final int EVALUABLE_ITEM_SIZE = evaluableItemNames.length;
            int counter = 0;
            int counterLocal;
            String aux;
            String trueName;
            int auxParsedWeight;
            int auxParsedWeightAmount = 0;
            int differenceCounter = OLD_EVALUABLE_ITEM_SIZE;
            while (counter < EVALUABLE_ITEM_SIZE) {
                trueName = evaluableItemNames[counter];
                aux = trueName.toLowerCase();
                if (aux.isEmpty()) {
                    throw new ControllerException(CurrentLanguage.getString(Text.NO_NULL, request));
                }
                counterLocal = 0;
                while (counterLocal != counter && counterLocal < EVALUABLE_ITEM_SIZE) {
                    if (c.compare(evaluableItemNames[counterLocal].toLowerCase(), aux) == 0) {
                        throw new ControllerException(CurrentLanguage.getString(Text.ASSIGNMENT_EVALUABLE_ITEM_NO_REPEAT, request));
                    }
                    counterLocal++;
                }
                auxParsedWeight = (int) Double.parseDouble(evaluableItemWeights[counter]);
                if (auxParsedWeight > ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT_MAX
                        || auxParsedWeight < ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT_MIN) {
                    throw new ControllerException(CurrentLanguage.getString(Text.NO_NULL, request));
                }
                auxParsedWeightAmount += auxParsedWeight;
                myList.add(new EvaluableItemUpdated(assignmentId,
                        trueName, auxParsedWeight, differenceCounter > 0 ? oldEvaluableItems.get(counter).getName()
                        : null));

                differenceCounter--;
                counter++;
            }
            if (auxParsedWeightAmount > ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT_MAX) {
                throw new ControllerException(CurrentLanguage.getString(Text.ASSIGNMENT_EVALUABLE_ITEM_AMOUNT, request));
            }

        }
        // 2. Save on database.
        mPersistence.updateEvaluableItems(assignmentId, myList, evalItemsDeleted);
        // Set redirect url
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_VIEW_ASSIGNMENT + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/Assignment/CalificateAssignment.jsp" + '&' + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + subjectCompetenceSelected + '&' + Constants.PARAMETER_ASSIGNMENT_SELECTED + '=' + assignmentId);
    }
}