package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.Assignment;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Subject competence evaluation percentage controller.<br/>
 *
 * Sets in session var teacher's subjects and competences list.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public class EvaluationPercentage2Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        // Security
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final SubjectCompetence currentSC = ((List<SubjectCompetence>) request.getSession().getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);

        // 1. Get data and validate it.
        // 1.1 Positive aspects
        final int eachPositiveValue = getInputWeight(ConstantsForm.EVALUATION_PERCENTAGE_EACH_POSITIVE);
        final int maxPositiveValue = getInputWeight(ConstantsForm.EVALUATION_PERCENTAGE_MAX_POSITIVE);
        if (eachPositiveValue > maxPositiveValue) {
            throw new ControllerException(CurrentLanguage.getString(Text.EVALUATION_PERCENTAGE_POSITIVE_ERROR, request));
        }

        // 1.2. Negative aspects
        final int eachNegativeValue = getInputWeight(ConstantsForm.EVALUATION_PERCENTAGE_EACH_NEGATIVE);
        final int maxNegativeValue = getInputWeight(ConstantsForm.EVALUATION_PERCENTAGE_MAX_NEGATIVE);
        if (eachNegativeValue > maxNegativeValue) {
            throw new ControllerException(CurrentLanguage.getString(Text.EVALUATION_PERCENTAGE_NEGATIVE_ERROR, request));
        }

        if (maxNegativeValue > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE_MAX) {
            throw new ControllerException(CurrentLanguage.getString(Text.EVALUATION_PERCENTAGE_MAX_NEGATIVE_ERROR, request));
        }

        // nPeriods
        // 1.3. Periods' weight
        final String titleSC = currentSC.getTitle();
        final List<EvaluationPeriodAssignment> list = new AssignmentUtil(request).getAllAssignmentsEvaluationperiod(currentSC.getEdmodoGroup(), currentSC.getTeacherId(), titleSC, true);
        final ArrayList<EvaluationPeriod> allEvaluationPeriods = new ArrayList<EvaluationPeriod>();
        final ArrayList<Assignment> allAssignments = new ArrayList<Assignment>();
        final int nPeriods = list.size();
        // 1.5. Periods' assignments weight
        final String periodsWeight = ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS_WEIGHT;
        final String assignmentScore = ConstantsForm.EVALUATION_PERCENTAGE_ASSIGNMENT_SCORE;
        int evaluationPeriodsWeight = 0;
        int nAssignmentsAux;
        int assignmentsWeightAux;
        int auxPeriodNumber;
        Assignment auxAssignment;
        EvaluationPeriod myEvaluationPeriod;
        List<Assignment> assignmentsEvaluationPeriodAux;
        int auxWeight;
        for (int i = 0; i < nPeriods; i++) {
            auxPeriodNumber = i + 1;
            assignmentsEvaluationPeriodAux = list.get(i).getMyAssignmentsList();
            nAssignmentsAux = assignmentsEvaluationPeriodAux.size();
            assignmentsWeightAux = 0;
            for (int j = 0; j < nAssignmentsAux; j++) {
                auxWeight = getInputWeight(assignmentScore + auxPeriodNumber + "" + (j + 1));
                assignmentsWeightAux += auxWeight;
                auxAssignment = assignmentsEvaluationPeriodAux.get(j);
                auxAssignment.setAssociatedWeight(auxWeight);
                allAssignments.add(auxAssignment);
            }
            if (assignmentsWeightAux > ConstantsForm.EVALUATION_PERCENTAGE_MAX_EVALUATION_PERIOD_ASSIGNMENTS_AMOUNT) {
                throw new ControllerException(CurrentLanguage.getString(Text.PERIOD, request) + " " + auxPeriodNumber + ": " + CurrentLanguage.getString(Text.EVALUATION_PERCENTAGE_ASSIGNMENTS_AMOUNT_ERROR, request) + " : " + assignmentsWeightAux + "%.");
            }
            auxWeight = getInputWeight(periodsWeight + auxPeriodNumber);
            myEvaluationPeriod = list.get(i).getMyEvaluationPeriod();
            myEvaluationPeriod.setPercentage(auxWeight);
            evaluationPeriodsWeight += auxWeight;
            allEvaluationPeriods.add(myEvaluationPeriod);
        }
        // Total evaluation amount.
        final int totalAmount = maxPositiveValue + evaluationPeriodsWeight;
        if (totalAmount > ConstantsForm.EVALUATION_PERCENTAGE_MAX_EVALUATION_AMOUNT) {
            throw new ControllerException(CurrentLanguage.getString(Text.CSC_TEACHER_TOTAL_WEIGHT_PERIODS, request) + ' ' + totalAmount + "%.");
        }

        // 2. Update subject competence
        // 3. Update all assignments
        currentSC.setEachPositiveWeigth(eachPositiveValue);
        currentSC.setMaxPositiveWeigth(maxPositiveValue);
        currentSC.setEachNegativeWeigth(eachNegativeValue);
        currentSC.setMaxNegativeWeigth(maxNegativeValue);
        final Persistence myPersistence = new Persistence();
        if (myPersistence.updateSubjectCompetence(titleSC, currentSC, allEvaluationPeriods)
                == Constants.NO_RESULT || myPersistence.updateAssignment(allAssignments) == Constants.NO_RESULT) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }

        // 4. Important refresh teacher's subject competences list
        new SubjectCompetenceUtil(this.request).setAllSubjectsCompetencesSession(false);
        // 5. Sets return web.
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/AssignmentsSubjectCompetence.jsp" + '&' + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + subjectCompetenceSelected);
    }

    private int getInputWeight(final String inputName) throws ControllerException {
        try {
            return (int) Math.round(Double.parseDouble(this.request.getParameter(inputName)));
        } catch (final Exception ex) {
            throw new ControllerException("Invalid " + inputName);
        }
    }
}