package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.Persistence;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Subject competence evaluation report controller.<br/>
 * Sets all assignments data into a request attribute.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public class EvaluationReportController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        // 1. Security
        final HttpSession session = this.request.getSession();
        final String idEdmodoUser = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoUser == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final SubjectCompetenceUtil scUtil = new SubjectCompetenceUtil(request);
        final int scIndex = scUtil.getSelectedSubjectCompetence();

        switch ((Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(scUtil.getSelectedSubjectCompetence());
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getEvaluationReport(mSubjectCompetence, request, scUtil, true, null, null, ConstantsDB.TABLE_NULL_ID));
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                final Student studentStudent = new StudentUtil(request).getAndSetAttributeStudent(idEdmodoUser);
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getEvaluationReport(((List<SubjectCompetence>) session.getAttribute(idEdmodoUser)).get(scIndex), request, scUtil,true, null, null, studentStudent.getIdStudent()));
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final Student student = new ParentUtil(request).getAndSetAttributeStudent();
                ParentUtil.checkChildren(student, idEdmodoUser);
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getEvaluationReport(((List<SubjectCompetence>) session.getAttribute(student.getIdEdmodo())).get(scIndex), request, scUtil, true, null, null, student.getIdStudent()));
                break;
        }
    }
}