package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.language.LanguageFactory;
import classcontrol.utils.Constants;
import javax.servlet.http.HttpSession;

/**
 *
 * If there is not a language id established in current session it gets current
 * user favourite language from database and set it as session var.<br/>
 * If no user was found it sets {@link LanguageFactory#ID_LANGUAGE_DEFAULT} as
 * language identificator in current session.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class LanguageController extends AbstractController {

    /**
     * Sets a language identificator in current session.<br/> It searches in
     * database, if no user was found it sets
     * {@link LanguageFactory#ID_LANGUAGE_DEFAULT} as language identificator in
     * current session.
     *
     * @throws ControllerException If any error appears.
     */
    @Override
    public void execute() throws ControllerException {
        final HttpSession mSession = request.getSession();
        // 1. Check if current session language exists.
        Integer languageSessionID = (Integer) mSession.getAttribute(Constants.SESSION_ID_LANGUAGE);
        // 1.1. Current session language exists.
        if (languageSessionID == null) {
            // 2.1. If an Edmodo user is logged search in database.
            final String edmodoUserID = (String) mSession.getAttribute(Constants.SESSION_ID_EDMODO_USER);
            final Byte edmodoUserRole = (Byte) mSession.getAttribute(Constants.SESSION_ID_WEB_ROLE);
            try {
                if (edmodoUserID != null && edmodoUserRole != null) {
                    languageSessionID = new Persistence().getLanguageUser(edmodoUserID, edmodoUserRole);
                }
            } catch (final IllegalArgumentException e) {
                e.printStackTrace();
            }
            languageSessionID = languageSessionID != null
                    && languageSessionID != Constants.NO_RESULT
                    ? languageSessionID
                    : LanguageFactory.ID_LANGUAGE_DEFAULT;
            mSession.setAttribute(Constants.SESSION_ID_LANGUAGE, languageSessionID);
        }
    }
}