package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Date;
import javax.servlet.http.HttpSession;

/**
 *
 * Modifies a teacher's subject competence and updates all teacher's subject
 * competences list.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class ModifySubjectCompetence3Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final String ERROR_MSG_BUSINESS = CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request);
        final SubjectCompetenceUtil myUtil = new SubjectCompetenceUtil(this.request);
        final int subjectCompetenceSelected = myUtil.getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final SubjectCompetence sc = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);
        final String oldTitle = sc.getTitle();
        final int teacherId = sc.getTeacherId();// Check fields (like Javascript, but now in server-side).
        final SubjectCompetence subjectCompetenceBefore = new Persistence().getSubjectCompetence(teacherId, oldTitle);
        if (teacherId == Constants.NO_RESULT || subjectCompetenceBefore == null || oldTitle == null) {
            throw new ControllerException(ERROR_MSG_BUSINESS);
        }
        // Check data:
        // 1. Title FORBIDEN
        //final String title = myUtil.getTitle(idEdmodoUser, oldTitle);
        // 2. Start and end dates
        final Date[] dates = myUtil.getDates(false);
        final Date startDate = dates[SubjectCompetenceUtil.START_DATE_INDEX];
        final Date endDate = dates[SubjectCompetenceUtil.END_DATE_INDEX];
        // 3. nPeriods
        final int nPeriods = myUtil.getPeriods();
        // 4 Description
        String description = myUtil.getDescription();
        // 5. Associated title
        final String assTitle = myUtil.getAssociatedTitle();
        // 6. Period's initial and final dates.
        final ArrayList<EvaluationPeriod> periodsList = myUtil.getEvaluationPeriodsList(nPeriods, startDate, endDate, oldTitle, teacherId);
        // 7. Subject / competences associatted weight
        //final int associatedWeight = myUtil.getassociatedSubjectCompetenceWeight();
        // 8. Check total weight = associated s/c + nPeriods weight
        //myUtil.checkTotalAmount(periodsList);
        // Set new data to update
        //subjectCompetenceBefore.setTitle(title);
        // EvaluationPeriods, recalculate:
        final Date oldStartDate = subjectCompetenceBefore.getInitialDate();
        final Date oldEndDate = subjectCompetenceBefore.getFinalDate();
        StringBuilder newNonAcademicDays = new StringBuilder(DatesUtil.getDatepickerDates(subjectCompetenceBefore.getNonAcademicDays()));

        if ((startDate.compareTo(oldStartDate) <= 0 && endDate.compareTo(oldStartDate) <= 0) || (startDate.compareTo(oldEndDate) >= 0 && endDate.compareTo(oldEndDate) >= 0)) {
            newNonAcademicDays = DatesUtil.getDatepickerDates(DatesUtil.getSaturdaySundaysBetweenTwoDates(startDate, endDate));
        } else {
            if (startDate.before(oldStartDate)) {
                final String newDates = DatesUtil.getDatepickerDates(DatesUtil.getSaturdaySundaysBetweenTwoDates(startDate, oldStartDate)).toString();
                newNonAcademicDays.append(newNonAcademicDays.length() == 0 || newDates.length() == 0 ? "" : ConstantsForm.MULTI_DATE_SEPARATOR).append(newDates);
            }
            if (oldEndDate.before(endDate)) {
                final String newDates = DatesUtil.getDatepickerDates(DatesUtil.getSaturdaySundaysBetweenTwoDates(oldEndDate, endDate)).toString();
                newNonAcademicDays.append(newNonAcademicDays.length() == 0 || newDates.length() == 0 ? "" : ConstantsForm.MULTI_DATE_SEPARATOR).append(newDates);
            }
        }
        subjectCompetenceBefore.setNonAcademicDays(DatesUtil.getDatabaseDates(newNonAcademicDays.toString()));
        subjectCompetenceBefore.setInitialDate(startDate);
        subjectCompetenceBefore.setFinalDate(endDate);
        subjectCompetenceBefore.setDescription(description);
        //subjectCompetenceBefore.setAssociatedWeight(associatedWeight);
        final boolean isAssociatedSubjectCompetence = assTitle != null ? true : false;
        subjectCompetenceBefore.setAssociatedTeacherId(isAssociatedSubjectCompetence ? teacherId : ConstantsDB.TABLE_NULL_ID);
        subjectCompetenceBefore.setAssociatedTitle(isAssociatedSubjectCompetence ? assTitle : null);

        if (new Persistence().updateSubjectCompetence(oldTitle, subjectCompetenceBefore, periodsList) == Constants.NO_RESULT) {
            throw new ControllerException(ERROR_MSG_BUSINESS);
        }
        // Important, reload teacher's subject competences list
        myUtil.setAllSubjectsCompetencesSession(true);
        this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_SELECT_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SelectSubjectCompetence.jsp");
    }
}