package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.entity.Student;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import javax.servlet.http.HttpSession;

/**
 *
 * Select subject competence controller.<br/>
 * Sets in session var teacher's subjects and competences list.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class SelectSubjectCompetenceController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        String idEdmodoStudent = idEdmodo;
        boolean findAndSetAttribute = false;
        switch ((Byte) request.getSession().getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                new SubjectCompetenceUtil(this.request).setAllSubjectsCompetencesSession(false);
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParentUtil = new ParentUtil(request);
                final Student student = mParentUtil.getAndSetAttributeStudent();
                mParentUtil.checkChildren(student, idEdmodo);
                idEdmodoStudent = student.getIdEdmodo();
                findAndSetAttribute = true;

                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                new StudentUtil(request).getAndSetAttributeStudent(idEdmodo);
                findAndSetAttribute = true;
                break;
        }
        if (findAndSetAttribute) {
            // BE CAREFULL, EACH STUDENT (OR PARENT'S STUDENT) WILL HAVE A SUBJECT COMPETENCE'S LIST IN CURRENT SESSION
            session.setAttribute(idEdmodoStudent, new Persistence().getInvolvedDataStudent(idEdmodoStudent));

        }
    }
}