package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class StudentUtil {

    private final HttpServletRequest request;

    private StudentUtil() {
        this.request = null;
    }

    /**
     *
     * @param request Incoming request.
     */
    public StudentUtil(final HttpServletRequest request) {
        this.request = request;
    }

    /**
     * Returns a student given a Edmodo student id.
     *
     * @param edmodoStudentId Student Edmodo id to get data.
     * @return Studen's data.
     */
    protected static Student getSelectedStudent(final String edmodoStudentId) {
        final String studentJSON = EdmodoAPI.users(new String[]{edmodoStudentId});
        return EdmodoAPI.usersSimulated(edmodoStudentId);
    }

    /**
     *
     * @param edmodoStudentId
     * @return
     * @throws ControllerException
     */
    public Student getAndSetAttributeStudent(final String edmodoStudentId) throws ControllerException {
        final Student student = getSelectedStudent(edmodoStudentId);
        request.setAttribute(Constants.ATT_STUDENT_DATA, student);
        return student;
    }

        /**
     * Sets null or all subjects competences in a session attribute. Besides set
     * the most previous subject competence initial date and latest subject competence final
     * date in session attributes.
     *
     */
    public void setAllSubjectsCompetencesSession(final String idEdmodoStudent) {
        final HttpSession session = this.request.getSession();
        Date initialDate = new Date();
        Date finalDate = new Date();
        final List<SubjectCompetence> mSCList = new Persistence().getInvolvedDataStudent(idEdmodoStudent);
        Date dateAux;
        for (final SubjectCompetence sc : mSCList) {
            dateAux = sc.getInitialDate();
            initialDate = initialDate.after(dateAux) ? dateAux : initialDate;
            dateAux = sc.getFinalDate();
            finalDate = finalDate.before(dateAux) ? dateAux : finalDate;
        }
        request.setAttribute(Constants.ATT_CREATE_INITIAL_DATE, initialDate);
        request.setAttribute(Constants.ATT_CREATE_FINAL_DATE, finalDate);
        session.setAttribute(idEdmodoStudent, mSCList);
    }
}