package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Assignment;
import classcontrol.entity.BonusPenalization;
import classcontrol.entity.Calification;
import classcontrol.entity.EvaluableItemStudentCalification;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.Student;
import classcontrol.entity.StudentCalificationReport;
import classcontrol.entity.StudentEvaluation;
import classcontrol.entity.StudentEvaluationPeriod;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class SubjectCompetenceUtil {

    private final HttpServletRequest request;
    private static String ERROR_MSG;

    private SubjectCompetenceUtil() {
        this.request = null;
    }

    /**
     *
     * @param request
     */
    public SubjectCompetenceUtil(final HttpServletRequest request) {
        this.request = request;
        ERROR_MSG = CurrentLanguage.getString(Text.NO_VALID_ARGUMENT, this.request) + ": ";
    }

    /**
     *
     * @return Selected subject competence index.
     * @throws ControllerException If there is not any subject competence
     * selected as parameter.
     */
    public int getSelectedSubjectCompetence() throws ControllerException {
        try {
            return Integer.parseInt(request.getParameter(Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED));
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
    }
    /**
     *
     */
    public final static byte EDMODO_GROUP_INDEX = 0;
    /**
     *
     */
    public final static byte EDMODO_GROUP_ID_INDEX = 1;

    /**
     *
     * @return [EDMODO_GROUP_INDEX]:edmodoGroup<br/>
     * [EDMODO_GROUP_ID_INDEX]:edmodoGroupId
     * @throws ControllerException
     */
    public String[] getEdmodoGroup() throws ControllerException {
        final String edmodoGroup = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_ED_GROUP);
        if (edmodoGroup == null || edmodoGroup.length() == 0) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_ED_GROUP);
        }
        String edmodoGroupId = "";
        boolean showError = false;
        try {
            edmodoGroupId = edmodoGroup.substring(edmodoGroup.indexOf(ConstantsForm.SEPARATOR) + ConstantsForm.SEPARATOR.length());

        } catch (final Exception e) {
            showError = true;
        }
        if (showError || edmodoGroupId.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_ED_GROUP_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_ED_GROUP);
        }
        return new String[]{edmodoGroup, edmodoGroupId};
    }

    /**
     *
     * @param idEdmodoUser
     * @param oldTitle If it is provided, check new and old names not are the
     * same.
     * @return
     * @throws ControllerException
     */
    public String getTitle(final String idEdmodoUser, final String oldTitle) throws ControllerException {
        final String title = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_TITLE);
        if (title == null || title.length() == 0 || title.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_TITLE);
        }
        if ((oldTitle == null || oldTitle.compareTo(title) != 0)
                && new Persistence().existSubjectCompetenceTeacher(idEdmodoUser, title)) {
            throw new ControllerException(CurrentLanguage.getString(Text.SUBJECT_COMPETENCE_REPEAT, request) + ": " + title + '.');
        }
        return title;
    }
    /**
     *
     */
    public final static byte START_DATE_INDEX = 0;
    /**
     *
     */
    public final static byte END_DATE_INDEX = 1;

    /**
     *
     * @return [START_DATE_INDEX]:startt date<br/>
     * [END_DATE_INDEX]:end date
     * @throws ControllerException
     */
    public Date[] getDates(final boolean isNew) throws ControllerException {
        Date startDate;
        try {
            startDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE));
            // Startate Correcto
            final Calendar initialCalendar = Calendar.getInstance();
            initialCalendar.setTime(startDate);

            final Calendar minCalendar = Calendar.getInstance();
            // BE CAREFULL, -1 comes from {@link ConstantsForm#MIN_DATE_PICKER}
            minCalendar.add(Calendar.YEAR, -1);
            // -2 DAY because of hour differences, it is -1 less than in .jsp
            minCalendar.add(Calendar.DAY_OF_YEAR, -2);

            if (isNew && initialCalendar.before(minCalendar)) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
        }
        Date endDate;
        try {
            endDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE));
            final Calendar finalCalendar = Calendar.getInstance();
            finalCalendar.setTime(endDate);
            final Calendar maxCalendar = Calendar.getInstance();
            // BE CAREFULL, +2 comes from {@link ConstantsForm#MAX_DATE_PICKER}
            maxCalendar.add(Calendar.YEAR, +2);
            // +1 DAY because of hour differences, it is +1 more than in .jsp
            maxCalendar.add(Calendar.DAY_OF_YEAR, +2);
            if (isNew && finalCalendar.after(maxCalendar)) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE);
        }
        if (startDate.after(endDate) || TimeUnit.DAYS.convert(Math.abs(startDate.getTime() - endDate.getTime()), TimeUnit.MILLISECONDS) > 1096) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
        }
        return new Date[]{startDate, endDate};
    }

    /**
     *
     * @return @throws ControllerException
     * @throws ControllerException
     */
    public int getPeriods() throws ControllerException {
        boolean showError = false;
        int nPeriods = ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS_MIN - 1;
        try {
            nPeriods = Integer.parseInt(this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS));
        } catch (final Exception ex) {
            showError = true;
        }
        if (showError || nPeriods < ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS_MIN || nPeriods > ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_PERIODS);
        }
        return nPeriods;
    }

    /**
     *
     * @return @throws ControllerException
     * @throws ControllerException
     */
    public String getDescription() throws ControllerException {
        String description = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_DESCRIPTION);
        int DES_SIZE;
        if (description != null) {
            DES_SIZE = description.length();
            description = DES_SIZE > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_DESCRIPTION_MAX ? description.substring(0, DES_SIZE - ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_DESCRIPTION_MAX) : description;
        } else {
            description = "";
        }
        return description;
    }

    /**
     *
     * @return null if is null or empty string.
     * @throws ControllerException
     */
    public String getAssociatedTitle() throws ControllerException {
        String assTitle = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_ASSOCIATED);
        if (assTitle != null) {
            assTitle = assTitle.trim();
            final int LENGTH = assTitle.length();
            if (LENGTH > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
                throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_ASSOCIATED);
            }
            if (LENGTH == 0) {
                assTitle = null;
            }
        }
        return assTitle;
    }

    /**
     *
     * @param nPeriods
     * @param startDate
     * @param endDate
     * @param title
     * @param idTeacher
     * @return
     * @throws ControllerException
     */
    public ArrayList<EvaluationPeriod> getEvaluationPeriodsList(final int nPeriods, final Date startDate, final Date endDate, final String title, final int idTeacher) throws ControllerException {
        boolean showError = false;
        final ArrayList<EvaluationPeriod> periodsList = new ArrayList<EvaluationPeriod>();
        final List<EvaluationPeriod> periodsListOld = new Persistence().getEvaluationPeriodsSubjectCompetence(idTeacher, title);
        final int OLD_PERIODS_SIZE = periodsListOld.size();
        Date initialDate, finalDate;
        String dateString;
        int current;
        try {
            for (int i = 0; i < nPeriods; i++) {
                current = i + 1;
                dateString = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE + current);
                initialDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(dateString);
                dateString = this.request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE + current);
                finalDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(dateString);
                if (initialDate.after(finalDate) || initialDate.before(startDate) || finalDate.after(endDate)) {
                    showError = true;
                    throw new Exception();
                }
                periodsList.add(new EvaluationPeriod(ConstantsDB.TABLE_ID_MIN, initialDate, finalDate,
                        i < OLD_PERIODS_SIZE ? periodsListOld.get(i).getPercentage()
                        : ConstantsDB.TABLE_EVALUATION_PERIOD_ATT_PERCENTAGE_DEF,
                        title, idTeacher));
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            showError = true;
        }
        if (showError) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE + " - " + ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE);
        }
        return periodsList;
    }

    /**
     * Sets null or all subjects competences in a session attribute. Besides set
     * the most previous subject competence initial date and latest subject
     * competence final date in session attributes.
     *
     * @param setNull If sets null the session attribute.
     */
    public void setAllSubjectsCompetencesSession(final boolean setNull) {
        final HttpSession session = this.request.getSession();
        Date initialDate = new Date();
        Date finalDate = new Date();
        final List<SubjectCompetence> mSCList = new Persistence().getSubjectsCompetences((String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER));
        Date dateAux;
        for (final SubjectCompetence sc : mSCList) {
            dateAux = sc.getInitialDate();
            initialDate = initialDate.after(dateAux) ? dateAux : initialDate;
            dateAux = sc.getFinalDate();
            finalDate = finalDate.before(dateAux) ? dateAux : finalDate;
        }
        request.setAttribute(Constants.ATT_CREATE_INITIAL_DATE, initialDate);
        request.setAttribute(Constants.ATT_CREATE_FINAL_DATE, finalDate);
        session.setAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES, setNull ? null : mSCList);
    }

    /**
     * Get full data for a subject competence evaluation report.
     *
     * @param scEdmodoGroup
     * @param scTeacherId
     * @param scTitle
     * @return List of paiss: student-all subject competence assignments'
     * califications
     */
    public final StudentEvaluationPeriod evaluationReport(final String scEdmodoGroup, final int scTeacherId, final String scTitle) {
        boolean findItem;
        int countBonusPenalization, countStudentCalification, totalAssignmentCalificationsAux, studentIdAux, assignmentIdAux;
        BonusPenalization mBonusPenalizationAux = null;
        List<Assignment> mAssignmentListAux;
        StudentCalificationReport mStudentCalificationReportAux = null;
        List<StudentCalificationReport> mAssignmentCalificationsAux;
        final AssignmentUtil mAssignmentUtil = new AssignmentUtil(request);
        final List<EvaluationPeriodAssignment> mEvaluationPeriodAssignmentList =
                mAssignmentUtil.getAllAssignmentsEvaluationperiod(scEdmodoGroup, scTeacherId, scTitle, false);
        final byte VISIBLE_DEFAULT = ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_DEFAULT_INDEX];
        final Persistence mPersistence = new Persistence();
        final List<BonusPenalization> mBonusPenalizationList = mPersistence.getBonusPenalizations(scTeacherId, scTitle);
        final EvaluableItemStudentCalification mData = mPersistence.getEvaluableItemStudentCalification(scTeacherId, scTitle);
        final int TOTAL_BONUS_PENALIZATION = mBonusPenalizationList.size();
        final List<StudentEvaluation> mStudentEvaluation = new ArrayList<StudentEvaluation>();
        final List<Student> mStudentList = EdmodoAPI.getSimulatedStudents();
        // BE CAREFULL NEVER USE ARRAYLIST.CLEAR()
        List<StudentCalificationReport> mStudentAssignmentsCalifications;
        for (final Student mStudent : mStudentList) {
            studentIdAux = mStudent.getIdStudent();
            mStudentAssignmentsCalifications = new ArrayList<StudentCalificationReport>();
            // 1. Each Evaluation Period
            for (final EvaluationPeriodAssignment mEvaluationPeriodAssignment : mEvaluationPeriodAssignmentList) {
                mAssignmentListAux = mEvaluationPeriodAssignment.getMyAssignmentsList();

                // 2. Each Evaluation Assignments' average
                for (final Assignment assignment : mAssignmentListAux) {
                    assignmentIdAux = assignment.getIdAssignment();
                    mAssignmentCalificationsAux = mAssignmentUtil.getAssignmentCalifications(mData, assignmentIdAux, scEdmodoGroup);
                    totalAssignmentCalificationsAux = mAssignmentCalificationsAux.size();
                    countStudentCalification = 0;
                    findItem = false;
                    // Find student calification
                    while (!findItem && countStudentCalification < totalAssignmentCalificationsAux) {
                        mStudentCalificationReportAux = mAssignmentCalificationsAux.get(countStudentCalification);

                        if (mStudentCalificationReportAux.getStudent().getIdStudent() == studentIdAux) {
                            findItem = true;
                        }
                        countStudentCalification++;
                    }
                    mStudentAssignmentsCalifications.add(findItem ? mStudentCalificationReportAux : new StudentCalificationReport(mStudent, new Calification(
                            assignmentIdAux, studentIdAux, 0,
                            "", "", VISIBLE_DEFAULT,
                            VISIBLE_DEFAULT), null));
                }
            }
            // 3. Bonus Penalization
            findItem = false;
            countBonusPenalization = 0;
            while (!findItem && countBonusPenalization < TOTAL_BONUS_PENALIZATION) {
                mBonusPenalizationAux = mBonusPenalizationList.get(countBonusPenalization);
                if (mBonusPenalizationAux.getIdStudent() == mStudent.getIdStudent()) {
                    findItem = true;
                }
                countBonusPenalization++;
            }
            mStudentEvaluation.add(new StudentEvaluation(mStudent, mStudentAssignmentsCalifications, !findItem ? new BonusPenalization(0, "", studentIdAux, scTitle, scTeacherId) : mBonusPenalizationAux, scTitle, scTeacherId));
        }
        return new StudentEvaluationPeriod(mStudentEvaluation, mEvaluationPeriodAssignmentList);
    }
}