package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Absence;
import classcontrol.entity.Assignment;
import classcontrol.entity.AttendReport;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.entity.BonusPenalization;
import classcontrol.entity.Calification;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.Student;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.StudentAspectReport;
import classcontrol.entity.StudentCalificationReport;
import classcontrol.entity.StudentEvaluation;
import classcontrol.entity.StudentEvaluationPeriod;
import classcontrol.entity.SubjectCompetence;
import classcontrol.entity.SubjectCompetenceEvaluation;
import classcontrol.utils.CalificationUtil;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class TableHtml {

    /**
     * Returns a HTML table with attend information. See parameters for more
     * details.
     *
     * @param sc
     * @param request
     * @param showID
     * @param initialDate
     * @param endDate
     * @param studentId If it is provided (must be greater tha
     * {@link ConstantsDB#TABLE_NULL_ID}, table returned will only contain data
     * for this student (if exists in table data).
     * @return
     * @throws ControllerException
     */
    public static StringBuilder getAttendReport(final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final Date initialDate, final Date endDate, final int studentId) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");

        List<Absence> myAbsences;
        final String edmodoGroup = sc.getEdmodoGroup();
        final String subjectCompetenceTitle = sc.getTitle();
        final Persistence myPersistence = new Persistence();
        final int teacherId = sc.getTeacherId();
        final List<EvaluationPeriod> evaluationperiodsList = myPersistence.getEvaluationPeriodsSubjectCompetence(teacherId, subjectCompetenceTitle);
        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriod evaluationPeriod : evaluationperiodsList) {
                if (evaluationPeriod.getInitialDate().before(initialDate) || evaluationPeriod.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);

                } else {
                    evaluationPeriodOldIndex.add(count + 1);//+1 due to humans count 1,2,3 and not 0,1,2...
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }

        final List<AttendReport> mReportData = new ArrayList<AttendReport>();
        // All students
        final String allStudents = EdmodoAPI.members(new String[]{edmodoGroup});
        // TODO parsear el groupData y sacar los alumnos:
//                final String[] studentList = new String[]{"Cristian Tejedor" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_1_EDMODO_TOKEN, "Raúl Rodríguez" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_2_EDMODO_TOKEN, "Irene García" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_3_EDMODO_TOKEN, "Elena García" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_4_EDMODO_TOKEN, "Teresa Lázaro" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_5_EDMODO_TOKEN, "Carlos Martínez" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_6_EDMODO_TOKEN, "Rosa Chacel" + ConstantsForm.SEPARATOR
//                    + EdmodoAPI.STUDENT_7_EDMODO_TOKEN};
        final List<Student> subjectCompetenceMembers = EdmodoAPI.getSimulatedStudents();
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList
        // All students absences (separate by evaluation periods)
        myAbsences = myPersistence.getAbsencesSubjectCompetence(teacherId, subjectCompetenceTitle);

        // 1. For each student
        ArrayList<Date> auxDatesList;
        ArrayList<Date> datesPeriod;
        List<List<Date>> totalEvaluationPeriods;
        int idStudentAux;
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        for (final Student currentMember : subjectCompetenceMembers) {
            idStudentAux = currentMember.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                totalEvaluationPeriods = new ArrayList<List<Date>>();
                for (final EvaluationPeriod evalPeriod : evaluationperiodsList) {
                    datesPeriod = new ArrayList<Date>();
                    // 1.1. Look for absences
                    for (final Absence myAbsence : myAbsences) {
                        // Has absences:
                        if (myAbsence.getStudentId() == currentMember.getIdStudent()) {
                            // 1.1.1 Get sorted absences list
                            auxDatesList = DatesUtil.getDatesFromDatePicker(DatesUtil.getDatepickerDates(myAbsence.getDates()).toString());
                            // 1.1.1.1 For each evaluation period look if there is a coincidence
                            for (final Date myDate : auxDatesList) {
                                if ((myDate.compareTo(evalPeriod.getInitialDate()) >= 0) && (myDate.compareTo(evalPeriod.getFinalDate()) <= 0)) {
                                    datesPeriod.add(myDate);
                                }
                            }
                        }
                    }
                    totalEvaluationPeriods.add(datesPeriod);
                }
                mReportData.add(new AttendReport(currentMember.getIdEdmodo(), currentMember.getFullName(), totalEvaluationPeriods));
            }
        }
        final int nPeriods = evaluationperiodsList.size();
        final SimpleDateFormat myAbsencesSDF = new SimpleDateFormat("dd/MM");
        EvaluationPeriod currentPeriod;

        final SimpleDateFormat myEvalPeriodsSDF = ConstantsForm.DATE_SIMPLE_DATE_FORMAT;
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);
        String dates;
        for (int i = 0; i < nPeriods; i++) {
            currentPeriod = evaluationperiodsList.get(i);
            dates = myEvalPeriodsSDF.format(currentPeriod.getInitialDate()) + ' ' + CurrentLanguage.getString(Text.TO, request) + ' ' + myEvalPeriodsSDF.format(currentPeriod.getFinalDate());
            htmlTableData.append("<th data-content=\"").
                    append(dates).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(periodText).append(" ").append(possibleRemove ? evaluationPeriodOldIndex.get(i) : i + 1).append(possibleRemove ? ": " + dates : "")
                    .append("</th>");
        }
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request)).append("</th></tr></thead><tbody>");

        int totalAbsencesCounter;
        for (final AttendReport mData : mReportData) {
            totalAbsencesCounter = 0;
            htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mData.getIdEdmodo() + "</td><td>" : "")
                    .append(mData.getStudentName()).append("</td>");
            List<Date> allDates;
            for (int i = 0; i < nPeriods; i++) {
                allDates = mData.getEvaluationPeriods().get(i);
                htmlTableData.append("<td>");
                for (final Date mDate : allDates) {
                    htmlTableData.append(myAbsencesSDF.format(mDate)).append(" ");
                    totalAbsencesCounter++;
                }
                htmlTableData.append("</td>");
            }

            htmlTableData.append("<td><b>").append(totalAbsencesCounter).append("</b></td></tr>");
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, nPeriods);
        return htmlTableData.append("</tbody></table>");
    }

    /**
     *
     * @param sc
     * @param request
     * @param showID
     * @param initialDate
     * @param endDate
     * @param studentId
     * @return
     * @throws ControllerException
     */
    public static StringBuilder getBehaviourAttitudeReport(final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final Date initialDate, final Date endDate, final int studentId) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        final Persistence myPersistence = new Persistence();
        final String scTitle = sc.getTitle();
        final int teacherId = sc.getTeacherId();
        final String teacherEmododSC = myPersistence.getIdEdmodoTeacher(teacherId);
        final List<EvaluationPeriod> evaluationperiodsList = myPersistence.getEvaluationPeriodsSubjectCompetence(teacherId, scTitle);
        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriod evaluationPeriod : evaluationperiodsList) {
                if (evaluationPeriod.getInitialDate().before(initialDate) || evaluationPeriod.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);

                } else {
                    evaluationPeriodOldIndex.add(count + 1);//+1 due to humans count 1,2,3 and not 0,1,2...
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }

        // All students
        final String allStudents = EdmodoAPI.members(new String[]{sc.getEdmodoGroup()});
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        // TODO parsear el groupData y sacar los alumnos:
        final List<Student> subjectCompetenceMembers = EdmodoAPI.getSimulatedStudents();
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList
        // TODO: se deja asi porque se parseará y se conseguirá un ArrayList

        // 1. For each student
        List<List<StudentAspect>> totalEvaluationPeriodsAspects;
        ArrayList<StudentAspect> studentAspectList;
        Date auxStudentAspectDate;
        final List<StudentAspect> subjectCompetenceAspectsApplied = myPersistence.getStudentAspectsSubjectCompetence(teacherEmododSC, scTitle);
        final List<StudentAspectReport> mReportData = new ArrayList<StudentAspectReport>();
        int idStudentAux;
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        for (final Student currentMember : subjectCompetenceMembers) {
            idStudentAux = currentMember.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                totalEvaluationPeriodsAspects = new ArrayList<List<StudentAspect>>();
                for (final EvaluationPeriod evalPeriod : evaluationperiodsList) {
                    studentAspectList = new ArrayList<StudentAspect>();
                    for (final StudentAspect currentAspect : subjectCompetenceAspectsApplied) {
                        // 1.1. Look for student applied aspect
                        if (currentAspect.getIdStudent() == currentMember.getIdStudent()) {
                            auxStudentAspectDate = currentAspect.getDate();
                            if ((auxStudentAspectDate.compareTo(evalPeriod.getInitialDate()) >= 0) && (auxStudentAspectDate.compareTo(evalPeriod.getFinalDate()) <= 0)) {
                                studentAspectList.add(currentAspect);
                            }
                        }
                    }
                    totalEvaluationPeriodsAspects.add(studentAspectList);
                }
                mReportData.add(new StudentAspectReport(currentMember.getIdEdmodo(), currentMember.getFullName(), totalEvaluationPeriodsAspects));
            }
        }
        final int nPeriods = evaluationperiodsList.size();
        EvaluationPeriod currentPeriod;
        final List<BehaviourAttitudeAspect> mySubjectCompetenceAspects = myPersistence.getBAAspectsSubjectCompetence(teacherEmododSC);
        final int SIZE_B_A_ASPECTS = mySubjectCompetenceAspects.size();
        final StringBuilder periodsNull = new StringBuilder();
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);
        final SimpleDateFormat myEvalPeriodsSDF = ConstantsForm.DATE_SIMPLE_DATE_FORMAT;
        String dates;
        for (int i = 0; i < nPeriods; i++) {
            currentPeriod = evaluationperiodsList.get(i);
            dates = myEvalPeriodsSDF.format(currentPeriod.getInitialDate()) + ' ' + CurrentLanguage.getString(Text.TO, request) + ' ' + myEvalPeriodsSDF.format(currentPeriod.getFinalDate());
            periodsNull.append("null,");
            htmlTableData.append("<th title=\"").append("\" data-content=\"")
                    .append(dates)
                    .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(periodText).append(" ").append(possibleRemove ? evaluationPeriodOldIndex.get(i) : i + 1).append(possibleRemove ? ": " + dates : "")
                    .append("</th>");
        }
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request))
                .append(" +</th><th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request))
                .append(" -</th></tr></thead><tbody>");
        int totalPositiveAspectsCounter;
        int totalNegativeAspectsCounter;
        int counter;
        boolean find;
        boolean isPositive;
        BehaviourAttitudeAspect aux;
        String currentName;
        for (final StudentAspectReport mData : mReportData) {
            totalNegativeAspectsCounter = 0;
            totalPositiveAspectsCounter = 0;
            htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mData.getIdEdmodo() + "</td><td>" : "")
                    .append(mData.getStudentName()).append("</td>");
            List<StudentAspect> myStudentAspects;
            for (int i = 0; i < nPeriods; i++) {
                myStudentAspects = mData.getEvaluationPeriods().get(i);
                htmlTableData.append("<td>");
                for (final StudentAspect mySA : myStudentAspects) {
                    counter = 0;
                    find = false;
                    while (!find && counter < SIZE_B_A_ASPECTS) {
                        aux = mySubjectCompetenceAspects.get(counter);
                        currentName = aux.getName();
                        if (currentName.compareTo(mySA.getName()) == 0) {
                            find = true;
                            isPositive = aux.getType() == ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX];
                            if (isPositive) {
                                totalPositiveAspectsCounter++;
                            } else {
                                totalNegativeAspectsCounter++;
                            }
                            htmlTableData.append("<span ").append(isPositive ? " class='positiveAspect'>+" : " class='negativeAspect'>-")
                                    .append(currentName).append(" </span>");
                        }
                        counter++;
                    }
                }
                htmlTableData.append("</td>");
            }
            htmlTableData.append("<td style=\"background-color:lightgreen\">").append(totalPositiveAspectsCounter).append("</td>")
                    .append("<td style=\"background-color:antiquewhite\">").append(totalNegativeAspectsCounter).append("</td></tr>");
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, evaluationperiodsList.size());
        final String EACH_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_EACH, request);
        final String MAX_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_MAX, request);
        request.setAttribute(Constants.ATT_BEHAVIOUR_ATTITUDE_ASPECTS_WEIGHT, "<div align=\"center\"><p style=\"text-align: center;\" id=\"" + ConstantsForm.ID_EXTRA_BEHAVIOUR_ATTITUDE_REPORT
                + "\"><b>" + CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_POSITIVE, request)
                + "</b>: " + ' ' + EACH_TEXT + " +"
                + sc.getEachPositiveWeigth() + "% " + MAX_TEXT
                + ' ' + sc.getMaxPositiveWeigth() + "% - <b>" + CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_NEGATIVE, request)
                + "</b>: " + EACH_TEXT + " -"
                + sc.getEachNegativeWeigth() + "% " + MAX_TEXT + ' ' + sc.getMaxNegativeWeigth() + "%.</p><div>");
        return htmlTableData.append("</tbody></table>");
    }

    /**
     *
     * @param assignmentId
     * @param sc
     * @param request
     * @param showID
     * @param studentId
     * @param roleRequest
     * @return
     * @throws ControllerException
     */
    public static StringBuilder getAssignmentCalifications(final int assignmentId, final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final int studentId, final byte roleRequest) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        final Persistence mPersistence = new Persistence();
        final String scEdmodoGroup = sc.getEdmodoGroup();
        final String scTitle = sc.getTitle();
        final int scTeacherId = sc.getTeacherId();
        final AssignmentUtil myUtil = new AssignmentUtil(request);
        request.setAttribute(Constants.ATT_CURRENT_ASSIGNMENT, myUtil.getSelectedAssignmentAllData(assignmentId, scEdmodoGroup, scTeacherId, scTitle));
        final List<EvaluableItem> mEvaluableItems = mPersistence.getEvaluableItemsAssignment(assignmentId);
        request.setAttribute(Constants.ATT_EVALUABLE_ITEM_LIST_ASSIGNMENT, mEvaluableItems);
        for (final EvaluableItem mEvaluableItem : mEvaluableItems) {
            htmlTableData.append("<th data-content=\"").append(mEvaluableItem.getName()).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(mEvaluableItem.getAssociatedWeight()).append(" %</th>");
        }
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_TH, request)).append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_BONUS_PENALIZATION_TH, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_EXTRA_TH, request)).append("</th><th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_REASON_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_FINAL_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_COMMENT_TH, request))
                .append("</th>");

        if (notStudent) {
            htmlTableData.append("<th data-content=\"").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_VISIBLE_PARENT_TH, request)).
                    append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(
                    CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_VISIBLE_PARENT_P_TH, request)).append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_VISIBLE_STUDENT_TH, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_VISIBLE_PARENT_S_TH, request))
                    .append("</th>");
        }
        htmlTableData.append("</tr></thead><tbody>");
        final double MAX_SCORE = EdmodoAPI.SIMULATED_MAX_SCORE;
        Student mAuxStudent;
        String studentNameAux;
        int sizeStudentNameAux;
        final List<StudentCalificationReport> mData = myUtil.getAssignmentCalifications(mPersistence.getEvaluableItemStudentCalification(scTeacherId, scTitle), assignmentId, scEdmodoGroup);
        List<EvaluableItemStudent> myEvaluableItemCalificationAux;
        EvaluableItemStudent evaluableItemStudentAux;
        boolean findEvaluableItem;
        int counter;
        Calification auxCalification;
        int auxEvaluableItemsStudentSize;
        double firstCalification;
        double bonusPenalization;
        double lastCalification;
        double calificationAux;
        String auxText;
        String visibilityParent;
        String visibilityStudent;
        final String VISIBILITY_YES = CurrentLanguage.getString(Text.CALIFICATION_VISIBLE_YES, request).toUpperCase();
        final String VISIBILITY_NO = CurrentLanguage.getString(Text.CALIFICATION_VISIBLE_NO, request).toUpperCase();
        final DecimalFormat df = ConstantsForm.appDecimalFormat();
        for (final StudentCalificationReport mStudentCalificationReport : mData) {
            mAuxStudent = mStudentCalificationReport.getStudent();
            if (notStudent || mAuxStudent.getIdStudent() == studentId) {
                studentNameAux = mAuxStudent.getFullName();
                studentNameAux = studentNameAux == null ? "" : studentNameAux;
                sizeStudentNameAux = studentNameAux.length();
                htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mAuxStudent.getIdEdmodo() + "</td><td>" : "")
                        .append(studentNameAux.substring(0, sizeStudentNameAux > Constants.MAX_NAME_NAV_BAR ? Constants.MAX_NAME_NAV_BAR : sizeStudentNameAux)).append("</td>");
                myEvaluableItemCalificationAux = mStudentCalificationReport.getMyEvaluableItemCalification();
                auxEvaluableItemsStudentSize = myEvaluableItemCalificationAux.size();
                firstCalification = 0;
                for (final EvaluableItem evaluableItem : mEvaluableItems) {
                    evaluableItemStudentAux = null;
                    findEvaluableItem = false;
                    counter = 0;
                    while (!findEvaluableItem && counter < auxEvaluableItemsStudentSize) {
                        evaluableItemStudentAux = myEvaluableItemCalificationAux.get(counter);
                        if (evaluableItemStudentAux != null && evaluableItemStudentAux.getName().compareTo(evaluableItem.getName()) == 0) {
                            findEvaluableItem = true;
                        }
                        counter++;
                    }
                    // Never nullpointer becasue of findEvaluableItem var
                    calificationAux = findEvaluableItem ? evaluableItemStudentAux.getScore() : 0;
                    htmlTableData.append("<td>").append(df.format(calificationAux)).append("</td>");
                    firstCalification += calificationAux * evaluableItem.getAssociatedWeight() * 0.01;
                }
                firstCalification = firstCalification > MAX_SCORE ? MAX_SCORE : firstCalification < 0 ? 0 : firstCalification;
                htmlTableData.append("<td>").append(df.format(firstCalification)).append("</td>");
                auxCalification = mStudentCalificationReport.getCalification();
                bonusPenalization = auxCalification.getBonusPenalization();
                auxText = auxCalification.getReasonBonusPenalization();
                htmlTableData.append("<td>").append(df.format(bonusPenalization)).append("</td><td>").append(auxText == null ? "" : auxText).append("</td>");
                lastCalification = firstCalification + bonusPenalization;
                lastCalification = lastCalification > MAX_SCORE ? MAX_SCORE : lastCalification < 0 ? 0 : lastCalification;
                visibilityParent = CalificationUtil.getVisibility(auxCalification.isVisibleParent(), request).toUpperCase();
                visibilityStudent = CalificationUtil.getVisibility(auxCalification.isVisibleStudent(), request).toUpperCase();
                auxText = auxCalification.getOptionalComment();
                htmlTableData.append("<td><b>").append(df.format(lastCalification)).
                        append("</b></td>");
                htmlTableData.append("<td>").append(auxText == null ? ""
                        : roleRequest == Constants.SESSION_ID_ROLE_TEACHER
                        || (roleRequest == Constants.SESSION_ID_ROLE_PARENT && visibilityParent.compareTo(VISIBILITY_YES) == 0)
                        || (roleRequest == Constants.SESSION_ID_ROLE_STUDENT && visibilityStudent.compareTo(VISIBILITY_YES) == 0)
                        ? auxText : "").append("</td>");
                if (notStudent) {
                    htmlTableData.append("<td>").append(visibilityParent).
                            append("</td><td>").append(visibilityStudent).append("</td>");
                }
                htmlTableData.append("</tr>");
            }
        }
        return htmlTableData.append("</tbody></table>");
    }

    /**
     *
     * @param sc
     * @param request
     * @param scUtil
     * @param showID
     * @param initialDate
     * @param endDate
     * @param studentId
     * @return
     * @throws ControllerException
     */
    public static StringBuilder getEvaluationReport(final SubjectCompetence sc, final HttpServletRequest request, final SubjectCompetenceUtil scUtil, final boolean showID, final Date initialDate, final Date endDate, final int studentId) throws ControllerException {
        // List students-assignment's data.

        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");

        final String scTitle = sc.getTitle();
        final int teacherId = sc.getTeacherId();
        final StudentEvaluationPeriod mData = scUtil.evaluationReport(sc.getEdmodoGroup(), teacherId, scTitle);

        // 2. Format data
        final DecimalFormat df = ConstantsForm.appDecimalFormat();
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);

        final List<EvaluationPeriodAssignment> evaluationPeriodAssignment = mData.getEvaluationPeriodAssignments();
        final List<EvaluationPeriodCalification> evaluationperiodsList = new ArrayList<EvaluationPeriodCalification>();

        List<Assignment> scAssignmentsAux;
        final List<AssignmentEvaluationPeriod> scAssignments = new ArrayList<AssignmentEvaluationPeriod>();
        EvaluationPeriod evaluationPeriodAux;
        for (final EvaluationPeriodAssignment current : evaluationPeriodAssignment) {
            evaluationPeriodAux = current.getMyEvaluationPeriod();
            evaluationperiodsList.add(new EvaluationPeriodCalification(evaluationPeriodAux, 0));
            scAssignmentsAux = current.getMyAssignmentsList();
            for (final Assignment assCurrent : scAssignmentsAux) {
                scAssignments.add(new AssignmentEvaluationPeriod(assCurrent, evaluationPeriodAux.getEvaluationPeriodId()));//
            }
        }

        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        //final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriodCalification evaluationPeriod : evaluationperiodsList) {
                evaluationPeriodAux = evaluationPeriod.mEvaluationPeriod;
                if (evaluationPeriodAux.getInitialDate().before(initialDate) || evaluationPeriodAux.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }

        final int SIZE_ASSIGNMENTS = scAssignments.size();
        int counter = 1;
        for (final EvaluationPeriodCalification current : evaluationperiodsList) {
            evaluationPeriodAux = current.mEvaluationPeriod;
            htmlTableData.append("<th title=\"").append(periodText).append(" ").append(counter).append("\" data-content=\"").append(ConstantsForm.DATE_SIMPLE_DATE_FORMAT.format(evaluationPeriodAux.getInitialDate()))
                    .append(' ').append(CurrentLanguage.getString(Text.TO, request)).append(' ').append(ConstantsForm.DATE_SIMPLE_DATE_FORMAT.format(evaluationPeriodAux.getFinalDate()))
                    .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(evaluationPeriodAux.getPercentage()).append(" %</th>");
            counter++;
        }
        final int SIZE_EVALUATION_PERIODS = evaluationperiodsList.size();

        final int MAX_POSITIVE = sc.getMaxPositiveWeigth();
        final int MAX_NEGATIVE = sc.getMaxNegativeWeigth();
        final int EACH_POSITIVE = sc.getEachPositiveWeigth();
        final int EACH_NEGATIVE = sc.getEachNegativeWeigth();
        final String EACH_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_EACH, request);
        htmlTableData.append("<th data-content=\"")
                .append(EACH_TEXT).append(": +").append(EACH_POSITIVE).append(" %")
                .append("\" title=\"").append(CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_POSITIVE, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(MAX_POSITIVE)
                .append(" % (+)</th><th data-content=\"")
                .append(EACH_TEXT).append(": -").append(sc.getEachNegativeWeigth()).append(" %")
                .append("\" title=\"").append(CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_NEGATIVE, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(MAX_NEGATIVE).append(" % (-)</th><th>")
                .append(CurrentLanguage.getString(Text.EVALUATION_INFORM_AVERAGE, request))
                .append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_BONUS_PENALIZATION_TH, request))
                .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                .append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_EXTRA_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_REASON_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.CALIFICATION_CALIFICATION_FINAL_TH, request))
                .append("</th></tr></thead><tbody>");
        BonusPenalization mBonusPenalizationAux;
        List<StudentCalificationReport> mStudentCalificationReport;
        Calification calification;
        List<EvaluableItemStudent> myEvaluableItemCalifications;
        Student auxStudent;
        double currentCalificationAux, finalCalificationAux,
                bonusPenalizationAux,
                averageEvaluableItems, maxGrade, evaluationPeriodWeight, positiveAspectsAux, negativeAspectsAux;
        AssignmentEvaluationPeriod auxAssignment;
        int idStudentAux, idAux, counterAssignment, evaluationPeriodIdAux;
        boolean find, findAssignment;
        Assignment mAssignment;
        // Max calification to show in the view
        final int NORMALIZE = ConstantsForm.NORMALIZE;
        final byte POSITIVE_ASPECT = ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX];
        // 3. Pase all data
        BehaviourAttitudeAspect aux;
        String currentName;
        final SubjectCompetenceEvaluation mDataSC = new Persistence().getEvaluationData(teacherId, scTitle);
        final List<EvaluableItem> mEvaluableItemsSC = mDataSC.getmEvaluableItemsSC();
        EvaluableItem mEvaluableItemAux;
        final List<StudentAspect> aspectsApplied = mDataSC.getAspectsApplied();
        final List<BehaviourAttitudeAspect> mySubjectCompetenceAspects = mDataSC.getMySubjectCompetenceAspects();
        final int SIZE_EVALUABLE_ITEMS = mEvaluableItemsSC.size();
        final int SIZE_B_A_ASPECTS = mySubjectCompetenceAspects.size();
        EvaluationPeriodCalification mEPCalificationAux;
        final List<StudentEvaluation> mStudentEvaluation = mData.getStudentEvaluationList();
        // 1. For each student
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        for (final StudentEvaluation mStudentEvaluationCurrent : mStudentEvaluation) {
            auxStudent = mStudentEvaluationCurrent.getStudent();
            idStudentAux = auxStudent.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                //System.out.println(auxStudent.getFullName());
                htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + auxStudent.getIdEdmodo() + "</td><td>" : "")
                        .append(auxStudent.getFullName()).append("</td>");
                mStudentCalificationReport = mStudentEvaluationCurrent.getStudentCalificationReport();
                // Clear possible evaluation period data:
                for (final EvaluationPeriodCalification current : evaluationperiodsList) {
                    current.calification = 0;
                }
                // 2. Each student's assignment
                for (final StudentCalificationReport mCurrent : mStudentCalificationReport) {
                    // 2.1. Average evaluable items + bonus penalization
                    calification = mCurrent.getCalification();
                    // Find assignment
                    findAssignment = false;
                    counterAssignment = 0;
                    while (!findAssignment && counterAssignment < SIZE_ASSIGNMENTS) {
                        auxAssignment = scAssignments.get(counterAssignment);
                        mAssignment = auxAssignment.assignment;
                        idAux = mAssignment.getIdAssignment();
                        if (idAux == calification.getIdAssignment()) {
                            maxGrade = mAssignment.getMaxGrade();
                            evaluationPeriodIdAux = auxAssignment.evaluationPeriodId;
                            findAssignment = true;
                            // List of all evaluable item's calfication of this assignment.
                            averageEvaluableItems = 0;
                            if (findAssignment) {
                                // Student's evaluable item califications
                                myEvaluableItemCalifications = mCurrent.getMyEvaluableItemCalification();
                                for (final EvaluableItemStudent mEvaluableItemStudent : myEvaluableItemCalifications) {
                                    find = false;
                                    counter = 0;
                                    // 1. Find EvaluableItems assignment's weight
                                    while (!find && counter < SIZE_EVALUABLE_ITEMS) {
                                        mEvaluableItemAux = mEvaluableItemsSC.get(counter);
                                        //System.out.println(mEvaluableItemAux);
                                        //System.out.println(" Comparo: " + mEvaluableItemStudent.getName() + " con: " + mEvaluableItemAux.getName() + " y " + mEvaluableItemStudent.getIdStudent() + " == " + studentId);
                                        if (mEvaluableItemStudent.getName().compareTo(mEvaluableItemAux.getName())
                                                == 0 && mEvaluableItemAux.getIdAssignment() == idAux) {
                                            //getAssociatedWeight()-->0 to 100
                                            averageEvaluableItems += mEvaluableItemAux.getAssociatedWeight() * 0.01 * mEvaluableItemStudent.getScore();
                                            // System.out.println("    Sumo item... " + averageEvaluableItems + "= " + mEvaluableItemAux.getAssociatedWeight() + "*0.01*" + mEvaluableItemStudent.getScore());
                                            find = true;
                                        }
                                        counter++;
                                    }
                                }
                            }
                            averageEvaluableItems += calification.getBonusPenalization();
                            // Final assignment's calification
                            averageEvaluableItems = averageEvaluableItems > maxGrade ? maxGrade : averageEvaluableItems;//htmlTableData.append("<td>").append(1).append("</td>");
                            // Normalize
                            averageEvaluableItems *= (NORMALIZE / maxGrade);
                            //System.out.println("EvaluableItems+Bonus: " + averageEvaluableItems);
                            // 2.2. Evaluation period calification's average, add the average calification to evaluation period
                            // Find evaluation period
                            find = false;
                            counter = 0;
                            while (!find && counter < SIZE_EVALUATION_PERIODS) {
                                mEPCalificationAux = evaluationperiodsList.get(counter);
                                evaluationPeriodAux = mEPCalificationAux.mEvaluationPeriod;
                                //System.out.println(" {}{} Empiezo: " + evaluationPeriodAux.getPercentage());
                                if (evaluationPeriodAux.getEvaluationPeriodId() == evaluationPeriodIdAux) {
                                    // Normalized
                                    mEPCalificationAux.calification += mAssignment.getAssociatedWeight() * 0.01 * averageEvaluableItems; //*0.01 == /100
                                    // System.out.println(" {}{} Periodo " + mEPCalificationAux.mEvaluationPeriod.getEvaluationPeriodId() + " Sumo calificación: " + mEPCalificationAux.calification + " = " + mAssignment.getAssociatedWeight() + "*0.01*" + averageEvaluableItems);
                                    find = true;
                                    for (final EvaluationPeriodCalification current : evaluationperiodsList) {
                                        //   System.out.println("  --Tengo " + current.mEvaluationPeriod.getEvaluationPeriodId() + "Total: " + current.calification);
                                    }
                                }
                                counter++;
                            }
                        }
                        counterAssignment++;
                    }
                }
                // Show Evaluation Period's calification
                // Average =
                evaluationPeriodWeight = 0;
                for (final EvaluationPeriodCalification current : evaluationperiodsList) {
                    // It is already normalized.
                    htmlTableData.append("<td>").append(df.format(current.calification)).append("</td>");
                    evaluationPeriodWeight += current.mEvaluationPeriod.getPercentage() * 0.01 * current.calification;
                }
                positiveAspectsAux = 0;
                negativeAspectsAux = 0;

                for (final StudentAspect mAspect : aspectsApplied) {
                    if (mAspect.getIdStudent() == idStudentAux) {
                        counter = 0;
                        find = false;
                        while (!find && counter < SIZE_B_A_ASPECTS) {
                            aux = mySubjectCompetenceAspects.get(counter);
                            currentName = aux.getName();
                            if (currentName.compareTo(mAspect.getName()) == 0) {
                                find = true;
                                if (aux.getType() == POSITIVE_ASPECT) {
                                    positiveAspectsAux++;
                                } else {
                                    negativeAspectsAux++;
                                }
                            }
                            counter++;
                        }
                    }
                }
                positiveAspectsAux *= EACH_POSITIVE;
                positiveAspectsAux = positiveAspectsAux > MAX_POSITIVE ? MAX_POSITIVE : positiveAspectsAux;
                // Normalize
                positiveAspectsAux = (positiveAspectsAux * NORMALIZE) / MAX_POSITIVE;

                htmlTableData.append("<td>").
                        append(df.format(positiveAspectsAux)).
                        append("</td><td>");
                negativeAspectsAux *= EACH_NEGATIVE;
                negativeAspectsAux = negativeAspectsAux > MAX_NEGATIVE ? MAX_NEGATIVE : negativeAspectsAux;
                // Normalize
                negativeAspectsAux = (negativeAspectsAux * NORMALIZE) / MAX_NEGATIVE;
                mBonusPenalizationAux = mStudentEvaluationCurrent.getBonusPenalization();
                bonusPenalizationAux = mBonusPenalizationAux.getScore();
                currentCalificationAux = evaluationPeriodWeight + (positiveAspectsAux * MAX_POSITIVE * 0.01) - (negativeAspectsAux * MAX_NEGATIVE * 0.01);
                finalCalificationAux = currentCalificationAux + bonusPenalizationAux;
                // Normalize
                finalCalificationAux = finalCalificationAux > NORMALIZE ? NORMALIZE : finalCalificationAux < 0 ? 0 : finalCalificationAux;
                htmlTableData.append(df.format(negativeAspectsAux))
                        .append("</td><td>")
                        .append(df.format(currentCalificationAux))// * 0.01 == /100 In JAVA /100 has problems
                        .append("</td><td>").append(df.format(bonusPenalizationAux)).append("</td><td>")
                        .append(mBonusPenalizationAux.getReason()).append("</td><td><b>")
                        .append(df.format(finalCalificationAux))
                        .append("</b></td></tr>");
            }
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, evaluationperiodsList.size());
        return htmlTableData.append("</tbody></table>");

    }

    private static final class EvaluationPeriodCalification {

        private EvaluationPeriod mEvaluationPeriod;
        private double calification;

        public EvaluationPeriodCalification(final EvaluationPeriod mEvaluationPeriod, final double calification) {
            this.mEvaluationPeriod = mEvaluationPeriod;
            this.calification = calification;
        }
    }

    private static class AssignmentEvaluationPeriod {

        private Assignment assignment;
        private int evaluationPeriodId;

        public AssignmentEvaluationPeriod(final Assignment assignment, final int evaluationPeriodId) {
            this.assignment = assignment;
            this.evaluationPeriodId = evaluationPeriodId;
        }
    }
}