package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.edmodo.EdmodoUtil;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * View subject / competence controller.<br/>
 * Sets in a request attribute subject/competence description.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class ViewAssignmentController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        final String idEdmodoUser = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoUser == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int scIndex = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        SubjectCompetence mSubjectCompetence = null;
        int possibleIdStudent = ConstantsDB.TABLE_NULL_ID;
        final byte roleUser = (Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE);
        switch (roleUser) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                mSubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(new SubjectCompetenceUtil(request).getSelectedSubjectCompetence());
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                final Student studentStudent = new StudentUtil(request).getAndSetAttributeStudent(idEdmodoUser);
                possibleIdStudent = studentStudent.getIdStudent();
                mSubjectCompetence = ((List<SubjectCompetence>) session.getAttribute(idEdmodoUser)).get(scIndex);
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParentUtil = new ParentUtil(request);
                final Student student = mParentUtil.getAndSetAttributeStudent();
                mParentUtil.checkChildren(student, idEdmodoUser);
                possibleIdStudent = student.getIdStudent();
                mSubjectCompetence = ((List<SubjectCompetence>) session.getAttribute(student.getIdEdmodo())).get(scIndex);
                break;
        }
        request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getAssignmentCalifications(new AssignmentUtil(request).getSelectedAssignmentId(), mSubjectCompetence, request, true, possibleIdStudent, roleUser, EdmodoUtil.getGroupStudents(mSubjectCompetence.getEdmodoGroup(), request, false)));
    }
}