package classcontrol.dao;

import classcontrol.controller.DatesUtil;
import classcontrol.entity.Absence;
import classcontrol.utils.Constants;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class AbsenceDAO {

    static List<Absence> getAbsencesSubjectCompetence(final int teacherIdSC, final String titleSC) throws IllegalArgumentException {
        if (teacherIdSC == ConstantsDB.TABLE_NULL_ID) {
            throw new IllegalArgumentException("No valid Edmodo id.");
        }
        final List<Absence> myAbsencesList = new ArrayList<Absence>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_DATE).append(',')
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID).
                    append(',').append(ConstantsDB.TABLE_ABSENCE_ATT_STUDENT_ID).append(" FROM ")
                    .append(ConstantsDB.VIEW_ABSENCE).append(" WHERE ").
                    append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID).append("=? AND ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE).append("=?")
                    .toString());
            ps.setInt(1, teacherIdSC);
            ps.setString(2, titleSC);
            ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                myAbsencesList.add(new Absence(rs.getString(ConstantsDB.TABLE_ABSENCE_ATT_DATE), rs.getInt(ConstantsDB.TABLE_ABSENCE_ATT_STUDENT_ID), rs.getInt(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID), titleSC));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAbsencesList;
        }
    }

    /**
     * Insert or updates if exists any absence for an user in database.
     *
     * @param idEdmodoStudent Absences owner.
     * @param idEdmodoSCTeacher Subject / competence owner .
     * @param titleSC Subject / competence title.
     * @param date Absence dates. If it is null or empty, removes all absences
     * and not insert any absence.
     * @see {@link DatesUtil#getDatepickerDates(java.lang.String)} to valid
     * format.
     * @return value higher than {@link Constants#NO_RESULT} if all ok, value
     * {@link Constants#NO_RESULT} otherwise.
     * @throws IllegalArgumentException If any error ocurrs: rollback is called.
     */
    static byte updateAbsencesStudent(final String idEdmodoStudent, final String idEdmodoSCTeacher, final String titleSC, final String date) {
        if (idEdmodoStudent == null) {
            throw new IllegalArgumentException("No valid Edmodo student id.");
        }
        if (idEdmodoSCTeacher == null) {
            throw new IllegalArgumentException("No valid subject competence Edmodo teacher id.");
        }
        if (titleSC == null) {
            throw new IllegalArgumentException("No valid subject competence title.");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            // Transaction
            con.setAutoCommit(false);
            // 1. Delete previous if exists
            // 1.1. idStudent and idSCTeacher
            final int idStudent = StudentDAO.getIdStudent(idEdmodoStudent);
            final int idSCTeacher = TeacherDAO.getIdTeacher(idEdmodoSCTeacher);
            // 1.2. Query
            ps = con.prepareStatement(new StringBuilder("DELETE FROM ")
                    .append(ConstantsDB.TABLE_NAME_ABSENCE).
                    append(" WHERE ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_STUDENT_ID).append("=? AND  ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID).append("=? AND  ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE).append("= ?;").toString());
            ps.setInt(1, idStudent);
            ps.setInt(2, idSCTeacher);
            ps.setString(3, titleSC);
            ps.executeUpdate();
            if (date != null && date.length() > 0) {
                // 2. Insert new
                ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                        .append(ConstantsDB.TABLE_NAME_ABSENCE).
                        append('(')
                        .append(ConstantsDB.TABLE_ABSENCE_ATT_STUDENT_ID).append(',')
                        .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID).append(',')
                        .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE).append(',')
                        .append(ConstantsDB.TABLE_ABSENCE_ATT_DATE).append(") VALUES (?,?,?,?);").toString());
                ps.setInt(1, idStudent);
                ps.setInt(2, idSCTeacher);
                ps.setString(3, titleSC);
                ps.setString(4, date);
                ps.executeUpdate();
            }
            // 3. Commit changes
            con.commit();
        } catch (final Exception ex) {
            con.rollback();
            result = Constants.NO_RESULT;
            //ex.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }
}