package classcontrol.dao;

import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.entity.StudentAspect;
import classcontrol.utils.Constants;
import java.sql.Connection;
import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class BehaviourAttitudeAspectDAO {

    /**
     * Return all subject competence's behaviour attitude aspects (associated
     * with teacher id).
     *
     * @param idEdmodoTeacher
     * @return
     * @throws IllegalArgumentException
     */
    // ALFAS
    static List<BehaviourAttitudeAspect> getBAAspectsSubjectCompetence(final String idEdmodoTeacher)
            throws IllegalArgumentException {
        if (idEdmodoTeacher == null) {
            throw new IllegalArgumentException("Invalid Edmodo id.");
        }
        final List<BehaviourAttitudeAspect> myBehaviourAttitudeAspectsList = new ArrayList<BehaviourAttitudeAspect>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.VIEW_BEHAVIOUR_ATTITUDE_ASPECT).
                    append(".* FROM ")
                    .append(ConstantsDB.VIEW_BEHAVIOUR_ATTITUDE_ASPECT)
                    .append(',').append(ConstantsDB.TABLE_NAME_TEACHER)
                    .append(" WHERE ").
                    append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).append("=? AND ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID).append('=').
                    append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER)
                    .toString());
            ps.setString(1, idEdmodoTeacher);
            ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                myBehaviourAttitudeAspectsList.add(new BehaviourAttitudeAspect(rs.getInt(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_EDMODO_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME), rs.getByte(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_DESCRIPTION), null));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myBehaviourAttitudeAspectsList;
        }
    }

    /**
     * Get data from a teacher's behaviour attitude aspect.
     *
     * @param idEdmodoTeacher
     * @param name
     * @return
     * @throws IllegalArgumentException
     */
    static BehaviourAttitudeAspect getBAAspect(final String idEdmodoTeacher, final String aspectName) throws IllegalArgumentException {
        if (idEdmodoTeacher == null) {
            throw new IllegalArgumentException("Invalid Edmodo id.");
        }
        if (aspectName == null) {
            throw new IllegalArgumentException("Invalid name.");
        }
        BehaviourAttitudeAspect myAbsence = null;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.VIEW_BEHAVIOUR_ATTITUDE_ASPECT).
                    append(".* FROM ")
                    .append(ConstantsDB.VIEW_BEHAVIOUR_ATTITUDE_ASPECT)
                    .append(',').append(ConstantsDB.TABLE_NAME_TEACHER)
                    .append(" WHERE ").
                    append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).append("=? AND ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID).append('=').
                    append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER).append(" AND ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME).append("=?")
                    .toString());
            ps.setString(1, idEdmodoTeacher);
            ps.setString(2, aspectName);
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                myAbsence = new BehaviourAttitudeAspect(rs.getInt(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_EDMODO_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME), rs.getByte(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_DESCRIPTION), null);
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAbsence;
        }
    }

    /**
     * Return all student's aspects applied in a subject competence.
     *
     * @param idEdmodoTeacher
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    //BETAS
    static List<StudentAspect> getStudentAspectsSubjectCompetence(final String idEdmodoTeacher, final String title) throws IllegalArgumentException {
        if (idEdmodoTeacher == null) {
            throw new IllegalArgumentException("Invalid teacher Edmodo id.");
        }
        if (title == null) {
            throw new IllegalArgumentException("Invalid title.");
        }
        final List<StudentAspect> myAspectsList = new ArrayList<StudentAspect>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT)
                    .append(".* FROM ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT).append(',')
                    .append(ConstantsDB.TABLE_NAME_TEACHER)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).append("=? AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append('=')
                    .append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER).append(" AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE).append("=?;")
                    .toString());
            ps.setString(1, idEdmodoTeacher);
            ps.setString(2, title);
            final ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                myAspectsList.add(new StudentAspect(
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME),
                        rs.getDate(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_DATE),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID)));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAspectsList;
        }
    }

    /**
     * Returns all student's behaviour attitude aspects applied in a subject
     * competence.
     *
     * @param idEdmodoTeacher
     * @param title
     * @param idEdmodoStudent
     * @return
     * @throws IllegalArgumentException
     */
    static List<StudentAspect> getBAAspectsSubjectCompetenceStudent(final String idEdmodoTeacher, final String title, final String idEdmodoStudent) throws IllegalArgumentException {
        if (idEdmodoTeacher == null) {
            throw new IllegalArgumentException("Invalid teacher Edmodo id.");
        }
        if (title == null) {
            throw new IllegalArgumentException("Invalid title.");
        }
        if (idEdmodoStudent == null) {
            throw new IllegalArgumentException("Invalid student Edmodo id.");
        }
        final List<StudentAspect> myAspectsList = new ArrayList<StudentAspect>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT)
                    .append(".* FROM ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT).append(',')
                    .append(ConstantsDB.TABLE_NAME_STUDENT).append(',')
                    .append(ConstantsDB.TABLE_NAME_TEACHER)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_NAME_TEACHER).append('.').append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).append("=? AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append('=')
                    .append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER).append(" AND ")
                    .append(ConstantsDB.TABLE_NAME_STUDENT).append('.').append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append("=? AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID).append('=')
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE).append("=?;")
                    .toString());
            ps.setString(1, idEdmodoTeacher);
            ps.setString(2, idEdmodoStudent);
            ps.setString(3, title);
            ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                myAspectsList.add(new StudentAspect(
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME),
                        rs.getDate(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_DATE),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID)));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAspectsList;
        }
    }

    /**
     * Insert a new behaviour attitude aspect.
     *
     * @throws IllegalArgumentException If any error ocurrs: rollback is called.
     */
    static byte insertBehaviourAttitudeAspect(final BehaviourAttitudeAspect myAspect) {
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                    .append(ConstantsDB.TABLE_NAME_BEHAVIOUR_ATTITUDE_ASPECT)
                    .append("(").append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME).append(',')
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_EDMODO_ID).append(',')
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE).append(',')
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_DESCRIPTION)
                    .append(") VALUES (?,?,?,?,?)").toString());
            ps.setInt(1, myAspect.getTeacherId());
            ps.setString(2, myAspect.getName());
            ps.setString(3, myAspect.getEdmodoId());
            ps.setByte(4, myAspect.getType());
            ps.setString(5, myAspect.getDescription());
            ps.executeUpdate();

        } catch (final Exception ex) {
            result = Constants.NO_RESULT;
            //ex.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }

    /**
     * Updates a behaviour attitude aspect name, description and type.
     *
     * @param myAspect
     * @return
     */
    static byte updateBehaviourAttitudeAspect(final BehaviourAttitudeAspect myAspect, final String oldName) {
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("UPDATE ")
                    .append(ConstantsDB.TABLE_NAME_BEHAVIOUR_ATTITUDE_ASPECT)
                    .append(" SET ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME).append("=?, ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_DESCRIPTION).append("=?, ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE).append("=? WHERE ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID).
                    append("=? AND ").append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME)
                    .append("=?").toString());
            ps.setString(1, myAspect.getName());
            ps.setString(2, myAspect.getDescription());
            ps.setByte(3, myAspect.getType());
            ps.setInt(4, myAspect.getTeacherId());
            ps.setString(5, oldName);
            ps.executeUpdate();
        } catch (final Exception ex) {
            result = Constants.NO_RESULT;
            ex.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }

    }

    /**
     *
     * @param idEdmodoStudent
     * @param idEdmodoSCTeacher
     * @param titleSC
     * @param aspectsList New aspects to apply.
     * @return
     */
    static byte updateAspectsStudent(final String idEdmodoStudent, final String idEdmodoSCTeacher,
            final String titleSC, final List<String> aspectsNameList,
            final boolean deletePrevious) {
        if (idEdmodoStudent == null) {
            throw new IllegalArgumentException("Invalid Edmodo student id.");
        }
        if (idEdmodoSCTeacher == null) {
            throw new IllegalArgumentException("Invalid subject competence Edmodo teacher id.");
        }
        if (titleSC == null) {
            throw new IllegalArgumentException("Invalid subject competence's title.");
        }
        if (aspectsNameList == null) {
            throw new IllegalArgumentException("Invalid aspect's names list.");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;//,ps2
        try {
            // Transaction
            con.setAutoCommit(false);
            // 1. Delete previous if exists
            final int studentId = StudentDAO.getIdStudent(idEdmodoStudent);
            final int teacherId = TeacherDAO.getIdTeacher(idEdmodoSCTeacher);
            // 2. Insert new aspects
            ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                    .append(ConstantsDB.TABLE_NAME_ASPECT_STUDENT).
                    append('(')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_DATE)
                    .append(") VALUES (?,?,?,?,?,?)").append(deletePrevious ? "" : " ON DUPLICATE KEY UPDATE " + ConstantsDB.TABLE_ASPECT_STUDENT_ATT_DATE + "=?").toString());
            final Date currentDate = new Date(Calendar.getInstance().getTimeInMillis());
            final StringBuilder possibleSB = new StringBuilder();
            for (final String aspect : aspectsNameList) {
                try {
                    possibleSB.append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME).append("!=? AND ");
                    ps.setInt(1, studentId);
                    ps.setInt(2, teacherId);
                    ps.setString(3, aspect);
                    ps.setInt(4, teacherId);
                    ps.setString(5, titleSC);
                    ps.setDate(6, currentDate);
                    if (!deletePrevious) {
                        ps.setDate(7, currentDate);
                    }
                    ps.executeUpdate();
                } catch (final Exception ex) {
                    // Forced error to no update row
                }
            }

            if (deletePrevious) {
                ps = con.prepareStatement(new StringBuilder("DELETE FROM ")
                        .append(ConstantsDB.TABLE_NAME_ASPECT_STUDENT).
                        append(" WHERE ").append(possibleSB)
                        .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID).append("=? AND  ")
                        .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append("=? AND ")
                        .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE).append("=?")
                        .toString());
                int count = 1;
                for (final String aspect : aspectsNameList) {
                    ps.setString(count, aspect);
                    count++;
                }
                ps.setInt(count, studentId);
                count++;
                ps.setInt(count, teacherId);
                count++;
                ps.setString(count, titleSC);
                ps.executeUpdate();
            }

            // 3. Commit changes
            con.commit();
        } catch (final Exception ex) {
            con.rollback();
            result = Constants.NO_RESULT;
            //System.out.println("errocarco");
            //ex.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }
}