package classcontrol.dao;

import java.sql.*;
import javax.sql.DataSource;
import org.apache.commons.dbcp.BasicDataSource;

/**
 * Database connection pool. Creates an only point to communicate with Class
 * Control database.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
final class ConnectionPool {

    /**
     * Connection pool.
     */
    private static ConnectionPool pool;
    /**
     * Datasource.
     */
    private static DataSource dataSource;

    /**
     * Private constructor.
     */
    private ConnectionPool() {
        try {
            dataSource = ClassControlDataSource.getDataBase();
        } catch (final Exception e) {
        }

    }

    /**
     * Initialize a Class Control database connection pool.
     *
     * @return Class Control database connection pool.
     */
    public static ConnectionPool getInstance() {
        if (pool == null) {
            pool = new ConnectionPool();
        }
        return pool;
    }

    public Connection getConnection() {
        try {
            return dataSource.getConnection();
        } catch (final SQLException sqle) {
            return null;
        }
    }

    /**
     * Closes Class Control database connection pool.
     *
     * @param c Connection to close.
     */
    public final void freeConnection(final Connection c) {
        try {
            c.close();
        } catch (final SQLException sqle) {
        }
    }

    /**
     * Class Control database settings. There is only one Class Control
     * database.
     */
    private static final class ClassControlDataSource {

        /**
         * Get the Class Control data base link.
         *
         * @return Configured Class Control data base link.
         *
         */
        static BasicDataSource getDataBase() throws SQLException {
            final BasicDataSource basicDataSource = new BasicDataSource();
            basicDataSource.setUrl("jdbc:mysql://eu-cdbr-west-01.cleardb.com:3306/heroku_c03e670d5e2f9b7?reconnect=true");
            basicDataSource.setUsername("b1c61017e08f00");
            basicDataSource.setPassword("251169ea");
            basicDataSource.setValidationQuery("SELECT 1");
            basicDataSource.setMaxActive(10);//ClearDB free ignite max connections.
            return basicDataSource;
        }
    }
}