package classcontrol.dao;

import java.sql.*;
import javax.sql.DataSource;
import org.apache.commons.dbcp.BasicDataSource;

/**
 * Database connection pool. It is useful due to there is only a single way to
 * connect Class Control database.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class ConnectionPool {

    /**
     * Connection pool.
     */
    private static ConnectionPool pool;
    /**
     * Datasource.
     */
    private static DataSource dataSource;

    /**
     * Private constructor.
     */
    private ConnectionPool() {
        try {
            dataSource = ClassControlDataSource.getDataBase();
        } catch (final Exception e) {
            //e.printStackTrace();
        }

    }

    /**
     * Initialize a Class Control database connection pool.
     *
     * @return Class Control database connection pool.
     */
    public static ConnectionPool getInstance() {
        if (pool == null) {
            pool = new ConnectionPool();
        }
        return pool;
    }

    public Connection getConnection() {
        try {

            return dataSource.getConnection();
        } catch (final SQLException sqle) {
            //sqle.printStackTrace();
            return null;
        }
    }

    /**
     * Closes Class Control database connection pool.
     *
     * @param c Connection to close.
     */
    public final void freeConnection(final Connection c) {
        try {
            c.close();
            //System.out.println("Connection Pool close()");
        } catch (final SQLException sqle) {
            //System.out.println("Connection Pool error close()");
            //sqle.printStackTrace();
        }
    }

    /**
     * Class Control database settings. There is only one Class Control
     * database.
     */
    private static class ClassControlDataSource {

        /**
         * Get the Class Control data base link.
         *
         * @return Configured Class Control data base link.
         *
         */
        static BasicDataSource getDataBase() throws SQLException {
            final BasicDataSource basicDataSource = new BasicDataSource();
            basicDataSource.setUrl("jdbc:mysql://eu-cdbr-west-01.cleardb.com:3306/heroku_3eb85e4f7505b47?reconnect=true");
            basicDataSource.setUsername("bc35d1cae118cf");
            basicDataSource.setPassword("4f53da94");
            basicDataSource.setValidationQuery("SELECT 1");
            basicDataSource.setMaxActive(10);//ClearDB free ignite max connections.
            return basicDataSource;
        }
// V. 0.1.: Plain DataSourceConnection: not recomended
//        public static Connection getDataBase() throws SQLException {
//        return DriverManager.getDataBase("jdbc:mysql://eu-cdbr-west-01.cleardb.com:3306/heroku_3eb85e4f7505b47", "bc35d1cae118cf", "4f53da94");
//    }
    }
}