package classcontrol.dao;

import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluableItemUpdated;
import classcontrol.utils.Constants;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.PreparedStatement;
import java.util.ArrayList;

/**
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class EvaluableItemDAO {

    static ArrayList<EvaluableItem> getEvaluableItemsAssignment(final int idAssignment) throws IllegalArgumentException {
        if (idAssignment < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Assignment's id no valid.");
        }
        final ArrayList<EvaluableItem> mylist = new ArrayList<EvaluableItem>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        ResultSet rs;
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.TABLE_NAME_EVALUABLE_ITEM)
                    .append(" WHERE ").append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSIGNMENT_ID)
                    .append("=?").toString());
            ps.setInt(1, idAssignment);
            rs = ps.executeQuery();
            while (rs.next()) {
                mylist.add(new EvaluableItem(idAssignment, rs.getString(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_NAME), rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT)));
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return mylist;
        }
    }

    static byte updateEvaluableItems(final int idAssignment, final ArrayList<EvaluableItemUpdated> newList, final ArrayList<String> deletedEvalItems) throws IllegalArgumentException {
        if (idAssignment < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Assignment's id no valid");
        }
        if (newList == null) {
            throw new IllegalArgumentException("Evaluable items list no valid");
        }
        if (deletedEvalItems == null) {
            throw new IllegalArgumentException("Deleted evaluable items list no valid");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            // Transaction
            con.setAutoCommit(false);
            // 1. Delete all previous assignment's evaluable items.
            ps = con.prepareStatement(new StringBuilder("DELETE FROM ")
                    .append(ConstantsDB.TABLE_NAME_EVALUABLE_ITEM)
                    .append(" WHERE ").append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSIGNMENT_ID)
                    .append("=? AND ").append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_NAME).append("=?").toString());
            for (final String current : deletedEvalItems) {
                ps.setInt(1, idAssignment);
                ps.setString(2, current);
                ps.executeUpdate();
            }

            // 2. Insert all new assignment's evaluable items in the list or update them
            ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                    .append(ConstantsDB.TABLE_NAME_EVALUABLE_ITEM)
                    .append("(").append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSIGNMENT_ID).append(',')
                    .append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_NAME).append(',')
                    .append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT)
                    .append(") VALUES (?,?,?) ON DUPLICATE KEY UPDATE ")
                    .append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_NAME).append("=?,")
                    .append(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT).append("=?")
                    .toString());
            String nameAux;
            String nameOldAux;
            int weightAux;
            for (final EvaluableItemUpdated evaluableItem : newList) {
                ps.setInt(1, idAssignment);
                nameAux = evaluableItem.getName();
                nameOldAux = evaluableItem.getOldName();
                weightAux = evaluableItem.getAssociatedWeight();
                ps.setString(2, nameOldAux == null ? nameAux : nameOldAux);
                ps.setInt(3, weightAux);
                ps.setString(4, nameAux);
                ps.setInt(5, weightAux);
                ps.executeUpdate();
            }
            con.commit();
        } catch (final Exception e) {
            con.rollback();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }

    static ArrayList<EvaluableItemStudent> getEvaluableItemStudentAssignment(final int idAssignment) throws IllegalArgumentException {
        if (idAssignment < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Assignment's id no valid.");
        }
        final ArrayList<EvaluableItemStudent> mylist = new ArrayList<EvaluableItemStudent>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        ResultSet rs;
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_EVALUABLE_ITEM_STUDENT).append(',')
                    //.append(ConstantsDB.TABLE_NAME_EVALUABLE_ITEM_STUDENT)
                    .append(" WHERE ").append(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_EVALUABLE_ITEM_ASSIGNMENT_ID)
                    .append("=?").toString());
            ps.setInt(1, idAssignment);
            rs = ps.executeQuery();
            while (rs.next()) {
                mylist.add(new EvaluableItemStudent(idAssignment, rs.getString(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_EVALUABLE_ITEM_NAME),
                        rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_STUDENT_ID),
                        rs.getDouble(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_SCORE)));
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return mylist;
        }
    }
}