package classcontrol.dao;

import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.entity.Calification;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluableItemStudentCalification;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.SubjectCompetenceEvaluation;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class EvaluationReportDAO {

    /**
     * Get all subject competence's califications and evaluable items applied to
     * students in that subject competence.
     *
     * @param idTeacherSC
     * @param titleSC
     * @return
     * @throws IllegalArgumentException
     */
    static EvaluableItemStudentCalification getData(final int idTeacherSC, final String titleSC) throws IllegalArgumentException {
        if (idTeacherSC < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid teacher's id");
        }
        if (titleSC == null) {
            throw new IllegalArgumentException("Invalid titleSC");
        }
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        ResultSet rs;
        PreparedStatement ps;
        final ArrayList<EvaluableItemStudent> mylist = new ArrayList<EvaluableItemStudent>();
        final List<Calification> myCalifications = new ArrayList<Calification>();
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_EVALUABLE_ITEM_STUDENT)
                    //.append(ConstantsDB.BD_NAME).append('.').append(ConstantsDB.TABLE_NAME_EVALUABLE_ITEM_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER).append("=? AND ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE).append("=?")
                    .toString());
            ps.setInt(1, idTeacherSC);
            ps.setString(2, titleSC);
            rs = ps.executeQuery();
            while (rs.next()) {
                mylist.add(new EvaluableItemStudent(rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_EVALUABLE_ITEM_ASSIGNMENT_ID), rs.getString(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_EVALUABLE_ITEM_NAME),
                        rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_STUDENT_ID),
                        rs.getDouble(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_SCORE)));
            }
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    //.append(ConstantsDB.BD_NAME).append('.').append(ConstantsDB.TABLE_NAME_CALIFICATION)
                    .append(ConstantsDB.VIEW_CALIFICATION)
                    .append(" WHERE ").
                    append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER).append("=? AND ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE).append("=?")
                    .toString());
            ps.setInt(1, idTeacherSC);
            ps.setString(2, titleSC);
            rs = ps.executeQuery();
            while (rs.next()) {
                myCalifications.add(new Calification(rs.getInt(ConstantsDB.TABLE_CALIFICATION_ATT_ASSIGNMENT_ID),
                        rs.getInt(ConstantsDB.TABLE_CALIFICATION_ATT_STUDENT_ID),
                        rs.getDouble(ConstantsDB.TABLE_CALIFICATION_ATT_BONUS_PENALIZATION),
                        rs.getString(ConstantsDB.TABLE_CALIFICATION_ATT_REASON),
                        rs.getString(ConstantsDB.TABLE_CALIFICATION_ATT_OPTIONAL_COMMENT),
                        rs.getByte(ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_PARENT),
                        rs.getByte(ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_STUDENT)));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return new EvaluableItemStudentCalification(myCalifications, mylist);
        }
    }

    /**
     * Finds all subject competence's data.
     *
     * @param teacherId Subject competence's teacher id.
     * @param title Subject competence's title.
     * @return all subject competence's data.
     * @throws IllegalArgumentException If arguments are null.
     */
    static SubjectCompetenceEvaluation getEvaluationData(final int teacherId, final String title) throws IllegalArgumentException {
        if (teacherId == ConstantsDB.TABLE_NULL_ID) {
            throw new IllegalArgumentException("Invalid teacher id");
        }
        if (title == null) {
            throw new IllegalArgumentException("Invalid title");
        }
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        ResultSet rs;
        PreparedStatement ps;
        final List<EvaluableItem> mEvaluableItemsSC = new ArrayList<EvaluableItem>();
        final List<StudentAspect> aspectsApplied = new ArrayList<StudentAspect>();
        final List<BehaviourAttitudeAspect> mySubjectCompetenceAspects = new ArrayList<BehaviourAttitudeAspect>();
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_EVALUABLE_ITEMS_ASSIGNMENT)
                    .append(" WHERE ").append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE)
                    .append("=? AND ").append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID).append("=?").toString());
            ps.setString(1, title);
            ps.setInt(2, teacherId);
            rs = ps.executeQuery();
            while (rs.next()) {
                mEvaluableItemsSC.add(new EvaluableItem(rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSIGNMENT_ID),
                        rs.getString(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_NAME),
                        rs.getInt(ConstantsDB.TABLE_EVALUABLE_ITEM_ATT_ASSOCIATED_WEIGHT)));
            }
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append("=? AND ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE).append("=?")
                    .toString());
            ps.setInt(1, teacherId);
            ps.setString(2, title);
            rs = ps.executeQuery();
            while (rs.next()) {
                aspectsApplied.add(new StudentAspect(
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME),
                        rs.getDate(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_DATE),
                        rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE),
                        rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID)));
            }
            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_BEHAVIOUR_ATTITUDE_ASPECT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID).
                    append("=?")
                    .toString());
            ps.setInt(1, teacherId);
            rs = ps.executeQuery();
            while (rs.next()) {
                mySubjectCompetenceAspects.add(new BehaviourAttitudeAspect(rs.getInt(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TEACHER_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_EDMODO_ID),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_NAME), rs.getByte(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_DESCRIPTION), null));
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return new SubjectCompetenceEvaluation(mEvaluableItemsSC, aspectsApplied, mySubjectCompetenceAspects);
        }
    }
}