package classcontrol.dao;

import classcontrol.entity.Absence;
import classcontrol.entity.Assignment;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.entity.BonusPenalization;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluableItemStudentCalification;
import classcontrol.entity.EvaluableItemUpdated;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.StudentCalificationReport;
import classcontrol.entity.SubjectCompetence;
import classcontrol.entity.SubjectCompetenceEvaluation;
import java.util.ArrayList;
import java.util.List;

/**
 * Get database connection to execute querys.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public interface IPersistence {

    /**
     *
     * @param idEmodo
     * @param idRole
     * @return
     * @throws IllegalArgumentException
     */
    public int getLanguageUser(final String idEmodo, final byte idRole) throws IllegalArgumentException;

    /**
     *
     * @param idEmodo
     * @return
     * @throws IllegalArgumentException
     */
    public int getIdTeacher(final String idEmodo) throws IllegalArgumentException;

    /**
     *
     * @param idTeacher
     * @return
     * @throws IllegalArgumentException
     */
    public String getIdEdmodoTeacher(final int idTeacher) throws IllegalArgumentException;

    /**
     *
     * @param idEmodo
     * @param idRole
     * @param idNewLan
     * @throws IllegalArgumentException
     */
    public void setLanguageUser(final String idEmodo, final byte idRole, final int idNewLan) throws IllegalArgumentException;

    /**
     *
     * @param idTeacherEdmodo
     * @return
     * @throws IllegalArgumentException
     */
    public List<SubjectCompetence> getSubjectsCompetences(final String idTeacherEdmodo) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoTeacher
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public SubjectCompetence getSubjectCompetence(final int idEdmodoTeacher, final String title) throws IllegalArgumentException;

    /**
     *
     * @param subjectCompetence
     * @param evaluationPeriodsList
     * @return
     */
    public byte insertSubjectCompetence(final SubjectCompetence subjectCompetence, final List<EvaluationPeriod> evaluationPeriodsList);

    /**
     *
     * @param idTeacher
     * @param title
     * @return
     */
    public byte deleteSubjectCompetence(final int idTeacher, final String title);

    /**
     *
     * @param idTeacherEdmodo
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public boolean existSubjectCompetenceTeacher(final String idTeacherEdmodo, final String title) throws IllegalArgumentException;

    /**
     *
     * @param idTeacherSC
     * @param titleSC
     * @return
     * @throws IllegalArgumentException
     */
    public List<EvaluationPeriod> getEvaluationPeriodsSubjectCompetence(final int idTeacherSC, final String titleSC) throws IllegalArgumentException;

    /**
     *
     * @param previousTitle
     * @param subjectCompetence
     * @param evaluationPeriodsList
     * @return
     */
    public byte updateSubjectCompetence(final String previousTitle, final SubjectCompetence subjectCompetence, final List<EvaluationPeriod> evaluationPeriodsList);

    /**
     *
     * @param title
     * @param idTeacherEdmodo
     * @param nonAcademicDays
     * @return
     */
    public byte updateNonAcademicDaysSubjectCompetence(final String title, final String idTeacherEdmodo, final String nonAcademicDays);

    /**
     *
     * @param idTeacher
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public List<Absence> getAbsencesSubjectCompetence(final int idTeacher, final String title) throws IllegalArgumentException;

    /**
     *
     * @param idTeacherEdmodo
     * @return
     * @throws IllegalArgumentException
     */
    public int getStudentId(final String idTeacherEdmodo) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoStudent
     * @param idEdmodoSCTeacher
     * @param titleSC
     * @param date
     * @return
     */
    public byte updateAbsencesStudent(final String idEdmodoStudent, final String idEdmodoSCTeacher, final String titleSC, final String date);

    /**
     *
     * @param idEdmodoTeacher
     * @return
     */
    public List<BehaviourAttitudeAspect> getBAAspectsSubjectCompetence(final String idEdmodoTeacher);

    /**
     *
     * @param myAspect
     * @return
     */
    public byte insertBehaviourAttitudeAspect(final BehaviourAttitudeAspect myAspect);

    /**
     *
     * @param teacherId
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public List<Assignment> getAssignments(final int teacherId, final String title) throws IllegalArgumentException;

    /**
     *
     * @param idAssignment
     * @return
     * @throws IllegalArgumentException
     */
    public byte deleteAssignment(final int idAssignment) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoTeacher
     * @param title
     * @param idEdmodoStudent
     * @return
     * @throws IllegalArgumentException
     */
    public List<StudentAspect> getBAAspectsSubjectCompetenceStudent(final String idEdmodoTeacher, final String title, final String idEdmodoStudent) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoTeacher
     * @param aspectName
     * @return
     * @throws IllegalArgumentException
     */
    public BehaviourAttitudeAspect getBAAspect(final String idEdmodoTeacher, final String aspectName) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoStudent
     * @param idEdmodoSCTeacher
     * @param titleSC
     * @param aspectsNameList
     * @param deletePrevious
     * @return
     */
    public byte updateAspectsStudent(final String idEdmodoStudent, final String idEdmodoSCTeacher, final String titleSC, final List<String> aspectsNameList, final boolean deletePrevious);

    /**
     *
     * @param idEdmodoTeacher
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public List<StudentAspect> getStudentAspectsSubjectCompetence(final String idEdmodoTeacher, final String title) throws IllegalArgumentException;

    /**
     *
     * @param myAspect
     * @param oldName
     * @return
     */
    public byte updateBehaviourAttitudeAspect(final BehaviourAttitudeAspect myAspect, final String oldName);

    /**
     *
     * @param idAssignment
     * @return
     * @throws IllegalArgumentException
     */
    public List<EvaluableItem> getEvaluableItemsAssignment(final int idAssignment) throws IllegalArgumentException;

    /**
     *
     * @param idAssignment
     * @return
     * @throws IllegalArgumentException
     */
    public Assignment getAssignment(final int idAssignment) throws IllegalArgumentException;

    /**
     *
     * @param idAssignment
     * @param list
     * @param deletedEvalItems
     * @return
     * @throws IllegalArgumentException
     */
    public byte updateEvaluableItems(final int idAssignment, final ArrayList<EvaluableItemUpdated> list, final ArrayList<String> deletedEvalItems) throws IllegalArgumentException;

    /**
     *
     * @param myAssignment
     * @return
     */
    public byte insertAssignment(final Assignment myAssignment);

    /**
     *
     * @param idEdmodoAssignment
     * @return
     * @throws IllegalArgumentException
     */
    public Assignment getAssignment(final String idEdmodoAssignment) throws IllegalArgumentException;

    /**
     *
     * @param myAssignmentList
     * @return
     * @throws IllegalArgumentException
     */
    public byte updateAssignment(final ArrayList<Assignment> myAssignmentList) throws IllegalArgumentException;

    /**
     *
     * @param idAssignment
     * @return
     * @throws IllegalArgumentException
     */
    public ArrayList<EvaluableItemStudent> getEvaluableItemStudentAssignment(final int idAssignment) throws IllegalArgumentException;

    /**
     *
     * @param idAssignment
     * @param mStudentCalifications
     * @return
     * @throws IllegalArgumentException
     */
    public byte updateCalificationsAssignment(final int idAssignment, final List<StudentCalificationReport> mStudentCalifications) throws IllegalArgumentException;

    /**
     *
     * @param teacherId
     * @param subjectCompetenceTitle
     * @return
     * @throws IllegalArgumentException
     */
    public List<BonusPenalization> getBonusPenalizations(final int teacherId, final String subjectCompetenceTitle) throws IllegalArgumentException;

    /**
     *
     * @param teacherId
     * @param subjectCompetenceTitle
     * @return
     */
    public EvaluableItemStudentCalification getEvaluableItemStudentCalification(final int teacherId, final String subjectCompetenceTitle);

    /**
     *
     * @param idTeacher
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    public SubjectCompetenceEvaluation getEvaluationData(final int idTeacher, final String title) throws IllegalArgumentException;

    /**
     *
     * @param mBonusPenalizationList
     * @return
     * @throws IllegalArgumentException
     */
    public byte insertBonusPenalization(final List<BonusPenalization> mBonusPenalizationList) throws IllegalArgumentException;

    /**
     *
     * @param idEdmodoStudent
     * @return
     * @throws IllegalArgumentException
     */
    public List<SubjectCompetence> getInvolvedDataStudent(final String idEdmodoStudent) throws IllegalArgumentException;
}