package classcontrol.dao;

import java.sql.Connection;
import java.sql.ResultSet;
import classcontrol.utils.Constants;
import java.sql.PreparedStatement;
import java.util.Set;

/**
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
final class LanguageDAO {

    /**
     *
     * @return {@link Constants#NO_RESULT} if user not exists in Class Control
     * database. database. Number >= 0 else.
     */
    static int getLanguageUser(final String idEdmodo, final byte idRole) throws IllegalArgumentException {
        if (idEdmodo == null) {
            throw new IllegalArgumentException("Edmodo id no valid.");
        }
        if (idRole != Constants.SESSION_ID_ROLE_TEACHER && idRole
                != Constants.SESSION_ID_ROLE_STUDENT && idRole
                != Constants.SESSION_ID_ROLE_PARENT) {
            throw new IllegalArgumentException("User rol no valid.");
        }
        int userLanguage = Constants.NO_RESULT;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        final ResultSet rs;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(idRole
                    == Constants.SESSION_ID_ROLE_TEACHER ? ConstantsDB.TABLE_TEACHER_ATT_ID_LANGUAGE
                    : idRole == Constants.SESSION_ID_ROLE_STUDENT ? ConstantsDB.TABLE_STUDENT_ATT_ID_LANGUAGE
                    : ConstantsDB.TABLE_PARENT_ATT_ID_LANGUAGE).append(" FROM ")
                    .append(idRole
                    == Constants.SESSION_ID_ROLE_TEACHER ? ConstantsDB.TABLE_NAME_TEACHER
                    : idRole == Constants.SESSION_ID_ROLE_STUDENT ? ConstantsDB.TABLE_NAME_STUDENT
                    : ConstantsDB.TABLE_NAME_PARENT).append(" WHERE ").
                    append(idRole
                    == Constants.SESSION_ID_ROLE_TEACHER ? ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO
                    : idRole == Constants.SESSION_ID_ROLE_STUDENT ? ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO
                    : ConstantsDB.TABLE_PARENT_ATT_ID_EDMODO).append("=?").toString());
            ps.setString(1, idEdmodo);
            rs = ps.executeQuery();
            if (rs.next()) {
                userLanguage = rs.getInt(idRole
                        == Constants.SESSION_ID_ROLE_TEACHER ? ConstantsDB.TABLE_TEACHER_ATT_ID_LANGUAGE
                        : idRole == Constants.SESSION_ID_ROLE_STUDENT ? ConstantsDB.TABLE_STUDENT_ATT_ID_LANGUAGE
                        : ConstantsDB.TABLE_PARENT_ATT_ID_LANGUAGE);
            }
        } catch (final Exception e) { //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return userLanguage;
        }
    }

    /**
     * Inserts a new user with specified language or updates an existent one. If
     * it is a new user and its role is TEACHER, all student's group members
     * will be inserted in database.
     *
     * @param idEdmodo
     * @param idRole
     * @param idNewLan
     * @param changeLanIfExists
     * @return {@link Constants#INSERTED_USER} if a new user was inserted,
     * {@link Constants#UPDATED_USER} if user existed and was updated its
     * language code or {@link Constants#NO_CHANGES_USER} if no changes were
     * applied.
     * @throws IllegalArgumentException If idEdmodo is null or idRole does not
     * exist.
     */
    static boolean setLanguageUser(final String idEdmodo, final byte idRole, final int idNewLan, final boolean changeLanIfExists, final Set<String> studentEdmodoId) throws IllegalArgumentException {
        if (idEdmodo == null) {
            throw new IllegalArgumentException("Edmodo id no valid.");
        }
        if (idRole != Constants.SESSION_ID_ROLE_TEACHER && idRole
                != Constants.SESSION_ID_ROLE_STUDENT && idRole
                != Constants.SESSION_ID_ROLE_PARENT) {
            throw new IllegalArgumentException("User rol no valid.");
        }
        boolean result = true;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            con.setAutoCommit(false);
            boolean exists = getLanguageUser(idEdmodo, idRole) != Constants.NO_RESULT;
            if ((exists && changeLanIfExists) || !exists) {
                switch (idRole) {
                    case Constants.SESSION_ID_ROLE_TEACHER:
                        ps = con.prepareStatement(exists && changeLanIfExists ? new StringBuilder("UPDATE ")
                                .append(ConstantsDB.TABLE_NAME_TEACHER).
                                append(" SET ").append(ConstantsDB.TABLE_TEACHER_ATT_ID_LANGUAGE)
                                .append("=? WHERE ")
                                .append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).
                                append("=?").toString() : new StringBuilder("INSERT INTO ")
                                .append(ConstantsDB.TABLE_NAME_TEACHER).
                                append(" (").append(ConstantsDB.TABLE_TEACHER_ATT_ID_LANGUAGE).append(',')
                                .append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO)
                                .append(") VALUES (?,?)")
                                .toString());
                        ps.setInt(1, idNewLan);
                        ps.setString(2, idEdmodo);
                        ps.executeUpdate();
                        break;
                    case Constants.SESSION_ID_ROLE_STUDENT:
                        ps = con.prepareStatement(exists && changeLanIfExists ? new StringBuilder("UPDATE ")
                                .append(ConstantsDB.TABLE_NAME_STUDENT)
                                .append(" SET ").append(ConstantsDB.TABLE_STUDENT_ATT_ID_LANGUAGE)
                                .append("=? WHERE ").append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).
                                append("=?").toString() : new StringBuilder("INSERT INTO ")
                                .append(ConstantsDB.TABLE_NAME_STUDENT).
                                append(" (").append(ConstantsDB.TABLE_STUDENT_ATT_ID_LANGUAGE).append(',')
                                .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO)
                                .append(") VALUES (?,?)")
                                .toString());
                        ps.setInt(1, idNewLan);
                        ps.setString(2, idEdmodo);
                        ps.executeUpdate();
                        break;
                    case Constants.SESSION_ID_ROLE_PARENT:
                        ps = con.prepareStatement(exists && changeLanIfExists ? new StringBuilder("UPDATE ")
                                .append(ConstantsDB.TABLE_NAME_PARENT)
                                .append(" SET ").append(ConstantsDB.TABLE_PARENT_ATT_ID_LANGUAGE)
                                .append("=? WHERE ").append(ConstantsDB.TABLE_PARENT_ATT_ID_EDMODO).
                                append("=?").toString() : new StringBuilder("INSERT INTO ")
                                .append(ConstantsDB.TABLE_NAME_PARENT).
                                append(" (").append(ConstantsDB.TABLE_PARENT_ATT_ID_LANGUAGE).append(',')
                                .append(ConstantsDB.TABLE_PARENT_ATT_ID_EDMODO)
                                .append(") VALUES (?,?)")
                                .toString());
                        ps.setString(1, idEdmodo);
                        ps.setInt(2, idNewLan);
                        ps.executeUpdate();
                        break;
                }
            }
            if (!exists || idRole == Constants.SESSION_ID_ROLE_TEACHER && studentEdmodoId != null) {
                // Inserts new students only if users not exists previously.
                ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                        .append(ConstantsDB.TABLE_NAME_STUDENT)
                        .append("(").append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO)
                        .append(") SELECT ? FROM dual WHERE NOT EXISTS (SELECT ")
                        .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" FROM ")
                        .append(ConstantsDB.TABLE_NAME_STUDENT).append(" WHERE ")
                        .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append("=? LIMIT 1)").toString());
                for (final String current : studentEdmodoId) {
                    ps.setString(1, current);
                    ps.setString(2, current);
                    ps.executeUpdate();
                }
            }
            con.commit();
        } catch (final Exception e) {
            con.rollback();
            //e.printStackTrace();
            result = false;
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }
}