package classcontrol.dao;

import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import classcontrol.utils.Constants;
import java.util.AbstractMap.SimpleEntry;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

/**
 * Handles all studen's database connections.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
final class StudentDAO {

    static int getIdStudent(final String idEdmodo) throws IllegalArgumentException {
        if (idEdmodo == null) {
            throw new IllegalArgumentException("No valid Edmodo id.");
        }
        int studentId = Constants.NO_RESULT;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" FROM ")
                    .append(ConstantsDB.VIEW_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(
                    "=?").toString());
            ps.setString(1, idEdmodo);
            final ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                studentId = rs.getInt(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT);
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return studentId;
        }
    }

    /**
     * Get student's Class Control application involved data.
     *
     * @param idEdmodoStudent Student to get data from.
     * @return A list of subject competences that student has some data.
     * @throws IllegalArgumentException If Edmodo student is is null.
     */
    static List<SubjectCompetence> getInvolvedDataStudent(final String idEdmodoStudent) throws IllegalArgumentException {
        if (idEdmodoStudent == null) {
            throw new IllegalArgumentException("Invalid student's Edmodo id");
        }
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        final List<SubjectCompetence> mSubjectsCompetences = new ArrayList<SubjectCompetence>();
        try {
            final Set<Entry<String, Integer>> pairList = new HashSet<Entry<String, Integer>>();

            // 1. Look for student's absences
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE)
                    .append(" FROM ")
                    .append(ConstantsDB.VIEW_ABSENCE).append(',').append(ConstantsDB.TABLE_NAME_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_ABSENCE_ATT_STUDENT_ID).append('=').
                    append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" =?").toString());
            ps.setString(1, idEdmodoStudent);
            ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                pairList.add(new SimpleEntry<String, Integer>(rs.getString(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE), rs.getInt(ConstantsDB.TABLE_ABSENCE_ATT_S_C_TEACHER_ID)));
            }
            // 2. Look for student's behaviour attitude aspects
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE)
                    .append(" FROM ")
                    .append(ConstantsDB.VIEW_ASPECT_STUDENT).append(',').append(ConstantsDB.TABLE_NAME_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_STUDENT_ID).append('=').
                    append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" =?").toString());
            ps.setString(1, idEdmodoStudent);
            rs = ps.executeQuery();
            while (rs.next()) {
                pairList.add(new SimpleEntry<String, Integer>(rs.getString(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TITLE), rs.getInt(ConstantsDB.TABLE_ASPECT_STUDENT_ATT_S_C_TEACHER_ID)));
            }

            // 3. Look for applied student's evaluate items
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER).append(',')
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE)
                    .append(" FROM ")
                    .append(ConstantsDB.VIEW_EVALUABLE_ITEM_STUDENT).append(',').append(ConstantsDB.TABLE_NAME_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_EVALUABLE_ITEM_STUDENT_ATT_STUDENT_ID).append('=').
                    append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" =?").toString());
            ps.setString(1, idEdmodoStudent);
            rs = ps.executeQuery();
            while (rs.next()) {
                pairList.add(new SimpleEntry<String, Integer>(rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER)));
            }

            // 4. Look for student's califications
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER).append(',')
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE)
                    .append(" FROM ")
                    .append(ConstantsDB.VIEW_CALIFICATION).append(',').append(ConstantsDB.TABLE_NAME_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_CALIFICATION_ATT_STUDENT_ID).append('=').
                    append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" =?").toString());
            ps.setString(1, idEdmodoStudent);
            rs = ps.executeQuery();
            while (rs.next()) {
                pairList.add(new SimpleEntry<String, Integer>(rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER)));
            }

            // 5. Look for student's bonus penalizations
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE)
                    .append(" FROM ")
                    .append(ConstantsDB.VIEW_BONUS_PENALIZATION).append(',').append(ConstantsDB.TABLE_NAME_STUDENT)
                    .append(" WHERE ")
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_STUDENT_ID).append('=').
                    append(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT).append(" AND ")
                    .append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append(" =?").toString());
            ps.setString(1, idEdmodoStudent);
            rs = ps.executeQuery();
            while (rs.next()) {
                pairList.add(new SimpleEntry<String, Integer>(rs.getString(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE), rs.getInt(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TEACHER_ID)));
            }

            ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_SUBJECT_COMPETENCE)
                    .append(" WHERE ").append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER).append("=? AND ")
                    .append(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE).append("=?").toString());


            for (final Entry<String, Integer> current : pairList) {
                ps.setInt(1, current.getValue());
                ps.setString(2, current.getKey());
                rs = ps.executeQuery();
                if (rs.next()) {
                    mSubjectsCompetences.add(new SubjectCompetence(rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE), rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_ED_GROUP), rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_DESCRIPTION), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_TEACHER), rs.getDate(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_I_DATE), rs.getDate(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_F_DATE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_ASS_S_C_ID_TEACHER), rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ASS_S_C_TITLE), rs.getString(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_NON_ACADEMIC_DAYS),
                            rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_POSITIVE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_NEGATIVE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_POSITIVE), rs.getInt(ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE)));
                }
            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return mSubjectsCompetences;
        }
    }

    static ArrayList<Student> getStudentList(final ArrayList<Map.Entry<String, String>> nameEdmodoIdPair) throws IllegalArgumentException {
        if (nameEdmodoIdPair == null) {
            throw new IllegalArgumentException("No valid Edmodo id list.");
        }

        final StringBuilder query = new StringBuilder("SELECT * FROM ")
                .append(ConstantsDB.VIEW_STUDENT)
                .append(" WHERE ");
        final int USERS_SIZE = nameEdmodoIdPair.size();
        final int USERS_SIZE_2 = USERS_SIZE - 2;
        for (int i = USERS_SIZE_2; i >= 0; i--) {
            query.append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append("=? OR ");
        }
        query.append(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO).append("=? ");
        final ArrayList<Student> mStudentList = new ArrayList<Student>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(query.toString());
            int counter = 1;
            for (final Map.Entry<String, String> current : nameEdmodoIdPair) {
                ps.setString(counter, current.getValue());
                counter++;
            }
            final ResultSet rs = ps.executeQuery();
            boolean find;
            int count;
            String idEdmodoAux;
            String valueEdmodoId;
            Map.Entry<String, String> entryAux;
            while (rs.next()) {
                idEdmodoAux = rs.getString(ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO);
                find = false;
                count = 0;
                while (!find && count < USERS_SIZE) {
                    entryAux = nameEdmodoIdPair.get(count);
                    valueEdmodoId = entryAux.getValue();
                    if (valueEdmodoId.compareTo(idEdmodoAux) == 0) {
                        mStudentList.add(new Student(rs.getInt(ConstantsDB.TABLE_STUDENT_ATT_ID_STUDENT), idEdmodoAux,
                                entryAux.getKey()));
                        find = true;
                    }
                    count++;
                }
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return mStudentList;
        }
    }
}