package classcontrol.dao;

import java.sql.Connection;
import java.sql.ResultSet;
import classcontrol.utils.Constants;
import java.sql.PreparedStatement;

/**
 *
 * Handles all teacher's database connections.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
final class TeacherDAO {

    /**
     * Returns a specified teacher's id.
     *
     * @param idEdmodoTeacher Edmodo token for this teacher.
     * @return {@link Constants#NO_RESULT} if user not exists in Class Control
     * database. database. Number >= 0 else.
     * @throws IllegalArgumentException If argunt is null.
     */
    static int getIdTeacher(final String idEdmodoTeacher) throws IllegalArgumentException {
        if (idEdmodoTeacher == null) {
            throw new IllegalArgumentException("Invalid Edmodo id");
        }
        int idUser = Constants.NO_RESULT;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER).append(" FROM ")
                    .append(ConstantsDB.VIEW_TEACHER)
                    .append(" WHERE ").append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO)
                    .append("=?").toString());
            ps.setString(1, idEdmodoTeacher);
            final ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                idUser = rs.getInt(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER);
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return idUser;
        }
    }

    /**
     * Returns a specified teacher's Edmodo id.
     *
     * @param idEdmodoTeacher Class Control id for this teacher.
     * @return Teacher's Edmodo id.
     * @throws IllegalArgumentException If argunt is null.
     */
    static String getIdEdmodoTeacher(final int idTeacher) throws IllegalArgumentException {
        if (idTeacher == ConstantsDB.TABLE_NULL_ID) {
            throw new IllegalArgumentException("Invalid id");
        }
        String idEdmodoTeacher = null;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();

        PreparedStatement ps;
        try {
            ps = con.prepareStatement(new StringBuilder("SELECT ")
                    .append(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO).append(" FROM ")
                    .append(ConstantsDB.VIEW_TEACHER)
                    .append(" WHERE ").append(ConstantsDB.TABLE_TEACHER_ATT_ID_TEACHER)
                    .append("=?").toString());
            ps.setInt(1, idTeacher);
            final ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                idEdmodoTeacher = rs.getString(ConstantsDB.TABLE_TEACHER_ATT_ID_EDMODO);
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return idEdmodoTeacher;
        }
    }
}