package classcontrol.entity;

import classcontrol.dao.ConstantsDB;

/**
 * Models a student absence competence.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class Absence {

    private String dates;
    private int studentId;
    private int subjectCompetenceTeacherId;
    private String subjectCompetenceTitle;

    private Absence() {
    }

    /**
     *
     * @param dates
     * @param studentId
     * @param subjectCompetenceTeacherId
     * @param subjectCompetenceTitle
     * @throws IllegalArgumentException
     */
    public Absence(final String dates, final int studentId, final int subjectCompetenceTeacherId, final String subjectCompetenceTitle) throws IllegalArgumentException {
        if (dates != null && dates.length() > ConstantsDB.TABLE_ABSENCE_ATT_DATE_MAX) {
            throw new IllegalArgumentException("Invalid dates.");
        }
        if (studentId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid studentId.");
        }
        if (subjectCompetenceTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid subjectCompetenceTeacherId.");
        }
        if (subjectCompetenceTitle == null || subjectCompetenceTitle.length() > ConstantsDB.TABLE_ABSENCE_ATT_S_C_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid title.");
        }
        this.dates = dates;
        this.studentId = studentId;
        this.subjectCompetenceTeacherId = subjectCompetenceTeacherId;
        this.subjectCompetenceTitle = subjectCompetenceTitle;
    }

    /**
     *
     * @return
     */
    public String getDates() {
        return dates;
    }

    /**
     *
     * @return
     */
    public int getStudentId() {
        return studentId;
    }

    /**
     *
     * @return
     */
    public int getSubjectCompetenceTeacherId() {
        return subjectCompetenceTeacherId;
    }

    /**
     *
     * @return
     */
    public String getSubjectCompetenceTitle() {
        return subjectCompetenceTitle;
    }
}