package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import java.util.Date;

/**
 *
 * Models a subject competence assignment.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class Assignment {

    private int idAssignment;
    private String title;
    private String description;
    private double maxGrade;
    private byte type;
    private String edmodoId;
    private int associatedWeight;
    private Date date;
    private String associatedSCTitle;
    private int associatedSCTeacherId;

    private Assignment() {
    }

    /**
     *
     * @param idAssignment
     * @param title Can be null.
     * @param description Can be null.
     * @param type
     * @param edmodoId
     * @param maxGrade Can be null.
     * @param associatedWeight
     * @param date
     * @param associatedSCTitle
     * @param associatedSCTeacherId
     * @throws IllegalArgumentException
     */
    public Assignment(final int idAssignment, final String title, String description,
            final byte type, final String edmodoId, final double maxGrade,
            final int associatedWeight, final Date date, final String associatedSCTitle, final int associatedSCTeacherId)
            throws IllegalArgumentException {
        if (idAssignment != ConstantsDB.TABLE_NULL_ID && idAssignment < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid idAssignment");
        }
        if (title != null && (title.length() == 0 || title.length() > ConstantsDB.CREATE_ASSIGNMENT_TITLE_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        if (description != null && (description.length() == 0 || description.length() > ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX)) {
            throw new IllegalArgumentException("Invalid description");
        }
        final byte NO_FIND = 0;
        int counter = NO_FIND;
        boolean find = false;
        final int ASSIGNMENT_ATT_TYPE_TYPES_LENGTH = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES.length;
        while (!find && counter < ASSIGNMENT_ATT_TYPE_TYPES_LENGTH) {
            if (type == ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[counter]) {
            }
            counter++;
        }
        if (counter == NO_FIND) {
            throw new IllegalArgumentException("Invalid type");
        }
        if (edmodoId == null || edmodoId.length() > ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT_MAX) {
            throw new IllegalArgumentException("Invalid assignment edmodo id");
        }
        if (associatedWeight < ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MIN || associatedWeight > ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MAX) {
            throw new IllegalArgumentException("Invalid associatedWeight");
        }
        if (maxGrade < ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION_MIN || maxGrade > ConstantsForm.CREATE_ASSIGNMENT_CALIFICATION_MAX) {
            throw new IllegalArgumentException("Invalid maxGrade");
        }
        if (date == null) {
            throw new IllegalArgumentException("Invalid date.");
        }
        final int ASS_TITLE = associatedSCTitle == null ? 0 : associatedSCTitle.length();
        if (ASS_TITLE == 0 || ASS_TITLE > ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid associated subject competence title");
        }
        if (associatedSCTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid associated SubjectCompetence teacher id.");
        }
        this.idAssignment = idAssignment;
        this.title = title;
        this.description = description;
        this.type = type;
        this.edmodoId = edmodoId;
        this.maxGrade = maxGrade;
        this.associatedWeight = associatedWeight;
        this.date = date;
        this.associatedSCTitle = associatedSCTitle;
        this.associatedSCTeacherId = associatedSCTeacherId;
    }

    /**
     *
     * @return
     */
    public int getIdAssignment() {
        return idAssignment;
    }

    /**
     *
     * @return
     */
    public String getDescription() {
        return description;
    }

    /**
     *
     * @return
     */
    public String getTitle() {
        return title;
    }

    /**
     *
     * @return
     */
    public double getMaxGrade() {
        return maxGrade;
    }

    /**
     *
     * @return
     */
    public String getEdmodoId() {
        return edmodoId;
    }

    /**
     *
     * @return
     */
    public byte getType() {
        return type;
    }

    /**
     *
     * @return
     */
    public int getAssociatedWeight() {
        return associatedWeight;
    }

    /**
     *
     * @return
     */
    public Date getDate() {
        return date;
    }

    /**
     *
     * @return
     */
    public String getAssociatedSCTitle() {
        return associatedSCTitle;
    }

    /**
     *
     * @return
     */
    public int getAssociatedSCTeacherId() {
        return associatedSCTeacherId;
    }

    /**
     *
     * @param title
     */
    public void setTitle(final String title) {
        if (title != null && (title.length() == 0 || title.length() > ConstantsDB.CREATE_ASSIGNMENT_TITLE_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        this.title = title;
    }

    /**
     *
     * @param maxGrade
     */
    public void setMaxGrade(final int maxGrade) {
        this.maxGrade = maxGrade;
    }

    /**
     *
     * @param description
     */
    public void setDescription(final String description) {
        if (description != null && (description.length() == 0 || description.length() > ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX)) {
            throw new IllegalArgumentException("Invalid description");
        }
        this.description = description;
    }

    /**
     *
     * @param associatedWeight
     */
    public void setAssociatedWeight(final int associatedWeight) {
        if (associatedWeight < ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MIN || associatedWeight > ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MAX) {
            throw new IllegalArgumentException("Invalid associatedWeight");
        }
        this.associatedWeight = associatedWeight;
    }

    public void setDate(final Date date) {
        this.date = date;
    }
}