package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;

/**
 * Models a behaviour attitude aspect (Edmodo badge).
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class BehaviourAttitudeAspect {

    private int teacherId;
    private String edmodoId;
    private String name;
    private byte type;
    private String description;
    private String imageUrl;

    private BehaviourAttitudeAspect() {
    }

    /**
     *
     * @param behaviourAttitudeAspectId
     * @param edmodoId
     * @param name
     * @param type
     * @param description
     * @param imageUrl
     * @throws IllegalArgumentException
     */
    public BehaviourAttitudeAspect(final int behaviourAttitudeAspectId,
            final String edmodoId, final String name, final byte type,
            final String description, final String imageUrl) throws IllegalArgumentException {
        if (behaviourAttitudeAspectId != ConstantsDB.TABLE_NULL_ID && behaviourAttitudeAspectId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid behaviourAttitudeAspectId");
        }
        if (edmodoId == null || edmodoId.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_ID_EDMODO_MAX) {
            throw new IllegalArgumentException("Invalid edmodoId");
        }
        if (name != null && (name.length() == 0 || name.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_NAME_MAX)) {
            throw new IllegalArgumentException("Invalid name");
        }
        final byte NO_FIND = 0;
        int counter = NO_FIND;
        boolean find = false;
        final int BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES_LENGTH = ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES.length;
        while (!find && counter < BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES_LENGTH) {
            if (type == ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[counter]) {
                find=true;
            }
            counter++;
        }
        if (!find) {
            throw new IllegalArgumentException("Invalid type");
        }
        if (description != null && (description.length() == 0 || description.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_DESCRIPTION_MAX)) {
            throw new IllegalArgumentException("Invalid description");
        }
        if (imageUrl != null && (imageUrl.length() == 0 || imageUrl.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_URL_MAX)) {
            throw new IllegalArgumentException("Invalid image url");
        }

        this.teacherId = behaviourAttitudeAspectId;
        this.edmodoId = edmodoId;
        this.name = name;
        this.type = type;
        this.description = description;
        this.imageUrl = imageUrl;

    }

    /**
     *
     * @return
     */
    public int getTeacherId() {
        return teacherId;
    }

    /**
     *
     * @return
     */
    public String getName() {
        return name;
    }

    /**
     *
     * @return
     */
    public String getDescription() {
        return description;
    }

    /**
     *
     * @return
     */
    public String getImgUrl() {
        return imageUrl;
    }

    /**
     *
     * @return
     */
    public String getEdmodoId() {
        return edmodoId;
    }

    /**
     *
     * @return
     */
    public byte getType() {
        return type;
    }
}