package classcontrol.entity;

import classcontrol.dao.ConstantsDB;

/**
 * Models a student's assignment calification.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public class Calification {

    private Calification() {
    }
    private int idAssignment;
    private int studentId;
    private double bonusPenalization;
    private String reasonBonusPenalization;
    private String optionalComment;
    private byte visibleParent;
    private byte visibleStudent;

    /**
     *
     * @param idAssignment
     * @param studentId
     * @param bonusPenalization
     * @param reasonBonusPenalization
     * @param optionalComment
     * @param visibleParent
     * @param visibleStudent
     * @throws IllegalArgumentException
     */
    public Calification(final int idAssignment, final int studentId,
            final double bonusPenalization, final String reasonBonusPenalization,
            final String optionalComment, final byte visibleParent,
            final byte visibleStudent) throws IllegalArgumentException {
        if (idAssignment != ConstantsDB.TABLE_NULL_ID && idAssignment < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid idAssignment");
        }
        if (studentId != ConstantsDB.TABLE_NULL_ID && studentId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid studentId");
        }
        if (reasonBonusPenalization != null && reasonBonusPenalization.length() > ConstantsDB.TABLE_CALIFICATION_ATT_REASON_MAX) {
            throw new IllegalArgumentException("Invalid reasonBonusPenalization");
        }
        if (optionalComment != null && optionalComment.length() > ConstantsDB.TABLE_CALIFICATION_ATT_OPTIONAL_COMMENT_MAX) {
            throw new IllegalArgumentException("Invalid optionalComment");
        }
        if (!visibleCorrect(visibleParent)) {
            throw new IllegalArgumentException("Invalid visibleParent");
        }
        if (!visibleCorrect(visibleParent)) {
            throw new IllegalArgumentException("Invalid visibleStudent");
        }
        this.idAssignment = idAssignment;
        this.studentId = studentId;
        this.bonusPenalization = bonusPenalization;
        this.reasonBonusPenalization = reasonBonusPenalization;
        this.optionalComment = optionalComment;
        this.visibleParent = visibleParent;
        this.visibleStudent = visibleStudent;
    }

    /**
     *
     * @return
     */
    public int getIdAssignment() {
        return idAssignment;
    }

    /**
     *
     * @return
     */
    public int getStudentId() {
        return studentId;
    }

    /**
     *
     * @return
     */
    public double getBonusPenalization() {
        return bonusPenalization;
    }

    /**
     *
     * @return
     */
    public String getReasonBonusPenalization() {
        return reasonBonusPenalization;
    }

    /**
     *
     * @return
     */
    public String getOptionalComment() {
        return optionalComment;
    }

    /**
     *
     * @return
     */
    public byte isVisibleParent() {
        return visibleParent;
    }

    /**
     *
     * @return
     */
    public byte isVisibleStudent() {
        return visibleStudent;
    }

    /**
     *
     * @param bonusPenalization
     */
    public void setBonusPenalization(final double bonusPenalization) {
        this.bonusPenalization = bonusPenalization;
    }

    /**
     *
     * @param reasonBonusPenalization
     */
    public void setReasonBonusPenalization(final String reasonBonusPenalization) {
        if (reasonBonusPenalization != null && reasonBonusPenalization.length() > ConstantsDB.TABLE_CALIFICATION_ATT_REASON_MAX) {
            throw new IllegalArgumentException("Invalid reasonBonusPenalization");
        }
        this.reasonBonusPenalization = reasonBonusPenalization;
    }

    /**
     *
     * @param optionalComment
     */
    public void setOptionalComment(final String optionalComment) {
        if (optionalComment != null && optionalComment.length() > ConstantsDB.TABLE_CALIFICATION_ATT_OPTIONAL_COMMENT_MAX) {
            throw new IllegalArgumentException("Invalid optionalComment");
        }
        this.optionalComment = optionalComment;
    }

    /**
     *
     * @param visibleParent
     */
    public void setVisibleParent(final byte visibleParent) {
        if (!visibleCorrect(visibleParent)) {
            throw new IllegalArgumentException("Invalid visibleParent");
        }
        this.visibleParent = visibleParent;
    }

    /**
     *
     * @param visibleStudent
     */
    public void setVisibleStudent(final byte visibleStudent) {

        if (!visibleCorrect(visibleStudent)) {
            throw new IllegalArgumentException("Invalid visibleStudent");
        }
        this.visibleStudent = visibleStudent;
    }

    private boolean visibleCorrect(final byte visibleOption) {
        final byte NO_FIND = 0;
        int counter = NO_FIND;
        boolean find = false;
        final int TABLE_CALIFICATION_ATT_VISIBLE_LENGTH = ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_TYPES.length;
        while (!find && counter < TABLE_CALIFICATION_ATT_VISIBLE_LENGTH) {
            if (visibleOption == ConstantsDB.TABLE_CALIFICATION_ATT_VISIBLE_TYPES[counter]) {
                find = true;
            }
            counter++;
        }
        return find;
    }
}