package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import java.util.Date;

/**
 * Models a subject competence evaluation period.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class EvaluationPeriod {

    private int evaluationPeriodId;
    private Date initialDate;
    private Date finalDate;
    private int percentage;
    private String associatedSCTitle;
    private int associattedSCTeacherId;

    private EvaluationPeriod() {
    }

    /**
     *
     * @param evaluationPeriodId
     * @param initialDate
     * @param finalDate
     * @param percentage
     * @param associatedSCTitle
     * @param associattedSCTeacherId
     * @throws IllegalArgumentException
     */
    public EvaluationPeriod(final int evaluationPeriodId, final Date initialDate,
            final Date finalDate, final int percentage, final String associatedSCTitle,
            final int associattedSCTeacherId) throws IllegalArgumentException {

        if (evaluationPeriodId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid evaluation Period id.");
        }
        if (initialDate == null) {
            throw new IllegalArgumentException("Invalid initialDate.");
        }
        if (finalDate == null) {
            throw new IllegalArgumentException("Invalid finalDate.");
        }
        if (percentage > ConstantsDB.TABLE_EVALUATION_PERIOD_ATT_PERCENTAGE_MAX || percentage < ConstantsDB.TABLE_EVALUATION_PERIOD_ATT_PERCENTAGE_MIN) {
            throw new IllegalArgumentException("Invalid percentage.");
        }
        if (associatedSCTitle == null || associatedSCTitle.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid associated subject competence title.");
        }
        if (associattedSCTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid associatted subject competence teacher id.");
        }
        this.evaluationPeriodId = evaluationPeriodId;
        this.initialDate = initialDate;
        this.finalDate = finalDate;
        this.percentage = percentage;
        this.associatedSCTitle = associatedSCTitle;
        this.associattedSCTeacherId = associattedSCTeacherId;
    }

    /**
     *
     * @return
     */
    public int getEvaluationPeriodId() {
        return evaluationPeriodId;
    }

    /**
     *
     * @return
     */
    public Date getInitialDate() {
        return initialDate;
    }

    /**
     *
     * @return
     */
    public Date getFinalDate() {
        return finalDate;
    }

    /**
     *
     * @return
     */
    public int getPercentage() {
        return percentage;
    }

    /**
     *
     * @return
     */
    public String getAssociatedSCTitle() {
        return associatedSCTitle;
    }

    /**
     *
     * @return
     */
    public int getAssociattedSCTeacherId() {
        return associattedSCTeacherId;
    }

    /**
     *
     * @param percentage
     */
    public void setPercentage(final int percentage) {
        if (percentage > ConstantsDB.TABLE_EVALUATION_PERIOD_ATT_PERCENTAGE_MAX || percentage < ConstantsDB.TABLE_EVALUATION_PERIOD_ATT_PERCENTAGE_MIN) {
            throw new IllegalArgumentException("Invalid percentage.");
        }
        this.percentage = percentage;
    }
}