package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import java.util.Date;

/**
 * Models a behaviour attitude aspect (Edmodo badge) applied to a student.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class StudentAspect {

    private int idStudent;
    private int idTeacherAspect;
    private String name;
    private String associatedSubjectCompetenceTitle;
    private int associatedSubjectCompetenceTeacherId;
    private Date date;

    private StudentAspect() {
    }

    /**
     *
     * @param idStudent
     * @param idTeacherAspect
     * @param name
     * @param date
     * @param associatedSubjectCompetenceTitle
     * @param associatedSubjectCompetenceTeacherId
     * @throws IllegalArgumentException
     */
    public StudentAspect(final int idStudent, final int idTeacherAspect,
            final String name, final Date date //,final int idSCTeacher, final String scTitle
            , final String associatedSubjectCompetenceTitle,
            final int associatedSubjectCompetenceTeacherId) throws IllegalArgumentException {
        if (idStudent != ConstantsDB.TABLE_NULL_ID && idStudent < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid idStudent");
        }
        if (idTeacherAspect != ConstantsDB.TABLE_NULL_ID && idStudent < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid idBehaviourAttitudeAspect");
        }
        if (name == null || name.length() > ConstantsDB.TABLE_ASPECT_STUDENT_ATT_ASPECT_NAME_MAX) {
            throw new IllegalArgumentException("Invalid name");
        }
        if (date == null) {
            throw new IllegalArgumentException("Invalid date");
        }
        final int ASS_TITLE = associatedSubjectCompetenceTitle == null ? 0 : associatedSubjectCompetenceTitle.length();
        if (ASS_TITLE == 0 || ASS_TITLE > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_ASS_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid associated subject competence title");
        }
        if (associatedSubjectCompetenceTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid associated SubjectCompetence teacher id.");
        }
        this.idStudent = idStudent;
        this.idTeacherAspect = idTeacherAspect;
        this.name = name;
        this.date = date;
        this.associatedSubjectCompetenceTitle = associatedSubjectCompetenceTitle;
        this.associatedSubjectCompetenceTeacherId = associatedSubjectCompetenceTeacherId;
    }

    /**
     *
     * @return
     */
    public int getIdStudent() {
        return idStudent;
    }

    /**
     *
     * @return
     */
    public int getIdTeacherAspect() {
        return idTeacherAspect;
    }

    /**
     *
     * @return
     */
    public Date getDate() {
        return date;
    }

    /**
     *
     * @return
     */
    public String getAssociatedSubjectCompetenceTitle() {
        return associatedSubjectCompetenceTitle;
    }

    /**
     *
     * @return
     */
    public int getAssociatedSubjectCompetenceTeacherId() {
        return associatedSubjectCompetenceTeacherId;
    }

    /**
     *
     * @return
     */
    public String getName() {
        return name;
    }
}