package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import java.util.ArrayList;
import java.util.List;

/**
 * Models a student-assignment data.
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class StudentEvaluation {

    private Student student;
    private List<StudentCalificationReport> mStudentCalificationReport;
    private BonusPenalization mBonusPenalization;
    private String subjectCompetenceTitle;
    private int subjectCompetenceTeacherId;

    /**
     *
     * @param student
     * @param mStudentCalificationReport
     * @param mBonusPenalization
     * @param subjectCompetenceTitle
     * @param subjectCompetenceTeacherId
     * @throws IllegalArgumentException
     */
    public StudentEvaluation(final Student student, final List<StudentCalificationReport> mStudentCalificationReport, BonusPenalization mBonusPenalization, final String subjectCompetenceTitle, final int subjectCompetenceTeacherId) throws IllegalArgumentException {
        if (student == null) {
            throw new IllegalArgumentException("Invalid student");
        }
        if (subjectCompetenceTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid subject competence teacher id");
        }
        if (subjectCompetenceTitle == null || subjectCompetenceTitle.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid subject competence title");
        }
        this.student = student;
        this.mStudentCalificationReport = mStudentCalificationReport == null ? new ArrayList<StudentCalificationReport>() : mStudentCalificationReport;
        this.mBonusPenalization = mBonusPenalization;
        this.subjectCompetenceTitle = subjectCompetenceTitle;
        this.subjectCompetenceTeacherId = subjectCompetenceTeacherId;
    }

    /**
     *
     * @return
     */
    public Student getStudent() {
        return student;
    }

    /**
     *
     * @return
     */
    public List<StudentCalificationReport> getStudentCalificationReport() {
        return mStudentCalificationReport;
    }

    /**
     *
     * @return
     */
    public BonusPenalization getBonusPenalization() {
        return mBonusPenalization;
    }

    /**
     *
     * @return
     */
    public String getSubjectCompetenceTitle() {
        return subjectCompetenceTitle;
    }

    /**
     *
     * @return
     */
    public int getSubjectCompetenceTeacherId() {
        return subjectCompetenceTeacherId;
    }
}