package classcontrol.entity;

import classcontrol.dao.ConstantsDB;
import java.util.Date;

/**
 * Models a subject competence.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class SubjectCompetence {

    private String title;
    private String edmodoGroup;
    private String description;
    private int teacherId;
    private Date initialDate;
    private Date finalDate;
    private int associatedTeacherId;
    private String associatedTitle;
    private String nonAcademicDays;
    private int eachPositiveWeigth;
    private int eachNegativeWeigth;
    private int maxPositiveWeigth;
    private int maxNegativeWeigth;

    private SubjectCompetence() {
    }

    /**
     *
     * @param title
     * @param edmodoGroup
     * @param description
     * @param teacherId
     * @param initialDate
     * @param finalDate
     * @param associatedTeacherId
     * @param associatedTitle
     * @param nonAcademicDays
     * @param eachPositiveWeigth
     * @param eachNegativeWeigth
     * @param maxPositiveWeigth
     * @param maxNegativeWeigth
     * @throws IllegalArgumentException
     */
    public SubjectCompetence(final String title, final String edmodoGroup,
            final String description, final int teacherId,
            final Date initialDate, final Date finalDate, final int associatedTeacherId,
            final String associatedTitle, final String nonAcademicDays,
            final int eachPositiveWeigth, final int eachNegativeWeigth, final int maxPositiveWeigth,
            final int maxNegativeWeigth) throws IllegalArgumentException {
        if (title == null || title.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid title.");
        }
        if (edmodoGroup == null || edmodoGroup.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_ED_GROUP_MAX) {
            throw new IllegalArgumentException("Invalid edmodoGroup.");
        }
        if (description != null && description.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_DESCRIPTION_MAX) {
            throw new IllegalArgumentException("Invalid description.");
        }
        if (teacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid teacherId.");
        }
        if (initialDate == null) {
            throw new IllegalArgumentException("Invalid initialDate.");
        }
        if (finalDate == null) {
            throw new IllegalArgumentException("Invalid finalDate.");
        }
        if (associatedTeacherId != ConstantsDB.TABLE_NULL_ID && associatedTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid associatedTeacherId.");
        }
        if (associatedTitle != null && associatedTitle.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid associatedTitle.");
        }
        if (nonAcademicDays != null && nonAcademicDays.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_NON_ACADEMIC_DAYS_MAX) {
            throw new IllegalArgumentException("Invalid nonAcademicDays.");
        }
        if (eachPositiveWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_POSITIVE_MIN || eachPositiveWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_POSITIVE_MAX) {
            throw new IllegalArgumentException("Invalid eachPositiveWeigth.");
        }
        if (eachNegativeWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_NEGATIVE_MIN || eachNegativeWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_NEGATIVE_MAX) {
            throw new IllegalArgumentException("Invalid eachNegativeWeigth.");
        }
        if (maxPositiveWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_POSITIVE_MIN || maxPositiveWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_POSITIVE_MAX) {
            throw new IllegalArgumentException("Invalid maxPositiveWeigth.");
        }
        if (maxNegativeWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE_MIN || maxNegativeWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE_MAX) {
            throw new IllegalArgumentException("Invalid maxNegativeWeigth.");
        }
        this.title = title;
        this.edmodoGroup = edmodoGroup;
        this.description = description;
        this.teacherId = teacherId;
        this.initialDate = initialDate;
        this.finalDate = finalDate;
        this.associatedTeacherId = associatedTeacherId;
        this.associatedTitle = associatedTitle;
        this.nonAcademicDays = nonAcademicDays;
        this.eachPositiveWeigth = eachPositiveWeigth;
        this.eachNegativeWeigth = eachNegativeWeigth;
        this.maxPositiveWeigth = maxPositiveWeigth;
        this.maxNegativeWeigth = maxNegativeWeigth;
    }

    /**
     *
     * @return
     */
    public String getTitle() {
        return title;
    }

    /**
     *
     * @return
     */
    public String getEdmodoGroup() {
        return edmodoGroup;
    }

    /**
     *
     * @return
     */
    public String getDescription() {
        return description;
    }

    /**
     *
     * @return
     */
    public int getTeacherId() {
        return teacherId;
    }

    /**
     *
     * @return
     */
    public Date getInitialDate() {
        return initialDate;
    }

    /**
     *
     * @return
     */
    public Date getFinalDate() {
        return finalDate;
    }

    /**
     *
     * @return
     */
    public int getAssociatedTeacherId() {
        return associatedTeacherId;
    }

    /**
     *
     * @return
     */
    public String getAssociatedTitle() {
        return associatedTitle;
    }

    /**
     *
     * @return
     */
    public String getNonAcademicDays() {
        return nonAcademicDays;
    }

    /**
     *
     * @param nonAcademicDays
     */
    public void setNonAcademicDays(final String nonAcademicDays) {
        if (nonAcademicDays != null && nonAcademicDays.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_NON_ACADEMIC_DAYS_MAX) {
            throw new IllegalArgumentException("Invalid nonAcademicDays.");
        }
        this.nonAcademicDays = nonAcademicDays;
    }

    /**
     *
     * @param title
     */
    public void setTitle(final String title) {
        if (title == null || title.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid title.");
        }
        this.title = title;
    }

    /**
     *
     * @param edmodoGroup
     */
    public void setEdmodoGroup(final String edmodoGroup) {
        if (edmodoGroup == null || edmodoGroup.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_ID_ED_GROUP_MAX) {
            throw new IllegalArgumentException("Invalid edmodoGroup.");
        }
        this.edmodoGroup = edmodoGroup;
    }

    /**
     *
     * @param description
     */
    public void setDescription(final String description) {
        if (description != null && description.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_DESCRIPTION_MAX) {
            throw new IllegalArgumentException("Invalid description.");
        }
        this.description = description;
    }

    /**
     *
     * @param teacherId
     */
    public void setTeacherId(final int teacherId) {
        if (teacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid teacherId.");
        }
        this.teacherId = teacherId;
    }

    /**
     *
     * @param initialDate
     */
    public void setInitialDate(final Date initialDate) {
        if (initialDate == null) {
            throw new IllegalArgumentException("Invalid initialDate.");
        }
        this.initialDate = initialDate;
    }

    /**
     *
     * @param finalDate
     */
    public void setFinalDate(final Date finalDate) {
        if (finalDate == null) {
            throw new IllegalArgumentException("Invalid finalDate.");
        }
        this.finalDate = finalDate;
    }

    /**
     *
     * @param associatedTeacherId
     */
    public void setAssociatedTeacherId(final int associatedTeacherId) {
        if (associatedTeacherId != ConstantsDB.TABLE_NULL_ID && associatedTeacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid associatedTeacherId.");
        }
        this.associatedTeacherId = associatedTeacherId;
    }

    /**
     *
     * @param associatedTitle
     */
    public void setAssociatedTitle(final String associatedTitle) {
        if (associatedTitle != null && associatedTitle.length() > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid associatedTitle.");
        }
        this.associatedTitle = associatedTitle;
    }

    /**
     *
     * @return
     */
    public int getEachPositiveWeigth() {
        return eachPositiveWeigth;
    }

    /**
     *
     * @param eachPositiveWeigth
     */
    public void setEachPositiveWeigth(final int eachPositiveWeigth) {
        if (eachPositiveWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_POSITIVE_MIN || eachPositiveWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_POSITIVE_MAX) {
            throw new IllegalArgumentException("Invalid eachPositiveWeigth.");
        }
        this.eachPositiveWeigth = eachPositiveWeigth;
    }

    /**
     *
     * @return
     */
    public int getEachNegativeWeigth() {
        return eachNegativeWeigth;
    }

    /**
     *
     * @param eachNegativeWeigth
     */
    public void setEachNegativeWeigth(final int eachNegativeWeigth) {
        if (eachNegativeWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_NEGATIVE_MIN || eachNegativeWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_EACH_NEGATIVE_MAX) {
            throw new IllegalArgumentException("Invalid eachNegativeWeigth.");
        }
        this.eachNegativeWeigth = eachNegativeWeigth;
    }

    /**
     *
     * @return
     */
    public int getMaxPositiveWeigth() {
        return maxPositiveWeigth;
    }

    /**
     *
     * @param maxPositiveWeigth
     */
    public void setMaxPositiveWeigth(final int maxPositiveWeigth) {
        if (maxPositiveWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_POSITIVE_MIN || maxPositiveWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_POSITIVE_MAX) {
            throw new IllegalArgumentException("Invalid maxPositiveWeigth.");
        }
        this.maxPositiveWeigth = maxPositiveWeigth;
    }

    /**
     *
     * @return
     */
    public int getMaxNegativeWeigth() {
        return maxNegativeWeigth;
    }

    /**
     *
     * @param maxNegativeWeigth
     */
    public void setMaxNegativeWeigth(final int maxNegativeWeigth) {
        if (maxNegativeWeigth < ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE_MIN || maxNegativeWeigth > ConstantsDB.TABLE_SUBJECT_COMPETENCE_ATT_MAX_NEGATIVE_MAX) {
            throw new IllegalArgumentException("Invalid maxNegativeWeigth.");
        }
        this.maxNegativeWeigth = maxNegativeWeigth;
    }
}