package classcontrol.language;

import classcontrol.utils.Text;
import java.util.ArrayList;

/**
 *
 * Provides specified language data.
 *
 * ATTENTION:If any language java class names changes, class's methods must be
 * changed too.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class LanguageFactory {

    /**
     * English language identificator.
     */
    public final static int ID_LANGUAGE_ENGLISH = 0;
    /**
     * Spanish language identificator.
     */
    public final static int ID_LANGUAGE_SPANISH = 1;
    /**
     * Greek language identificator.
     */
    public final static int ID_LANGUAGE_GREEK = 2;
    /**
     * Default language identificator.
     */
    public final static int ID_LANGUAGE_DEFAULT = ID_LANGUAGE_ENGLISH;

    /**
     * Provides native language name.
     *
     * @param idLanguage Language idetificator.
     * @return Language name.
     */
    public static String getLanguageById(final int idLanguage) {
        final StringBuilder string = new StringBuilder("");
        final String ENGLISH_NAME = new EnglishLanguage().getLanguageName();
        switch (idLanguage) {
            case ID_LANGUAGE_ENGLISH:
                string.append(ENGLISH_NAME);
                break;
            case ID_LANGUAGE_SPANISH:
                string.append(new SpanishLanguage().getLanguageName());
                break;
            case ID_LANGUAGE_GREEK:
                string.append(new GreekLanguage().getLanguageName());
                break;
            default:
                string.append(ENGLISH_NAME);
                break;
        }
        return string.toString();
    }

    /**
     * Retruns a Class Control language identificator or
     * {@link LanguageFactory#ID_LANGUAGE_DEFAULT} if not matches.
     *
     * @param code
     * @returna Class Control language identificator or
     * {@link LanguageFactory#ID_LANGUAGE_DEFAULT} if not matches.
     */
    public static byte getLanguageIdByCode(final String code) {
        byte response = ID_LANGUAGE_DEFAULT;
        if (code != null) {

            if (code.toLowerCase().compareTo(new EnglishLanguage().getString(Text.HTML_LANG).toLowerCase()) == 0) {
                response = ID_LANGUAGE_ENGLISH;
            } else {
                if (code.toLowerCase().compareTo(new SpanishLanguage().getString(Text.HTML_LANG).toLowerCase()) == 0) {
                    response = ID_LANGUAGE_SPANISH;
                } else {
                    if (code.toLowerCase().compareTo(new GreekLanguage().getString(Text.HTML_LANG).toLowerCase()) == 0) {
                        response = ID_LANGUAGE_GREEK;
                    }
                }
            }
        }
        return response;
    }

    /**
     * Provides language Java fully qualified class name.
     *
     * @param idLanguage Language identificator
     * @return Languages class name.
     */
    public static String getLanguageClassById(final int idLanguage) {
        final StringBuilder string = new StringBuilder("classcontrol.language.");
        final String ENGLISH_NAME = "English";
        switch (idLanguage) {
            case ID_LANGUAGE_ENGLISH:
                string.append(ENGLISH_NAME);
                break;
            case ID_LANGUAGE_SPANISH:
                string.append("Spanish");
                break;
            case ID_LANGUAGE_GREEK:
                string.append("Greek");
                break;
            default:
                string.append(ENGLISH_NAME);
                break;
        }
        return string.append("Language").toString();
    }

    /**
     * Provides all available language names.
     *
     * @return List of all available language names.
     */
    public static ArrayList<Language> getAllLanguages() {
        final ArrayList<Language> languagesList = new ArrayList<Language>();
        languagesList.add(new Language(new EnglishLanguage().getLanguageName(), ID_LANGUAGE_ENGLISH));
        languagesList.add(new Language(new SpanishLanguage().getLanguageName(), ID_LANGUAGE_SPANISH));
        languagesList.add(new Language(new GreekLanguage().getLanguageName(), ID_LANGUAGE_GREEK));
        return languagesList;
    }
}