package classcontrol.language;

import java.util.ArrayList;

/**
 *
 * Provides specified language data.
 *
 *
 * ATTENTION:If any language java class names changes, class's methods must be
 * changed too.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class LanguageFactory {

    /**
     * English language identificator.
     */
    public final static int ID_LANGUAGE_ENGLISH = 0;
    /**
     * Spanish language identificator.
     */
    public final static int ID_LANGUAGE_SPANISH = 1;
    /**
     * Default language identificator.
     */
    public final static int ID_LANGUAGE_DEFAULT = ID_LANGUAGE_ENGLISH;

    /**
     * Provides native language name.
     *
     * @param idLanguage Language idetificator.
     * @return Language name.
     */
    public static String getLanguageById(final int idLanguage) {
        final StringBuilder string = new StringBuilder("");
        final String ENGLISH_NAME = new EnglishLanguage().getLanguageName();
        switch (idLanguage) {
            case ID_LANGUAGE_ENGLISH:
                string.append(ENGLISH_NAME);
                break;
            case ID_LANGUAGE_SPANISH:
                string.append(new SpanishLanguage().getLanguageName());
                break;
            default:
                string.append(ENGLISH_NAME);
                break;
        }
        return string.toString();
    }

    /**
     * Provides language Java fully qualified class name.
     *
     * @param idLanguage Language idetificator
     * @return Languages class name.
     */
    public static String getLanguageClassById(final int idLanguage) {
        final StringBuilder string = new StringBuilder("classcontrol.language.");
        final String ENGLISH_NAME = "English";
        switch (idLanguage) {
            case ID_LANGUAGE_ENGLISH:
                string.append(ENGLISH_NAME);
                break;
            case ID_LANGUAGE_SPANISH:
                string.append("Spanish");
                break;
            default:
                string.append(ENGLISH_NAME);
                break;
        }
        return string.append("Language").toString();
    }

    /**
     * Provides all available language names.
     *
     * @return List of all available language names.
     */
    public static ArrayList<Language> getAllLanguages() {
        final ArrayList<Language> languagesList = new ArrayList<Language>();
        languagesList.add(new Language(new EnglishLanguage().getLanguageName(), ID_LANGUAGE_ENGLISH));
        languagesList.add(new Language(new SpanishLanguage().getLanguageName(), ID_LANGUAGE_SPANISH));
        return languagesList;
    }
}