package classcontrol.servlet;

import classcontrol.controller.AbstractController;
import classcontrol.controller.ControllerFactory;
import classcontrol.controller.LanguageController;
import classcontrol.controller.LoginController;
import classcontrol.controller.LoginControllerException;
import classcontrol.controller.ParentStudentController;
import java.io.IOException;
import classcontrol.utils.Constants;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 1.Process all application's requests.
 *
 * 2.Implements security model:<br/>
 * 2.1.: Get Edmodo requester data to know if it is a valid user.<br/>
 * 2.2.: Send a flag to the next view to be showed thta comes from front
 * controller.<br/><br/>
 *
 * 3. Sets current session language settings.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class FrontController extends HttpServlet {

    /**
     * Processes requests for both HTTP
     * <code>GET</code> and
     * <code>POST</code> methods.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        // 1. Encoding
        request.setCharacterEncoding("UTF-8");
        response.setContentType("text/html;charset=UTF-8");
//        final Enumeration<String> myParameters = request.getParameterNames();
//        String name;
//        while (myParameters.hasMoreElements()) {
//            name = myParameters.nextElement();
//            System.out.println("\"" + name + "\": " + request.getParameter(name));
//        }
        try {
            // 1. SECURITY MODEL (1): Get data from requester (from Edmodo).
            // If requester is not an Edmodo user: 403 statuts response code.
            // with new LoginControllerException()
            final AbstractController loginController = new LoginController();
            loginController.init(request);
            loginController.execute();
            //////////////////////////////////////////////////
            String showPage = null;
            ///////////////////////////////////////////////////
            // 2. If controller is passed by parameter.
            final String possibleController = request.getParameter(Constants.CONTROLLER_ID);
            boolean goHome = false;
            boolean isPDF = false;
            boolean isJSON = false;
            if (possibleController != null) {
                final AbstractController control = (AbstractController) Class.forName(ControllerFactory.getControllerByIdForm(Integer.parseInt(request.getParameter(Constants.CONTROLLER_ID)))).newInstance();
                control.init(request);
                control.execute();

                // 2.1.a Get possible JSON AJAX Data, not dispatch any web page
                final String responseJson = control.responseJson();
                if (responseJson != null) {
                    response.setContentType("application/json;charset=UTF-8");
                    final PrintWriter out = response.getWriter();
                    out.print(responseJson);
                    out.flush();
                    isJSON = true;

                } else {
                    isPDF = control.responsePDF();
                    if (isPDF) {
                        final ByteArrayOutputStream myPDF = (ByteArrayOutputStream) request.getAttribute(Constants.CONTROLLER_PDF_OBJECT);
                        if (myPDF != null) {
                            // Setting some response headers
                            response.setHeader("Expires", "0");
                            response.setHeader("Cache-Control",
                                    "must-revalidate, post-check=0, pre-check=0");
                            response.setHeader("Pragma", "public");
                            // Setting the content type
                            response.setContentType("application/pdf");
                            response.setHeader("Content-disposition", "inline; filename=ClassControl.pdf");
                            // The contentlength
                            response.setContentLength(myPDF.size());
                            // write ByteArrayOutputStream to the ServletOutputStream
                            final OutputStream os = response.getOutputStream();
                            myPDF.writeTo(os);
                            os.flush();
                            os.close();
                        }
                    } else {
                        // 2.1.b. Dispatch a web page
                        showPage = control.getReturnPage();
                        if (showPage.compareTo(AbstractController.HOME_URL) == 0) {
                            goHome = true;
                        }
                    }
                }
            } else {
                goHome = true;
            }
            if (!isJSON) {
                // 3. SECURITY MODEL (2): enable .jsp view only for this request.
                request.setAttribute(Constants.COME_FROM_FRONT_CONTROLLER, true);
                // 4. Language current session settings
                final AbstractController lanController = new LanguageController();
                lanController.init(request);
                lanController.execute();
                if (!isPDF) {
                    if (goHome) {
                        // 2.1.c. Return Teacher, Student or Parent index according current role.
                        final byte role = (Byte) request.getSession().getAttribute(Constants.SESSION_ID_WEB_ROLE);
                        showPage = role == Constants.SESSION_ID_ROLE_TEACHER ? "/Teacher/TeacherIndex.jsp"
                                : role == Constants.SESSION_ID_ROLE_PARENT ? "/Parent/ParentIndex.jsp"
                                : role == Constants.SESSION_ID_ROLE_STUDENT ? "/Student/StudentIndex.jsp" : "";
                        if (role == Constants.SESSION_ID_ROLE_PARENT) {
                            final AbstractController parentStudentController = new ParentStudentController();
                            parentStudentController.init(request);
                            parentStudentController.execute();
                        }
                    }
                    request.getRequestDispatcher(showPage).forward(request, response);
                }
            }
        } catch (final LoginControllerException e) {
            // No valid login
            response.setStatus(HttpServletResponse.SC_FORBIDDEN);
            request.getRequestDispatcher("/Error/Error403.jsp").forward(request, response);
        } catch (final Exception e) {
            //e.printStackTrace();
            throw new javax.servlet.ServletException(e.getMessage());//Para que vaya a la pagina de error correspondiente con el mensaje cojido.
        }
    }

    // <editor-fold defaultstate="collapsed" desc="HttpServlet methods. Click on the + sign on the left to edit the code.">
    /**
     * Handles the HTTP
     * <code>GET</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /**
     * Handles the HTTP
     * <code>POST</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }
}