package classcontrol.utils;

import classcontrol.language.ILanguage;
import classcontrol.language.LanguageFactory;
import javax.servlet.http.HttpServletRequest;

/**
 * Language mediator. Returns texts in a specified language.
 *
 * @see {@link Constants#SESSION_ID_LANGUAGE}.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class CurrentLanguage {

    /**
     * Get a specified text in current session language. If any language is
     * setted or current language is invalid, default language text is returned.
     *
     * @param idText Text to get.
     * @param request Current session request.
     * @return A specified text in current session language.
     */
    public static String getString(final int idText, final HttpServletRequest request) {
        try {
            final Integer languageSessionID = (Integer) request.getSession().
                    getAttribute(Constants.SESSION_ID_LANGUAGE);
            return ((ILanguage) Class.forName(LanguageFactory.
                    getLanguageClassById(languageSessionID != null
                    ? languageSessionID : LanguageFactory.ID_LANGUAGE_DEFAULT))
                    .newInstance()).getString(idText);
        } catch (final Exception ex) {
            return "";
        }
    }
}