SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

CREATE SCHEMA IF NOT EXISTS `heroku_c03e670d5e2f9b7` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `heroku_c03e670d5e2f9b7` ;

-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`teacher`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`teacher` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`teacher` (
  `id_teacher` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_teacher`))
ENGINE = InnoDB;

CREATE UNIQUE INDEX `id_edmodo_UNIQUE` ON `heroku_c03e670d5e2f9b7`.`teacher` (`id_edmodo` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`subject_competence`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`subject_competence` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`subject_competence` (
  `teacher_id` INT NOT NULL,
  `title` VARCHAR(45) NOT NULL,
  `subject_competence_teacher_id` INT NULL,
  `subject_competence_title` VARCHAR(45) NULL,
  `edmodo_group` VARCHAR(45) NOT NULL,
  `initial_date` DATE NOT NULL,
  `final_date` DATE NOT NULL,
  `description` VARCHAR(100) NULL,
  `non_academic_days` VARCHAR(5800) NULL,
  `each_positive_weight` INT(3) NOT NULL DEFAULT 0,
  `each_negative_weight` INT(3) NOT NULL DEFAULT 0,
  `max_positive_weight` INT(3) NOT NULL DEFAULT 0,
  `max_negative_weight` INT(3) NOT NULL DEFAULT 0,
  PRIMARY KEY (`teacher_id`, `title`),
  CONSTRAINT `fk_subject_competence_teacher1`
    FOREIGN KEY (`teacher_id`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`teacher` (`id_teacher`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_subject_competence_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id` , `subject_competence_title`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB;

CREATE INDEX `fk_subject_competence_teacher1_idx` ON `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` ASC);

CREATE INDEX `fk_subject_competence_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`subject_competence` (`subject_competence_teacher_id` ASC, `subject_competence_title` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect` (
  `teacher_id_teacher` INT NOT NULL,
  `name` VARCHAR(50) NOT NULL COMMENT 'Because Edmodo not provides a way to get the badge name without an user.',
  `description` VARCHAR(140) NULL COMMENT 'Because Edmodo not provides a way to get the badge name without an user.',
  `edmodo_id` VARCHAR(45) NOT NULL,
  `type` BIT NOT NULL DEFAULT 1 COMMENT '0: Negative\n1: Positive',
  PRIMARY KEY (`teacher_id_teacher`, `name`),
  CONSTRAINT `fk_behaviour_attitude_aspect_teacher1`
    FOREIGN KEY (`teacher_id_teacher`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`teacher` (`id_teacher`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_behaviour_attitude_aspect_teacher1_idx` ON `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect` (`teacher_id_teacher` ASC);

CREATE UNIQUE INDEX `edmodo_id_UNIQUE` ON `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect` (`edmodo_id` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`assignment`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`assignment` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`assignment` (
  `id_assignment` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `associated_weight` INT(3) NOT NULL DEFAULT 0,
  `type` TINYINT(1) NOT NULL DEFAULT 0 COMMENT '0: online grade\n1: offline grade\n2: online assignment\n3: offlie assignment',
  `max_grade` DOUBLE NOT NULL DEFAULT 0,
  `date` DATE NOT NULL,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id_assignment`),
  CONSTRAINT `fk_assignment_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_assignment_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`assignment` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`evaluable_item`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item` (
  `assignment_id_fk` INT NOT NULL,
  `name` VARCHAR(30) NOT NULL,
  `associated_weight` INT(3) NOT NULL DEFAULT 0,
  PRIMARY KEY (`assignment_id_fk`, `name`),
  CONSTRAINT `fk_evaluable_item_assignment1`
    FOREIGN KEY (`assignment_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`assignment` (`id_assignment`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_evaluable_item_assignment1_idx` ON `heroku_c03e670d5e2f9b7`.`evaluable_item` (`assignment_id_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`student` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`student` (
  `id_student` INT NOT NULL AUTO_INCREMENT,
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_student`))
ENGINE = InnoDB;

CREATE UNIQUE INDEX `id_edmodo_UNIQUE` ON `heroku_c03e670d5e2f9b7`.`student` (`id_edmodo` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`evaluable_item_student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_student` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_student` (
  `student_id_fk` INT NOT NULL,
  `score` DOUBLE NULL,
  `evaluable_item_assignment_id_fk` INT NOT NULL,
  `evaluable_item_name_fk` VARCHAR(30) NOT NULL,
  PRIMARY KEY (`student_id_fk`, `evaluable_item_assignment_id_fk`, `evaluable_item_name_fk`),
  CONSTRAINT `fk_alumnoHasevaluable_item_alumno`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_evaluable_item_student_evaluable_item1`
    FOREIGN KEY (`evaluable_item_assignment_id_fk` , `evaluable_item_name_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`evaluable_item` (`assignment_id_fk` , `name`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_alumnoHasevaluable_item_alumno_idx` ON `heroku_c03e670d5e2f9b7`.`evaluable_item_student` (`student_id_fk` ASC);

CREATE INDEX `fk_evaluable_item_student_evaluable_item1_idx` ON `heroku_c03e670d5e2f9b7`.`evaluable_item_student` (`evaluable_item_assignment_id_fk` ASC, `evaluable_item_name_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`bonus_penalization`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`bonus_penalization` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`bonus_penalization` (
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `student_id_fk` INT NOT NULL,
  `score` DOUBLE NOT NULL,
  `reason` VARCHAR(45) NULL,
  PRIMARY KEY (`subject_competence_teacher_id_fk`, `subject_competence_title_fk`, `student_id_fk`),
  CONSTRAINT `fk_subject_competence_has_alumno_alumno`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_bonus_penalization_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_subject_competence_has_alumno_alumno2_idx` ON `heroku_c03e670d5e2f9b7`.`bonus_penalization` (`student_id_fk` ASC);

CREATE INDEX `fk_bonus_penalization_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`bonus_penalization` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`qualification`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`qualification` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`qualification` (
  `assignment_id_fk` INT NOT NULL,
  `student_id_fk` INT NOT NULL,
  `bonus_penalization` DOUBLE NULL DEFAULT 0.0,
  `reason_bonus_penalization` VARCHAR(45) NULL,
  `optional_comment` VARCHAR(45) NULL,
  `visible_student` BIT(1) NOT NULL DEFAULT 1 COMMENT '0: NO\n1: YES',
  `visible_parent` BIT(1) NOT NULL DEFAULT 1 COMMENT '0: NO\n1: YES',
  PRIMARY KEY (`assignment_id_fk`, `student_id_fk`),
  CONSTRAINT `fk_assignment_has_alumno_assignment1`
    FOREIGN KEY (`assignment_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`assignment` (`id_assignment`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_assignment_has_alumno_alumno1`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_assignment_has_alumno_alumno1_idx` ON `heroku_c03e670d5e2f9b7`.`qualification` (`student_id_fk` ASC);

CREATE INDEX `fk_assignment_has_alumno_assignment1_idx` ON `heroku_c03e670d5e2f9b7`.`qualification` (`assignment_id_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`aspect_student`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`aspect_student` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`aspect_student` (
  `student_id_fk` INT NOT NULL,
  `aspect_teacher_id_fk` INT NOT NULL,
  `aspect_name_fk` VARCHAR(50) NOT NULL,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `date` DATE NOT NULL,
  PRIMARY KEY (`student_id_fk`, `aspect_teacher_id_fk`, `aspect_name_fk`, `subject_competence_teacher_id_fk`, `subject_competence_title_fk`),
  CONSTRAINT `fk_alumno_has_behaviour_attitude_aspect_alumno1`
    FOREIGN KEY (`student_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_aspect_student_behaviour_attitude_aspect1`
    FOREIGN KEY (`aspect_teacher_id_fk` , `aspect_name_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect` (`teacher_id_teacher` , `name`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_aspect_student_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_alumno_has_behaviour_attitude_aspect_alumno1_idx` ON `heroku_c03e670d5e2f9b7`.`aspect_student` (`student_id_fk` ASC);

CREATE INDEX `fk_aspect_student_behaviour_attitude_aspect1_idx` ON `heroku_c03e670d5e2f9b7`.`aspect_student` (`aspect_teacher_id_fk` ASC, `aspect_name_fk` ASC);

CREATE INDEX `fk_aspect_student_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`aspect_student` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`evaluation_period`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluation_period` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluation_period` (
  `id_evaluation_period` INT NOT NULL AUTO_INCREMENT,
  `initial_date` DATE NOT NULL,
  `final_date` DATE NOT NULL,
  `percentage` INT(3) NOT NULL DEFAULT 0,
  `subject_competence_teacher_id_fk` INT NOT NULL,
  `subject_competence_title_fk` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`id_evaluation_period`),
  CONSTRAINT `fk_evaluation_period_subject_competence1`
    FOREIGN KEY (`subject_competence_teacher_id_fk` , `subject_competence_title_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_evaluation_period_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`evaluation_period` (`subject_competence_teacher_id_fk` ASC, `subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`absence`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`absence` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`absence` (
  `student_absence_student_id_fk` INT NOT NULL,
  `student_absence_subject_competence_teacher_id_fk` INT NOT NULL,
  `student_absence_subject_competence_title_fk` VARCHAR(45) NOT NULL,
  `dates` VARCHAR(5500) NULL,
  PRIMARY KEY (`student_absence_student_id_fk`, `student_absence_subject_competence_teacher_id_fk`, `student_absence_subject_competence_title_fk`),
  CONSTRAINT `fk_student_has_subject_competence_student1`
    FOREIGN KEY (`student_absence_student_id_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`student` (`id_student`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_student_has_subject_competence_subject_competence1`
    FOREIGN KEY (`student_absence_subject_competence_teacher_id_fk` , `student_absence_subject_competence_title_fk`)
    REFERENCES `heroku_c03e670d5e2f9b7`.`subject_competence` (`teacher_id` , `title`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;

CREATE INDEX `fk_student_has_subject_competence_student1_idx` ON `heroku_c03e670d5e2f9b7`.`absence` (`student_absence_student_id_fk` ASC);

CREATE INDEX `fk_student_has_subject_competence_subject_competence1_idx` ON `heroku_c03e670d5e2f9b7`.`absence` (`student_absence_subject_competence_teacher_id_fk` ASC, `student_absence_subject_competence_title_fk` ASC);


-- -----------------------------------------------------
-- Table `heroku_c03e670d5e2f9b7`.`parent`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`parent` ;

CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`parent` (
  `id_edmodo` VARCHAR(45) NOT NULL,
  `id_language` INT NOT NULL DEFAULT 0 COMMENT '0: English\n1: Spanish',
  PRIMARY KEY (`id_edmodo`))
ENGINE = InnoDB
COMMENT = 'The purpose of this table is to keep parent\'s favourite lang /* comment truncated */ /*uage system.*/';

CREATE UNIQUE INDEX `id_edmodo_UNIQUE` ON `heroku_c03e670d5e2f9b7`.`parent` (`id_edmodo` ASC);

USE `heroku_c03e670d5e2f9b7` ;

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`assignment_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`assignment_view` (`id_assignment` INT, `id_edmodo` INT, `associated_weight` INT, `type` INT, `max_grade` INT, `date` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`evaluation_period_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluation_period_view` (`id_evaluation_period` INT, `initial_date` INT, `final_date` INT, `percentage` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`qualification_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`qualification_view` (`assignment_id_fk` INT, `student_id_fk` INT, `bonus_penalization` INT, `reason_bonus_penalization` INT, `optional_comment` INT, `visible_student` INT, `visible_parent` INT, `teacher_id` INT, `title` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`evaluable_item_student_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_student_view` (`student_id_fk` INT, `score` INT, `evaluable_item_assignment_id_fk` INT, `evaluable_item_name_fk` INT, `teacher_id` INT, `title` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`bonus_penalization_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`bonus_penalization_view` (`subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT, `student_id_fk` INT, `score` INT, `reason` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`aspect_student_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`aspect_student_view` (`student_id_fk` INT, `aspect_teacher_id_fk` INT, `aspect_name_fk` INT, `subject_competence_teacher_id_fk` INT, `subject_competence_title_fk` INT, `date` INT, `edmodo_id` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`evaluable_item_assignment_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_assignment_view` (`subject_competence_title_fk` INT, `subject_competence_teacher_id_fk` INT, `assignment_id_fk` INT, `name` INT, `associated_weight` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect_view` (`teacher_id_teacher` INT, `name` INT, `description` INT, `edmodo_id` INT, `type` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`absence_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`absence_view` (`student_absence_student_id_fk` INT, `student_absence_subject_competence_teacher_id_fk` INT, `student_absence_subject_competence_title_fk` INT, `dates` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`subject_competence_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`subject_competence_view` (`teacher_id` INT, `title` INT, `subject_competence_teacher_id` INT, `subject_competence_title` INT, `edmodo_group` INT, `initial_date` INT, `final_date` INT, `description` INT, `non_academic_days` INT, `each_positive_weight` INT, `each_negative_weight` INT, `max_positive_weight` INT, `max_negative_weight` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`student_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`student_view` (`id_student` INT, `id_edmodo` INT, `id_language` INT);

-- -----------------------------------------------------
-- Placeholder table for view `heroku_c03e670d5e2f9b7`.`teacher_view`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `heroku_c03e670d5e2f9b7`.`teacher_view` (`id_teacher` INT, `id_edmodo` INT, `id_language` INT);

-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`assignment_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`assignment_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`assignment_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `assignment_view` AS SELECT * FROM assignment;

-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`evaluation_period_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluation_period_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluation_period_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `evaluation_period_view` AS SELECT * FROM evaluation_period;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`qualification_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`qualification_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`qualification_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `qualification_view` AS SELECT qualification.*,subject_competence.teacher_id,subject_competence.title FROM qualification,subject_competence
;

-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`evaluable_item_student_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_student_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_student_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `evaluable_item_student_view` AS SELECT evaluable_item_student.*,subject_competence.teacher_id,subject_competence.title FROM evaluable_item_student,subject_competence;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`bonus_penalization_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`bonus_penalization_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`bonus_penalization_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `bonus_penalization_view` AS SELECT * FROM bonus_penalization;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`aspect_student_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`aspect_student_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`aspect_student_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `aspect_student_view` AS SELECT aspect_student.*,edmodo_id FROM aspect_student,behaviour_attitude_aspect WHERE name=aspect_name_fk AND teacher_id_teacher=aspect_teacher_id_fk
;

-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`evaluable_item_assignment_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_assignment_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`evaluable_item_assignment_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `evaluable_item_assignment_view` AS SELECT assignment.subject_competence_title_fk,assignment.subject_competence_teacher_id_fk,evaluable_item.* FROM evaluable_item,assignment WHERE assignment_id_fk=id_assignment;

-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`behaviour_attitude_aspect_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `behaviour_attitude_aspect_view` AS SELECT * FROM behaviour_attitude_aspect;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`absence_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`absence_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`absence_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `absence_view` AS SELECT * FROM absence;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`subject_competence_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`subject_competence_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`subject_competence_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `subject_competence_view` AS SELECT * FROM subject_competence;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`student_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`student_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`student_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `student_view` AS SELECT * FROM student;


-- -----------------------------------------------------
-- View `heroku_c03e670d5e2f9b7`.`teacher_view`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `heroku_c03e670d5e2f9b7`.`teacher_view` ;
DROP TABLE IF EXISTS `heroku_c03e670d5e2f9b7`.`teacher_view`;
USE `heroku_c03e670d5e2f9b7`;
CREATE  OR REPLACE VIEW `teacher_view` AS SELECT * FROM teacher
;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
