package classcontrol.controller;

import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Absence;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * Shows student's absences for a student or nothing if various students are
 * selected.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class AbsenceStudent2Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        String myStudentReport = this.request.getParameter(Constants.PARAMETER_COMES_FROM_REPORT);
        if (myStudentReport != null) {
            final JSONObject mjson;
            try {
                mjson = new JSONArray(EdmodoAPI.users((String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), new String[]{myStudentReport})).getJSONObject(0);
                myStudentReport = mjson.getString(EdmodoAPI.API_FIRST_NAME_KEY) + ' ' + mjson.getString(EdmodoAPI.API_LAST_NAME_KEY) + ConstantsForm.SEPARATOR + myStudentReport;
            } catch (final JSONException ex) {
                throw new ControllerException();
            }
        }
        final String[] selectedStudents = myStudentReport != null ? new String[]{myStudentReport} : this.request.getParameterValues(ConstantsForm.ATTEND_ABSENCES_STUDENTS);
        final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(subjectCompetenceSelected);
        final int SIZE = selectedStudents == null ? 0 : selectedStudents.length;
        if (SIZE == 0) {
            throw new ControllerException(CurrentLanguage.getString(Text.S_C_ATTEND_AT_LEAST_ONE, request));
        }
        if (SIZE == 1) {
            // Show all student's absences.
            // Not show any absence if two or more students were selected.
            final String onlySelectedUser = selectedStudents[0];
            final int possibleSeparator = onlySelectedUser.lastIndexOf(ConstantsForm.SEPARATOR);
            final String edmodoStudentId = onlySelectedUser.substring(possibleSeparator == -1 ? 0 : possibleSeparator + ConstantsForm.SEPARATOR.length());
            // All student's subject / competence absences.
            final Persistence myPersistence = new Persistence();

            final List<Absence> mList = myPersistence.getAbsencesSubjectCompetence(mSubjectCompetence.getTeacherId(), mSubjectCompetence.getTitle());
            final int idStudent = myPersistence.getStudentId(edmodoStudentId);
            // If 1 student: show all its absences.
            final int ABSENCES_SIZE = mList.size();
            String mStudentAbsences = "";
            boolean find = false;
            int counter = 0;
            Absence currentAbsence;
            while (!find && counter < ABSENCES_SIZE) {
                currentAbsence = mList.get(counter);
                if (currentAbsence.getStudentId() == idStudent) {
                    mStudentAbsences = currentAbsence.getDates();
                    find = true;
                }
                counter++;
            }
            this.request.setAttribute(Constants.ATT_ABSENCE_ABSENCES_LIST, mStudentAbsences);
        }
        this.request.setAttribute(Constants.ATT_ATTEND_INITIAL_DATE, mSubjectCompetence.getInitialDate());
        this.request.setAttribute(Constants.ATT_ATTEND_FINAL_DATE, mSubjectCompetence.getFinalDate());
        this.request.setAttribute(Constants.ATT_ABSENCE_STUDENTS_LIST, selectedStudents);
        this.request.setAttribute(Constants.ATT_NON_ACADEMIC_DAYS, mSubjectCompetence.getNonAcademicDays());
    }
}