package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.edmodo.EdmodoUtil;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 * Shows an attend report for a subject competence.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class AttendReportController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int scIndex = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        switch ((Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) request.getSession().getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(scIndex);
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getAttendReport(mSubjectCompetence, request, true, null, null, ConstantsDB.TABLE_NULL_ID, EdmodoUtil.getGroupStudents(mSubjectCompetence.getEdmodoGroup(), request, false)));
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                final Student student = new StudentUtil(request).getAndSetAttributeStudent(idEdmodo);
                final SubjectCompetence mSC = ((List<SubjectCompetence>) session.getAttribute(idEdmodo)).get(scIndex);
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getAttendReport(mSC, request, true, null, null, student.getIdStudent(), EdmodoUtil.getGroupStudents(mSC.getEdmodoGroup(), request, false)));
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParentUtil = new ParentUtil(request);
                final Student studentParent = mParentUtil.getAndSetAttributeStudent();
                mParentUtil.checkChildren(studentParent, idEdmodo);
                final SubjectCompetence currentSC = ((List<SubjectCompetence>) session.getAttribute(studentParent.getIdEdmodo())).get(scIndex);
                request.setAttribute(Constants.ATT_HTML_TABLE, TableHtml.getAttendReport(currentSC, request, true, null, null, studentParent.getIdStudent(), EdmodoUtil.getGroupStudents(currentSC.getEdmodoGroup(), request, false)));
                break;
        }
    }
}