package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Assignment;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Date;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * Create subject / competence controller.<br/>
 * Sets initial and final dates in two request attributes.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class CreateAssignment2Controller extends AbstractController {

    private String nextUrl = null;

    @Override
    public final void execute() throws ControllerException {
        final HttpSession mSession = this.request.getSession();
        // Security
        final String idEdmodoUser = (String) mSession.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoUser == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int currentSC = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) mSession.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(currentSC);
        final String ERROR_MSG = CurrentLanguage.getString(Text.NO_VALID_ARGUMENT, this.request) + ": ";
        // 1. Get data:
        // 1.1. Title
        // No null
        // Min and max
        final String title = this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_TITLE);
        if (title == null || title.length() == 0 || title.length() > ConstantsDB.CREATE_ASSIGNMENT_TITLE_MAX) {
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_TITLE);
        }
        // 1.2. Date
        // No null // No before - after subject competence's initial and end dates.
        Date date;
        try {
            date = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DATE));
            if (date.before(mSubjectCompetence.getInitialDate())
                    || date.after(mSubjectCompetence.getFinalDate())) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_DATE);
        }
        // 1.3. Type
        // No null
        // Correct type
        byte type;
        final byte type1 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_INDEX];
        final byte type2 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_INDEX];
        final byte type3 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_ASSIGNMENT_INDEX];
        final byte type4 = ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_ASSIGNMENT_INDEX];
        try {
            type = Byte.parseByte(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_TYPE));
            if (type != type1 && type != type2 && type != type3 && type != type4) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            //ex.printStackTrace();
            throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_TYPE);
        }
        // 1.4. Maximum qualification
        // No null
        // Min and max
        boolean showError = false;
        int qualificationMax = ConstantsForm.CREATE_ASSIGNMENT_QUALIFICATION_MIN - 1;
        try {
            qualificationMax = (int) Math.round(Double.parseDouble(this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_QUALIFICATION)));
        } catch (final Exception ex) {
            showError = true;
        }
        if (showError || qualificationMax < ConstantsForm.CREATE_ASSIGNMENT_QUALIFICATION_MIN || qualificationMax > ConstantsForm.CREATE_ASSIGNMENT_QUALIFICATION_MAX) {
            //throw new ControllerException(ERROR_MSG + ConstantsForm.CREATE_ASSIGNMENT_QUALIFICATION);
        }
        // 1.5. Description
        String description = this.request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DESCRIPTION);
        int DES_SIZE;
        if (description != null) {
            DES_SIZE = description.length();
            description = DES_SIZE > ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX ? description.substring(0, DES_SIZE - ConstantsDB.CREATE_ASSIGNMENT_DESCRIPTION_MAX) : DES_SIZE == 0 ? null : description;
        }
        try {
            final String userToken = (String) mSession.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY);
            final String edmodoGroup = mSubjectCompetence.getEdmodoGroup();
            final String edmodoId = type == type1 || type == type2
                    ? new JSONObject(EdmodoAPI.newGrade(userToken, title, qualificationMax, edmodoGroup)).getString(EdmodoAPI.API_GRADE_ID_KEY)
                    : type == type3 || type == type4
                    ? new JSONObject(EdmodoAPI.createAssignment(userToken, idEdmodoUser, title, description, date, qualificationMax, edmodoGroup)).getString(EdmodoAPI.API_ASSIGNMENT_ID_KEY) : null;
            final Persistence mPersistence = new Persistence();
            if (edmodoId != null) {
                mPersistence.insertAssignment(new Assignment(ConstantsDB.TABLE_NULL_ID,
                        title, description, type, edmodoId, qualificationMax, ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT_MIN,
                        date, mSubjectCompetence.getTitle(), mSubjectCompetence.getTeacherId()));
            }
            // Set redirect url
            final String defineEvaluableItem = request.getParameter(ConstantsForm.CREATE_ASSIGNMENT_DEFINE_EVALUABLE_ITEMS);
            String evaluableItems = "/?" + Constants.PARAMETER_SUBJECT_COMPETENCE_SELECTED + '=' + currentSC + '&' + Constants.CONTROLLER_ID + '=';
            final boolean goEvaluableItem =
                    Byte.parseByte(defineEvaluableItem) == ConstantsForm.CREATE_ASSIGNMENT_DEFINE_EVALUABLE_ITEMS_YES;
            evaluableItems += goEvaluableItem
                    ? "" + Constants.CONTROLLER_ID_EVALUABLE_ITEM
                    + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/Assignment/EvaluableItem.jsp" + '&' + Constants.PARAMETER_ASSIGNMENT_SELECTED + '='
                    + mPersistence.getAssignment(edmodoId).getIdAssignment() : "";

            if (!goEvaluableItem) {
                evaluableItems += "" + Constants.CONTROLLER_ID_SUBJECT_COMPETENCE + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/SubjectCompetence/AssignmentsSubjectCompetence.jsp";
            } else {
                nextUrl = evaluableItems;
            }
            this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, evaluableItems);
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException();

            //ex.printStackTrace();
        }
    }

    @Override
    public final String getReturnPage() {
        final String url = request.getParameter(Constants.CONTROLLER_NEXT_URL);
        return nextUrl != null ? nextUrl : url == null ? HOME_URL : url;
    }
}