package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.Date;
import javax.servlet.http.HttpSession;

/**
 *
 *
 * Example:<br/>
 * Today: 17/04/14<br/>Minium: -1y: 17/04/13<br/> Maxium: +2y 17/04/16<br/>
 * 365.24*3=1095.72 possible days maxium to be non academic.
 * yyyy{dd/MMdd/MM..dd/MM}yyyy{dd/MMdd/MM..dd/MM}yyyy{dd/MMdd/MM..dd/MM}
 *
 * YEARS=3
 *
 *
 * yyyy{}.length()=6. 6*YEARS=18 is the max length in YEARS years (years).
 *
 *
 * dd/MM.length()=5. 5*(365.33*YEARS)=5480 is the max length in YEARS years
 * (days). {1096 days max: {@link ConstanstForm#SUBJECT_COMPETENCE_MAX_DURATION_DAYS}
 *
 *
 * Total=18+5480=5498 possible chars to be non academic in YEARS years.
 * {@link ConstantsDB#TABLE_SUBJECT_COMPETENCE_ATT_NON_ACADEMIC_DAYS_MAX}
 * Checked by Cristian TG 17/04/14
 *
 *
 * Finally: {@link ConstantsDB#TABLE_SUBJECT_COMPETENCE_ATT_NON_ACADEMIC_DAYS_MAX} is the max length of a subject competence non-academic days
 * record in database.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public class DefineAcademicDaysController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final int subjectCompetenceSelected = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final ArrayList<SubjectCompetence> mSubjectsCompetences = (ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES);
        final SubjectCompetence mySubjectCompetence = mSubjectsCompetences.get(subjectCompetenceSelected);
        final Date initialDate = mySubjectCompetence.getInitialDate();
        final Date finalDate = mySubjectCompetence.getFinalDate();
        this.request.setAttribute(Constants.ATT_ATTEND_INITIAL_DATE, initialDate);
        this.request.setAttribute(Constants.ATT_ATTEND_FINAL_DATE, finalDate);
        this.request.setAttribute(Constants.ATT_NON_ACADEMIC_DAYS, mySubjectCompetence.getNonAcademicDays());
        StringBuilder mySubjectCompetencesSameDates = new StringBuilder();
        String currentTitle;
        final String myTitle = mySubjectCompetence.getTitle();
        final byte INITIAL = 0;
        int counter = INITIAL;
        boolean firstTime = true;
        for (final SubjectCompetence current : mSubjectsCompetences) {
            currentTitle = current.getTitle();
            if (currentTitle.compareTo(myTitle) != 0 && initialDate.compareTo(current.getInitialDate()) == 0
                    && finalDate.compareTo(current.getFinalDate()) == 0) {
                if (firstTime) {
                    mySubjectCompetencesSameDates.
                            append("<input type=\"checkbox\" name=\"").append(ConstantsForm.ATTEND_NON_ACADEMIC_DAYS_ALL).append("\" value=\"").append(ConstantsForm.ATTEND_NON_ACADEMIC_DAYS_ALL).append("\" > ").append(CurrentLanguage.getString(Text.APPLY_ALL_NEW_CHANGES, request)).append(": <b>");
                    firstTime = false;
                }
                mySubjectCompetencesSameDates.append(currentTitle).append(ConstantsForm.SEPARATOR);
                counter++;
            }
        }
        if (counter > INITIAL) {
            final int SIZE = mySubjectCompetencesSameDates.length();
            mySubjectCompetencesSameDates.delete(SIZE - ConstantsForm.SEPARATOR.length(), SIZE).append("</b><br/><br/><br/>");
            this.request.setAttribute(Constants.ATT_NON_ACADEMIC_DAYS_S_C_SAME_DATES, mySubjectCompetencesSameDates);
        }

    }
}