package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.edmodo.EdmodoUtil;
import classcontrol.language.LanguageFactory;
import classcontrol.utils.Constants;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 * Handles all business logic on first user's application's launch.
 *
 * @author Cristian TG
 * @since 0.2-BETA
 * @version 1.0-INITIAL
 */
public final class FirstSessionLaunchController extends AbstractController {

    Set<String> allStudentsEdmodoId;

    @Override
    public final void execute() throws ControllerException {
        final String launchRequestEdmodo = request.getParameter(EdmodoAPI.API_LAUNCH_KEY_KEY);
        HttpSession mSession = request.getSession();
        // 1.a. First current session application's launch.
        if (launchRequestEdmodo != null) {
            // Invalidate previous session, for security.
            mSession.invalidate();
            mSession = request.getSession();
            try {
                final JSONObject mjson = new JSONObject(EdmodoAPI.launchRequests(launchRequestEdmodo));
                // 1.1 Analyze data and set in session attributes.
                final String edmodoUserId = mjson.getString(EdmodoAPI.API_USER_TOKEN_KEY);
                final byte roleUser = EdmodoAPI.getClassControlUserRole(mjson.getString(EdmodoAPI.API_USER_TYPE_KEY));
                mSession.setAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY, mjson.getString(EdmodoAPI.API_ACCESS_TOKEN_KEY));
                mSession.setAttribute(Constants.SESSION_ID_EDMODO_USER, edmodoUserId);
                mSession.setAttribute(Constants.SESSION_ID_WEB_ROLE, roleUser);
                // 1.2 Check if this Edmodo user is already stored in database.
                this.allStudentsEdmodoId = new HashSet<String>();
                // 1.3. Insert all user's group's students in database.
                final ArrayList<Map.Entry<String, String>> groupsTitleEdmodoId = EdmodoUtil.getGroupNamesAndEdmodId(edmodoUserId, request, true);
                final ArrayList<Thread> mThreads = new ArrayList<Thread>();
                Thread mThread;
                for (final Map.Entry<String, String> entry : groupsTitleEdmodoId) {
                    mThread = new MemberFinder(entry.getValue());
                    mThread.start();
                    mThreads.add(mThread);
                }
                try {
                    for (final Thread current : mThreads) {
                        current.join();
                    }
                } catch (final Exception ex) {
                }
                if (!new Persistence().setLanguageUser(edmodoUserId, roleUser, LanguageFactory.getLanguageIdByCode(request.getParameter(EdmodoAPI.API_LANGUAGE_KEY)), false, allStudentsEdmodoId)) {
                    throw new ControllerException();
                }
            } catch (final JSONException ex) {
                throw new LoginControllerException();
            }
        } else {
            // As Edmodo rules say: The publisher should only launch the application
            //if the response from the launchRequests call determines it is a valid.
            //If the response is not valid, the publisher should not launch the application:
            //so: throw new LoginControllerException() is called.
            if (mSession.getAttribute(Constants.SESSION_ID_EDMODO_USER) == null) {
                throw new LoginControllerException();
            }
        }
    }

    /**
     * Makes http request to find all Edmodo group's members.
     */
    private final class MemberFinder extends Thread {

        String mValue;

        public MemberFinder(final String mValue) {
            super();
            this.mValue = mValue;
        }

        @Override
        public void run() {
            final ArrayList<Map.Entry<String, String>> membersAux = EdmodoUtil.getGroupMembers(mValue, request, true);
            for (final Map.Entry<String, String> member : membersAux) {
                allStudentsEdmodoId.add(member.getKey());
            }
        }
    }
}