package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Generate a pdf report based on user's options.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class GenerateReports2Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        // Security
        final HttpSession session = this.request.getSession();
        String idEdmodoUser = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        final String errorText = CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request);
        if (idEdmodoUser == null) {
            throw new ControllerException(errorText);
        }
        // 1. Get data and store it at session variable due to devices that download the pdf instead of show it.
        // 1.1. Subjects and competences
        String[] subjectCompetence = request.getParameterValues(ConstantsForm.GENERATE_REPORTS_SUBJECTS_NAME);
        if (subjectCompetence == null) {
            subjectCompetence = (String[]) session.getAttribute(ConstantsForm.GENERATE_REPORTS_SUBJECTS_NAME);
        } else {
            session.setAttribute(ConstantsForm.GENERATE_REPORTS_SUBJECTS_NAME, subjectCompetence);
        }
        final List<SubjectCompetence> scList = new ArrayList<SubjectCompetence>();
        List<SubjectCompetence> scListTotal = new ArrayList<SubjectCompetence>();

        // 1.1.1 Student or students
        int possibleIdStudent = ConstantsDB.TABLE_NULL_ID;
        String possibleNameStudent = null;
        switch ((Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                final Persistence mPersistence = new Persistence();
                scListTotal = mPersistence.getSubjectsCompetences(idEdmodoUser);
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParent = new ParentUtil(request);
                scListTotal = (List<SubjectCompetence>) session.getAttribute(mParent.getSelectedStudentEdmodoId());
                final Student student = mParent.getAndSetAttributeStudent();
                mParent.checkChildren(student, idEdmodoUser);
                possibleIdStudent = student.getIdStudent();
                possibleNameStudent = student.getFullName();
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                scListTotal = (List<SubjectCompetence>) session.getAttribute(idEdmodoUser);
                final Student studentStudent = new StudentUtil(request).getSelectedStudent(idEdmodoUser);
                possibleIdStudent = studentStudent.getIdStudent();
                possibleNameStudent = studentStudent.getFullName();
                break;
        }
        final int TOTAL_SC = scListTotal.size();
        boolean find;
        int count;
        SubjectCompetence scAux;
        for (final String title : subjectCompetence) {
            find = false;
            count = 0;
            while (!find && count < TOTAL_SC) {
                scAux = scListTotal.get(count);
                if (title.compareTo(scAux.getTitle()) == 0) {
                    scList.add(scAux);
                    find = true;
                }
                count++;
            }
        }
        // 1.2. Report type
        String[] reportType = request.getParameterValues(ConstantsForm.GENERATE_REPORTS_OPTIONS_NAME);
        if (reportType == null) {
            reportType = (String[]) session.getAttribute(ConstantsForm.GENERATE_REPORTS_OPTIONS_NAME);
        } else {
            session.setAttribute(ConstantsForm.GENERATE_REPORTS_OPTIONS_NAME, reportType);
        }

        final List<Byte> typeReport = new ArrayList<Byte>();
        // Check correct type
        byte type;
        final byte typeAttend = ConstantsForm.GENERATE_REPORTS_OPTIONS[ConstantsForm.GENERATE_REPORTS_ATTEND_OPTION_INDEX];
        final byte typeBehaviourAttitude = ConstantsForm.GENERATE_REPORTS_OPTIONS[ConstantsForm.GENERATE_REPORTS_BEHAVIOUR_ATTITUDE_OPTION_INDEX];
        final byte typeAssignments = ConstantsForm.GENERATE_REPORTS_OPTIONS[ConstantsForm.GENERATE_REPORTS_ASSIGNMENTS_OPTION_INDEX];
        try {
            for (final String mType : reportType) {
                type = Byte.parseByte(mType);
                if (type != typeAttend && type != typeBehaviourAttitude && type != typeAssignments) {
                    throw new Exception();
                }
                typeReport.add(type);
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(errorText + ConstantsForm.CREATE_ASSIGNMENT_TYPE);
        }
        // 1.3. Dates: no limits start-end
        Date startDate;
        Date endDate;
        try {
            String startDateParameter = request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
            String endDateParameter = request.getParameter(ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE);
            if (startDateParameter == null) {
                startDateParameter = (String) session.getAttribute(ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
            } else {
                session.setAttribute(ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE, startDateParameter);
            }
            if (endDateParameter == null) {
                endDateParameter = (String) session.getAttribute(ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE);
            } else {
                session.setAttribute(ConstantsForm.CREATE_SUBJECT_COMPETENCE_FINAL_DATE, endDateParameter);
            }
            startDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(startDateParameter);
            endDate = ConstantsForm.DATE_SIMPLE_DATE_FORMAT.parse(endDateParameter);
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(errorText + ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
        }
        if (startDate.after(endDate)) {
            throw new ControllerException(errorText + ConstantsForm.CREATE_SUBJECT_COMPETENCE_INITIAL_DATE);
        }
        // 1.4. Orientation
        String orientationType = request.getParameter(ConstantsForm.GENERATE_REPORTS_ORIENTATION_PDF);
        if (orientationType == null) {
            orientationType = (String) session.getAttribute(ConstantsForm.GENERATE_REPORTS_ORIENTATION_PDF);
        } else {
            session.setAttribute(ConstantsForm.GENERATE_REPORTS_ORIENTATION_PDF, orientationType);
        }
        byte mOrientation;
        // Check correct type
        try {
            mOrientation = Byte.parseByte(orientationType);
            if (mOrientation != ConstantsForm.GENERATE_REPORTS_ORIENTATION[ConstantsForm.GENERATE_REPORTS_ORIENTATION_HORIZONTAL_INDEX] && mOrientation != ConstantsForm.GENERATE_REPORTS_ORIENTATION[ConstantsForm.GENERATE_REPORTS_ORIENTATION_VERTICAL_INDEX]) {
                throw new Exception();
            }
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(errorText);
        }


        // 2. Generate PDF
        try {
            request.setAttribute(Constants.CONTROLLER_PDF_OBJECT, new PdfUtil().generatePDF(request, scList, typeReport, mOrientation, startDate, endDate, possibleIdStudent, possibleNameStudent));
            this.isPDF = true;
        } catch (final IOException ex) {
            //ex.printStackTrace();
            throw new ControllerException(errorText);
        }
    }
}