package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * Shows student's absences for a student or nothing if various students are
 * selected.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class ModifyAspect3Controller extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final String idEdmodoTeacher = (String) this.request.getSession().getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoTeacher == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }

        // a. Get data
        final AspectUtil myAspectUtil = new AspectUtil(this.request);
        // 1. Name
        final String[] names = myAspectUtil.getName(idEdmodoTeacher);
        final String newName = names[AspectUtil.NEW_NAME];
        // 2. Description
        final String description = myAspectUtil.getDescription();
        // 3. URL (modify: empty string means no change)
        final String url = myAspectUtil.getUrlImg(false);
        // 4. Type
        final byte myType = myAspectUtil.getType();

        // b. Register Teacher's behaviour attitude aspect (badge) in Edmodo
        final Persistence myPersistence = new Persistence();
        final BehaviourAttitudeAspect oldAspect = myPersistence.getBAAspect(
                idEdmodoTeacher, names[AspectUtil.OLD_NAME]);
        final String aspectEdmodoId = oldAspect.getEdmodoId();
        try {
            // b.1. Update in Class Control database if all ok
            if (new JSONObject(EdmodoAPI.updateBadge(aspectEdmodoId, newName, description, url)).getString(EdmodoAPI.API_STATUS_KEY).compareTo(EdmodoAPI.API_SUCCESS_KEY) == 0 && myPersistence.updateBehaviourAttitudeAspect(
                    new BehaviourAttitudeAspect(oldAspect.getTeacherId(), aspectEdmodoId, newName, myType, description, url),
                    names[AspectUtil.OLD_NAME]) == Constants.NO_RESULT) {
                throw new ControllerException();
            }
            // b.2. Set redirect url
            this.request.setAttribute(Constants.ATT_NEXT_URL_MESSAGE, "/?" + Constants.CONTROLLER_ID + '=' + Constants.CONTROLLER_ID_TEACHER_ASPECTS + '&' + Constants.CONTROLLER_NEXT_URL + "=/Teacher/Aspect.jsp");
        } catch (final Exception ex) {
            //ex.printStackTrace();
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
    }
}