package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Student;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * Sets parent's children list in a request attribute.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class ParentStudentController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession mSession = this.request.getSession();
        final String idEdmodoParent = (String) mSession.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoParent == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final ArrayList<Student> children = new ArrayList<Student>();
        try {
            final Persistence mPersistence = new Persistence();
            final JSONArray childrenArray = new JSONArray(EdmodoAPI.children((String) request.getSession().getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), idEdmodoParent));
            final int N_CHILDREN = childrenArray.length();
            String studentEdmodoId;
            JSONObject mJSONObject;
            for (int i = 0; i < N_CHILDREN; i++) {
                mJSONObject = childrenArray.getJSONObject(i);
                studentEdmodoId = mJSONObject.getString(EdmodoAPI.API_USER_TOKEN_KEY);
                children.add(new Student(mPersistence.getIdStudent(studentEdmodoId),
                        studentEdmodoId, mJSONObject.getString(EdmodoAPI.API_FIRST_NAME_KEY)
                        + ' ' + mJSONObject.optString(EdmodoAPI.API_LAST_NAME_KEY)));
            }
        } catch (final Exception ex) {
            throw new ControllerException();
        }
        request.setAttribute(Constants.CONTROLLER_PARENT_CHILDREN_LIST, children);
    }
}