package classcontrol.controller;

import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Student;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import javax.servlet.http.HttpServletRequest;
import org.codehaus.jettison.json.JSONArray;

/**
 * Handles all parent's role bussiness logic.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public final class ParentUtil {

    private final HttpServletRequest request;

    private ParentUtil() {
        this.request = null;
    }

    /**
     *
     * @param request Incoming request.
     */
    public ParentUtil(final HttpServletRequest request) {
        this.request = request;
    }

    /**
     *
     * @return Selected assignment id.
     * @throws ControllerException If there is not any assignment selected as
     * parameter.
     */
    public String getSelectedStudentEdmodoId() throws ControllerException {
        final String edmodoStudentId = request.getParameter(Constants.PARAMETER_STUDENT_SELECTED);
        if (edmodoStudentId == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        return edmodoStudentId;
    }

    /**
     *
     * @return @throws ControllerException
     */
    public Student getAndSetAttributeStudent() throws ControllerException {
        final Student student = new StudentUtil(request).getSelectedStudent(getSelectedStudentEdmodoId());
        request.setAttribute(Constants.ATT_STUDENT_DATA, student);
        return student;
    }

    /**
     * Checks if a specified student has a relationship with its parent.
     *
     * @param student
     * @param idEdmodoParent
     * @throws ControllerException
     */
    public void checkChildren(final Student student, final String idEdmodoParent) throws ControllerException {
        try {
            final JSONArray childrenArray = new JSONArray(EdmodoAPI.children((String) request.getSession().getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), idEdmodoParent));
            final int N_CHILDREN = childrenArray.length();
            boolean find = false;
            int counter = 0;
            final String studentEdmodoId = student.getIdEdmodo();
            while (!find && counter < N_CHILDREN) {
                if (childrenArray.getJSONObject(counter).optString(EdmodoAPI.API_USER_TOKEN_KEY).compareTo(studentEdmodoId) == 0) {
                    find = true;
                }
                counter++;
            }
            if (!find) {
                throw new ControllerException();
            }
        } catch (final Exception ex) {
            throw new ControllerException("Invalid children for this parent.");
        }
    }
}