package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.edmodo.EdmodoUtil;
import classcontrol.entity.Assignment;
import classcontrol.entity.Qualification;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.Student;
import classcontrol.entity.StudentQualificationReport;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * View subject / competence's assignment controller.<br/>
 * Shows an assignment's qualifications table with all students of the subject
 * competence.
 *
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class QualificateAssignmentController extends AbstractController {

    @Override
    public final void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        final String idEdmodoUser = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodoUser == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }

        final AssignmentUtil mUtil = new AssignmentUtil(this.request);

        final int assignmentId = mUtil.getSelectedAssignmentId();

        final SubjectCompetence mSubjectCompetence = ((ArrayList<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(new SubjectCompetenceUtil(request).getSelectedSubjectCompetence());
        final String scTitle = mSubjectCompetence.getTitle();
        final String scEdmodoGroup = mSubjectCompetence.getEdmodoGroup();
        final int scTeacherId = mSubjectCompetence.getTeacherId();
        final String accessToken = (String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY);
        final Persistence mPersistence = new Persistence();
        final Assignment mAssignment = mUtil.getSelectedAssignmentAllData(assignmentId,
                scEdmodoGroup, scTeacherId, scTitle, EdmodoAPI.gradesSetByAppForGroup(accessToken, scEdmodoGroup), EdmodoAPI.assignmentsByAppForUser(accessToken, mPersistence.getIdEdmodoTeacher(scTeacherId)));
        final double assignmentTotal = mAssignment.getMaxGrade();
        final String assignmentEdmodoId = mAssignment.getEdmodoId();
        final byte assignmentType = mAssignment.getType();
        final String tableData = request.getParameter(ConstantsForm.TABLE_NAME);
        // By defalut, error
        this.possibleJSON = "{\"" + ConstantsForm.CONTROLLER_AJAX_NAME + "\":\"" + ConstantsForm.QUALIFICATION_AJAX_ERROR + "\"}";
        if (tableData != null) {
            final List<EvaluableItem> evaluableItems = mPersistence.getEvaluableItemsAssignment(assignmentId);
            final int EVALUABLE_ITEMS_SIZE = evaluableItems.size();
            final List<Student> subjectCompetenceMembers = EdmodoUtil.getGroupStudents(scEdmodoGroup, request, false);
            final List<StudentQualificationReport> myList = mUtil.getAssignmentQualifications(mPersistence.getEvaluableItemStudentQualification(scTeacherId, scTitle), assignmentId, scEdmodoGroup, subjectCompetenceMembers);
            final int TOTAL_SIZE = myList.size();
            final char END_LINE = '\n';
            final char SEPARATOR = '\t';
            final int MAX_JUMPS = 8 + EVALUABLE_ITEMS_SIZE + 1;//+1 because is zero based
            final int INDEX_END = tableData.indexOf(END_LINE);
            int indexJump = INDEX_END;
            int oldIndex;
            int currentColumn = 0;
            int currentRow = 1;
            boolean existsUser = false;
            int counter;
            String auxString;
            int nextEnd = tableData.indexOf(END_LINE, INDEX_END + 1);
            final int JUMP_COLUMNS = EVALUABLE_ITEMS_SIZE + 1;//+1= 0:id column + 1:Name column
            final int LAST_COLUMN = JUMP_COLUMNS + 7;
            int auxEvaluableItemPosition;
            Qualification qualificationAux = null;
            StudentQualificationReport studentqualificationReportAux = null;
            boolean firstTime = true;
            List<EvaluableItemStudent> evaluableItemsStudentAux = null;
            String evaluableItemNameAux;
            boolean existsEvaluableItem;
            int count;
            int evaluableItemStudentSize;
            String evaluableItemName;
            EvaluableItemStudent evaluableItemStudentAux;
            //double gradeAux = 0;
            final ArrayList<Integer> evaluableItemsColumns = new ArrayList<Integer>();
            for (int i = 2; i <= EVALUABLE_ITEMS_SIZE + 1; i++) {
                evaluableItemsColumns.add(i);
            }
            String edmodoStudentId = "";
            String content = "Class Control: " + mSubjectCompetence.getTitle() + '.';
            try {
                if (INDEX_END >= 0) {
                    final ArrayList<Thread> mThreads = new ArrayList<Thread>();
                    Thread mThread;
                    // Parse each line
                    while (indexJump >= 0) {
                        // 1. Get data
                        oldIndex = indexJump + 1 + (currentColumn == 0 && !firstTime ? 1 : 0);
                        if (firstTime) {
                            firstTime = false;
                        }
                        indexJump = tableData.indexOf(SEPARATOR, oldIndex);
                        if (nextEnd > -1 && indexJump > nextEnd) {
                            indexJump = nextEnd - (currentColumn == LAST_COLUMN ? 1 : 0);
                            nextEnd = tableData.indexOf(END_LINE, nextEnd + 1);
                        }
                        auxString = indexJump > -1 ? tableData.substring(oldIndex, indexJump) : tableData.substring(oldIndex);
                        // 2. Column action
                        if (currentColumn == 0) {
                            //gradeAux = 0;
                            edmodoStudentId = auxString;
                            // Look if exists this Edmodo Student Id
                            existsUser = false;
                            counter = 0;
                            while (!existsUser && counter < TOTAL_SIZE) {
                                studentqualificationReportAux = myList.get(counter);
                                if (studentqualificationReportAux.getStudent().getIdEdmodo().compareTo(auxString) == 0) {
                                    existsUser = true;
                                    evaluableItemsStudentAux = studentqualificationReportAux.getMyEvaluableItemQualification();
                                    qualificationAux = studentqualificationReportAux.getQualification();
                                }
                                counter++;
                            }
                        } else {
                            if (existsUser) {
                                auxEvaluableItemPosition = evaluableItemsColumns.indexOf(currentColumn);
                                if (auxEvaluableItemPosition > -1) {
                                    // 1. Get evaluableItem[currentColumn]'s name.
                                    evaluableItemNameAux = evaluableItems.get(auxEvaluableItemPosition).getName();
                                    existsEvaluableItem = false;
                                    count = 0;
                                    evaluableItemStudentSize = evaluableItemsStudentAux.size();
                                    while (!existsEvaluableItem && count < evaluableItemStudentSize) {
                                        evaluableItemStudentAux = evaluableItemsStudentAux.get(count);
                                        evaluableItemName = evaluableItemStudentAux.getName();
                                        if (evaluableItemNameAux.compareTo(evaluableItemName) == 0) {
                                            evaluableItemStudentAux.setScore(Double.parseDouble(auxString));
                                            existsEvaluableItem = true;
                                        }
                                        count++;
                                    }
                                    if (!existsEvaluableItem) {
                                        evaluableItemsStudentAux.add(new EvaluableItemStudent(assignmentId, evaluableItemNameAux, studentqualificationReportAux.getStudent().getIdStudent(), Double.parseDouble(auxString)));
                                    }
                                } else {
                                    if (currentColumn == JUMP_COLUMNS + 2) {//Extra
                                        qualificationAux.setBonusPenalization(Double.parseDouble(auxString));
                                    } else {
                                        if (currentColumn == JUMP_COLUMNS + 3) {//Reason
                                            qualificationAux.setReasonBonusPenalization(auxString);
                                        } else {
                                            if (currentColumn == JUMP_COLUMNS + 4) {
                                                // Set grade this assignment/grade
                                                mThread = new UpdateGrade(accessToken,
                                                        edmodoStudentId,
                                                        auxString,
                                                        assignmentTotal, assignmentEdmodoId, assignmentType, content);
                                                mThreads.add(mThread);
                                                mThread.start();
                                            } else {

                                                if (currentColumn == JUMP_COLUMNS + 5) {//Optional Comment
                                                    qualificationAux.setOptionalComment(auxString);
                                                } else {
                                                    if (currentColumn == JUMP_COLUMNS + 6) {//Visible parent
                                                        qualificationAux.setVisibleParent(visibleTextToByte(auxString));
                                                    } else {
                                                        if (currentColumn == LAST_COLUMN) {//Visible student
                                                            qualificationAux.setVisibleStudent(visibleTextToByte(auxString));
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }

                        }
                        currentColumn = (currentColumn + 1) % MAX_JUMPS;
                        currentRow = currentColumn == LAST_COLUMN ? currentRow + 1 : currentRow;
                    }
                    for (final Thread current : mThreads) {
                        current.join();
                    }
                    this.possibleJSON = "{\"" + ConstantsForm.CONTROLLER_AJAX_NAME + "\":\"" + (mPersistence.updateQualificationsAssignment(assignmentId, myList) == Constants.NO_RESULT ? ConstantsForm.QUALIFICATION_AJAX_ERROR : ConstantsForm.QUALIFICATION_AJAX_OK) + "\"}";
                } else {
                    throw new Exception("Invalid data");
                }
            } catch (final Exception e) {
                //e.printStackTrace();
            }
        }
    }

    /**
     * Makes http request to set grades.
     */
    private final class UpdateGrade extends Thread {

        String accessToken;
        String studentEdmodoId;
        String score;
        double total;
        String gradeAssignmentEdmodoId;
        byte type;
        String content;

        /**
         * Basic constaructor
         * @param accessToken
         * @param studentEdmodoId
         * @param score
         * @param total
         * @param gradeAssignmentEdmodoId
         * @param type
         * @param content
         */
        public UpdateGrade(final String accessToken,
                final String studentEdmodoId, final String score,
                final double total, final String gradeAssignmentEdmodoId,
                final byte type, final String content) {
            super();
            this.accessToken = accessToken;
            this.studentEdmodoId = studentEdmodoId;
            this.score = score;
            this.total = total;
            this.gradeAssignmentEdmodoId = gradeAssignmentEdmodoId;
            this.type = type;
            this.content = content;
        }

        @Override
        public void run() {
            try {
                EdmodoAPI.setGrade(accessToken, studentEdmodoId, score, total, gradeAssignmentEdmodoId, type, content);
            } catch (final Exception ex) {
            }
        }
    }

    /**
     * Returns an integer code that represents assignmet's comment visbility.
     *
     * @param text Text to obtains its code.
     * @return Integer code that represents assignmet's comment visbility.
     */
    private byte visibleTextToByte(String text) {
        text = text.toUpperCase();
        return text.compareTo(CurrentLanguage.getString(Text.QUALIFICATION_VISIBLE_YES, request).toUpperCase()) == 0
                ? ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_YES_INDEX]
                : text.compareTo(CurrentLanguage.getString(Text.QUALIFICATION_VISIBLE_NO, request).toUpperCase()) == 0
                ? ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_NO_INDEX]
                : ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_TYPES[ConstantsDB.TABLE_QUALIFICATION_ATT_VISIBLE_DEFAULT_INDEX];
    }
}