package classcontrol.controller;

import classcontrol.dao.Persistence;
import classcontrol.edmodo.EdmodoAPI;
import classcontrol.entity.Student;
import classcontrol.entity.SubjectCompetence;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import java.util.List;
import javax.servlet.http.HttpSession;

/**
 *
 * Select subject competence controller.<br/>
 * Sets in session var teacher's subjects and competences list.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.2-BETA
 */
public class SelectAssignmentController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        // Security
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        final int scIndex = new SubjectCompetenceUtil(request).getSelectedSubjectCompetence();
        SubjectCompetence currentSC = null;
        switch ((Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                currentSC = ((List<SubjectCompetence>) session.getAttribute(Constants.ATT_LIST_SUBJECTS_COMPETENCES)).get(scIndex);
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParentUtil = new ParentUtil(request);
                final Student student = new ParentUtil(request).getAndSetAttributeStudent();
                mParentUtil.checkChildren(student, idEdmodo);
                currentSC = ((List<SubjectCompetence>) session.getAttribute(student.getIdEdmodo())).get(scIndex);
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                final Student studentStudent = new StudentUtil(request).getAndSetAttributeStudent(idEdmodo);
                currentSC = ((List<SubjectCompetence>) session.getAttribute(studentStudent.getIdEdmodo())).get(scIndex);
                break;
        }
        final String edmodoGroup = currentSC.getEdmodoGroup();
        final int teacherId = currentSC.getTeacherId();
        final String accessToken = (String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY);
        new AssignmentUtil(request).getAllAssignmentsEvaluationperiod(edmodoGroup, teacherId, currentSC.getTitle(), true,
                EdmodoAPI.gradesSetByAppForGroup(accessToken, edmodoGroup), EdmodoAPI.assignmentsByAppForUser(accessToken, new Persistence().getIdEdmodoTeacher(teacherId)));
    }
}