package classcontrol.controller;

import classcontrol.entity.Student;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import javax.servlet.http.HttpSession;

/**
 *
 * Select subject competence controller.<br/>
 * Sets in a session attribute all subject competence's that belong the
 * specified user.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public class SelectSubjectCompetenceController extends AbstractController {

    @Override
    public void execute() throws ControllerException {
        final HttpSession session = this.request.getSession();
        final String idEdmodo = (String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER);
        if (idEdmodo == null) {
            throw new ControllerException(CurrentLanguage.getString(Text.BUSINESS_PROBLEM, request));
        }
        String idEdmodoStudent = idEdmodo;
        switch ((Byte) request.getSession().getAttribute(Constants.SESSION_ID_WEB_ROLE)) {
            case Constants.SESSION_ID_ROLE_TEACHER:
                new SubjectCompetenceUtil(this.request).setAllSubjectsCompetencesSession(false);
                break;
            case Constants.SESSION_ID_ROLE_PARENT:
                final ParentUtil mParentUtil = new ParentUtil(request);
                final Student student = mParentUtil.getAndSetAttributeStudent();
                mParentUtil.checkChildren(student, idEdmodo);
                idEdmodoStudent = student.getIdEdmodo();
                // True because parents could have more than 1 children.
                new StudentUtil(request).setAllSubjectsCompetencesSession(idEdmodoStudent, true);
                break;
            case Constants.SESSION_ID_ROLE_STUDENT:
                final StudentUtil mStudentUtil= new StudentUtil(request);
                // False because per session one student.
                mStudentUtil.getAndSetAttributeStudent(idEdmodo);
                mStudentUtil.setAllSubjectsCompetencesSession(idEdmodoStudent, false);
                break;
        }
    }
}