package classcontrol.controller;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.dao.Persistence;
import classcontrol.entity.Absence;
import classcontrol.entity.Assignment;
import classcontrol.entity.AttendReport;
import classcontrol.entity.BehaviourAttitudeAspect;
import classcontrol.entity.BonusPenalization;
import classcontrol.entity.Qualification;
import classcontrol.entity.EvaluableItem;
import classcontrol.entity.EvaluableItemStudent;
import classcontrol.entity.EvaluationPeriod;
import classcontrol.entity.EvaluationPeriodAssignment;
import classcontrol.entity.Student;
import classcontrol.entity.StudentAspect;
import classcontrol.entity.StudentAspectReport;
import classcontrol.entity.StudentQualificationReport;
import classcontrol.entity.StudentEvaluation;
import classcontrol.entity.StudentEvaluationPeriod;
import classcontrol.entity.SubjectCompetence;
import classcontrol.entity.SubjectCompetenceEvaluation;
import classcontrol.utils.QualificationUtil;
import classcontrol.utils.Constants;
import classcontrol.utils.CurrentLanguage;
import classcontrol.utils.Text;
import com.lowagie.text.html.simpleparser.HTMLWorker;
import java.io.StringReader;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;

/**
 * Handles all business logic for generate HTML tables for Class Control
 * reports.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class TableHtml {

    /**
     * Returns a HTML table with an attend information report for a subject
     * competence. See parameters for more details.
     *
     * @param sc Subject competence's to get attend report data.
     * @param request Current session request.
     * @param showID If table must contain a column with edmodo idetificator.
     * @param initialDate Restricts results from this date.
     * @param endDate Restricts results to this date.
     * @param studentId If it is provided (must be greater than
     * {@link ConstantsDB#TABLE_NULL_ID}, table returned will only contain data
     * for this student (if exists in table data).
     * @param subjectCompetenceMembers All subject competence's members.
     * @return a HTML table with an attend information report. See parameters
     * for more details.
     * @throws ControllerException If some problem happened.
     */
    public static StringBuilder getAttendReport(final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final Date initialDate, final Date endDate, final int studentId, final List<Student> subjectCompetenceMembers) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" style=\"margin-bottom: 20px;\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        List<Absence> myAbsences;
        final String subjectCompetenceTitle = sc.getTitle();
        final Persistence myPersistence = new Persistence();
        final int teacherId = sc.getTeacherId();
        final List<EvaluationPeriod> evaluationperiodsList = myPersistence.getEvaluationPeriodsSubjectCompetence(teacherId, subjectCompetenceTitle);
        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriod evaluationPeriod : evaluationperiodsList) {
                if (evaluationPeriod.getInitialDate().before(initialDate) || evaluationPeriod.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);
                } else {
                    evaluationPeriodOldIndex.add(count + 1);//+1 due to humans count 1,2,3 and not 0,1,2...
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }

        final List<AttendReport> mReportData = new ArrayList<AttendReport>();
        // All students absences (separate by evaluation periods)
        myAbsences = myPersistence.getAbsencesSubjectCompetence(teacherId, subjectCompetenceTitle);

        // 1. For each student
        ArrayList<Date> auxDatesList;
        ArrayList<Date> datesPeriod;
        List<List<Date>> totalEvaluationPeriods;
        int idStudentAux;
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        for (final Student currentMember : subjectCompetenceMembers) {
            idStudentAux = currentMember.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                totalEvaluationPeriods = new ArrayList<List<Date>>();
                for (final EvaluationPeriod evalPeriod : evaluationperiodsList) {
                    datesPeriod = new ArrayList<Date>();
                    // 1.1. Look for absences
                    for (final Absence myAbsence : myAbsences) {
                        // Has absences:
                        if (myAbsence.getStudentId() == currentMember.getIdStudent()) {
                            // 1.1.1 Get sorted absences list
                            auxDatesList = DatesUtil.getDatesFromDatePicker(DatesUtil.getDatepickerDates(myAbsence.getDates()).toString());
                            // 1.1.1.1 For each evaluation period look if there is a coincidence
                            for (final Date myDate : auxDatesList) {
                                if ((myDate.compareTo(evalPeriod.getInitialDate()) >= 0) && (myDate.compareTo(evalPeriod.getFinalDate()) <= 0)) {
                                    datesPeriod.add(myDate);
                                }
                            }
                        }
                    }
                    totalEvaluationPeriods.add(datesPeriod);
                }
                mReportData.add(new AttendReport(currentMember.getIdEdmodo(), currentMember.getFullName(), totalEvaluationPeriods));
            }
        }
        final int nPeriods = evaluationperiodsList.size();
        final SimpleDateFormat myAbsencesSDF = new SimpleDateFormat("dd/MM");
        EvaluationPeriod currentPeriod;

        final SimpleDateFormat myEvalPeriodsSDF = ConstantsForm.DATE_SIMPLE_DATE_FORMAT;
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);
        String dates;
        for (int i = 0; i < nPeriods; i++) {
            currentPeriod = evaluationperiodsList.get(i);
            dates = myEvalPeriodsSDF.format(currentPeriod.getInitialDate()) + ' ' + CurrentLanguage.getString(Text.TO, request) + ' ' + myEvalPeriodsSDF.format(currentPeriod.getFinalDate());
            htmlTableData.append("<th data-content=\"").
                    append(dates).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(periodText).append(" ").append(possibleRemove ? evaluationPeriodOldIndex.get(i) : i + 1).append(possibleRemove ? ": " + dates : "")
                    .append("</th>");
        }
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request)).append("</th></tr></thead><tbody>");

        int totalAbsencesCounter;
        for (final AttendReport mData : mReportData) {
            totalAbsencesCounter = 0;
            htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mData.getIdEdmodo() + "</td><td>" : "")
                    .append(mData.getStudentName()).append("</td>");
            List<Date> allDates;
            for (int i = 0; i < nPeriods; i++) {
                allDates = mData.getEvaluationPeriods().get(i);
                htmlTableData.append("<td>");
                for (final Date mDate : allDates) {
                    htmlTableData.append(myAbsencesSDF.format(mDate)).append(" ");
                    totalAbsencesCounter++;
                }
                htmlTableData.append("</td>");
            }

            htmlTableData.append("<td><b>").append(totalAbsencesCounter).append("</b></td></tr>");
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, nPeriods);
        return htmlTableData.append("</tbody></table>");
    }

    /**
     * Returns a HTML table with a behaviour attitude information report for a
     * subject competence. See parameters for more details.
     *
     * @param sc Subject competence's to get vehaviour attitude report data.
     * @param request Current session request.
     * @param showID If table must contain a column with edmodo idetificator.
     * @param initialDate Restricts results from this date.
     * @param endDate Restricts results to this date.
     * @param studentId If it is provided (must be greater than
     * {@link ConstantsDB#TABLE_NULL_ID}, table returned will only contain data
     * for this student (if exists in table data).
     * @param subjectCompetenceMembers All subject competence's members.
     * @return a HTML table with an attend information report. See parameters
     * for more details.
     * @throws ControllerException If some problem happened.
     */
    public static StringBuilder getBehaviourAttitudeReport(final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final Date initialDate, final Date endDate, final int studentId, final List<Student> subjectCompetenceMembers) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" style=\"margin-bottom: 20px;\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        final Persistence mPersistence = new Persistence();
        final String scTitle = sc.getTitle();
        final int teacherId = sc.getTeacherId();
        final String teacherEmododSC = mPersistence.getIdEdmodoTeacher(teacherId);
        final List<EvaluationPeriod> evaluationperiodsList = mPersistence.getEvaluationPeriodsSubjectCompetence(teacherId, scTitle);
        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriod evaluationPeriod : evaluationperiodsList) {
                if (evaluationPeriod.getInitialDate().before(initialDate) || evaluationPeriod.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);

                } else {
                    evaluationPeriodOldIndex.add(count + 1);//+1 due to humans count 1,2,3 and not 0,1,2...
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }
        // 1. For each student
        List<List<StudentAspect>> totalEvaluationPeriodsAspects;
        ArrayList<StudentAspect> studentAspectList;
        Date auxStudentAspectDate;
        final List<StudentAspect> subjectCompetenceAspectsApplied = mPersistence.getStudentAspectsSubjectCompetence(teacherEmododSC, scTitle);
        final List<StudentAspectReport> mReportData = new ArrayList<StudentAspectReport>();
        int idStudentAux;
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        for (final Student currentMember : subjectCompetenceMembers) {
            idStudentAux = currentMember.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                totalEvaluationPeriodsAspects = new ArrayList<List<StudentAspect>>();
                for (final EvaluationPeriod evalPeriod : evaluationperiodsList) {
                    studentAspectList = new ArrayList<StudentAspect>();
                    for (final StudentAspect currentAspect : subjectCompetenceAspectsApplied) {
                        // 1.1. Look for student applied aspect
                        if (currentAspect.getIdStudent() == currentMember.getIdStudent()) {
                            auxStudentAspectDate = currentAspect.getDate();
                            if ((auxStudentAspectDate.compareTo(evalPeriod.getInitialDate()) >= 0) && (auxStudentAspectDate.compareTo(evalPeriod.getFinalDate()) <= 0)) {
                                studentAspectList.add(currentAspect);
                            }
                        }
                    }
                    totalEvaluationPeriodsAspects.add(studentAspectList);
                }
                mReportData.add(new StudentAspectReport(currentMember.getIdEdmodo(), currentMember.getFullName(), totalEvaluationPeriodsAspects));
            }
        }
        final int nPeriods = evaluationperiodsList.size();
        EvaluationPeriod currentPeriod;
        final List<BehaviourAttitudeAspect> mySubjectCompetenceAspects = mPersistence.getBAAspectsSubjectCompetence(teacherEmododSC);
        final int SIZE_B_A_ASPECTS = mySubjectCompetenceAspects.size();
        final StringBuilder periodsNull = new StringBuilder();
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);
        final SimpleDateFormat myEvalPeriodsSDF = ConstantsForm.DATE_SIMPLE_DATE_FORMAT;
        String dates;
        for (int i = 0; i < nPeriods; i++) {
            currentPeriod = evaluationperiodsList.get(i);
            dates = myEvalPeriodsSDF.format(currentPeriod.getInitialDate()) + ' ' + CurrentLanguage.getString(Text.TO, request) + ' ' + myEvalPeriodsSDF.format(currentPeriod.getFinalDate());
            periodsNull.append("null,");
            htmlTableData.append("<th title=\"").append("\" data-content=\"")
                    .append(dates)
                    .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(periodText).append(" ").append(possibleRemove ? evaluationPeriodOldIndex.get(i) : i + 1).append(possibleRemove ? ": " + dates : "")
                    .append("</th>");
        }
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request))
                .append(" +</th><th>").append(CurrentLanguage.getString(Text.REPORTS_TOTAL, request))
                .append(" -</th></tr></thead><tbody>");
        int totalPositiveAspectsCounter;
        int totalNegativeAspectsCounter;
        int counter;
        boolean find;
        boolean isPositive;
        BehaviourAttitudeAspect aux;
        String currentName;
        for (final StudentAspectReport mData : mReportData) {
            totalNegativeAspectsCounter = 0;
            totalPositiveAspectsCounter = 0;
            htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mData.getIdEdmodo() + "</td><td>" : "")
                    .append(mData.getStudentName()).append("</td>");
            List<StudentAspect> myStudentAspects;
            for (int i = 0; i < nPeriods; i++) {
                myStudentAspects = mData.getEvaluationPeriods().get(i);
                htmlTableData.append("<td>");
                for (final StudentAspect mySA : myStudentAspects) {
                    counter = 0;
                    find = false;
                    while (!find && counter < SIZE_B_A_ASPECTS) {
                        aux = mySubjectCompetenceAspects.get(counter);
                        currentName = aux.getName();
                        if (currentName.compareTo(mySA.getName()) == 0) {
                            find = true;
                            isPositive = aux.getType() == ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX];
                            if (isPositive) {
                                totalPositiveAspectsCounter++;
                            } else {
                                totalNegativeAspectsCounter++;
                            }
                            htmlTableData.append("<span ").append(isPositive ? " class='positiveAspect'>+" : " class='negativeAspect'>-")
                                    .append(currentName).append(" </span>");
                        }
                        counter++;
                    }
                }
                htmlTableData.append("</td>");
            }
            htmlTableData.append("<td style=\"background-color:lightgreen\">").append(totalPositiveAspectsCounter).append("</td>")
                    .append("<td style=\"background-color:antiquewhite\">").append(totalNegativeAspectsCounter).append("</td></tr>");
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, evaluationperiodsList.size());
        final String EACH_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_EACH, request);
        final String MAX_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_MAX, request);
        request.setAttribute(Constants.ATT_BEHAVIOUR_ATTITUDE_ASPECTS_WEIGHT, "<div align=\"center\"><p style=\"text-align: center;\" id=\"" + ConstantsForm.ID_EXTRA_BEHAVIOUR_ATTITUDE_REPORT
                + "\"><b>" + CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_POSITIVE, request)
                + "</b>: " + ' ' + EACH_TEXT + " +"
                + sc.getEachPositiveWeigth() + "% " + MAX_TEXT
                + ' ' + sc.getMaxPositiveWeigth() + "% <b>" + CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_NEGATIVE, request)
                + "</b>: " + EACH_TEXT + " -"
                + sc.getEachNegativeWeigth() + "% " + MAX_TEXT + ' ' + sc.getMaxNegativeWeigth() + "%.</p><div>");
        return htmlTableData.append("</tbody></table>");
    }

    /**
     * Returns a HTML table with a subject competence's assignments report
     * information. See parameters for more details.
     *
     * @param assignmentId Assignment id to get all data.
     * @param sc Subject competence's to get attend report data.
     * @param request Current session request.
     * @param showID If table must contain a column with edmodo idetificator.
     * @param studentId If it is provided (must be greater than
     * {@link ConstantsDB#TABLE_NULL_ID}, table returned will only contain data
     * for this student (if exists in table data).
     * @param roleRequest User requester role.
     * @param subjectCompetenceMembers All subject competence's members.
     * @param gradesGroupJSON String result of {@link EdmodoAPI#gradesSetByAppForGroup(java.lang.String, java.lang.String
     * }
     *
     * @param assignmentsUserJSON String result of {@link EdmodoAPI#assignmentsByAppForUser(java.lang.String, java.lang.String)   *
     * }
     * @
     * param htmlWorker Optioanl HTMLWorker that thit method use to parse Each
     * evaluable item and its weigth.
     *
     * return a HTML table with an attend information report. See parameters for
     * more details.
     * @throws ControllerException If some problem happened.
     */
    public static StringBuilder getAssignmentqualifications(final int assignmentId, final SubjectCompetence sc, final HttpServletRequest request, final boolean showID, final int studentId, final byte roleRequest, final List<Student> subjectCompetenceMembers, final String gradesGroupJSON, final String assignmentsUserJSON, final HTMLWorker htmlWorker) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" style=\"margin-bottom: 20px;\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        final Persistence mPersistence = new Persistence();
        final String scEdmodoGroup = sc.getEdmodoGroup();
        final String scTitle = sc.getTitle();
        final int scTeacherId = sc.getTeacherId();
        final AssignmentUtil mUtil = new AssignmentUtil(request);
        final Assignment mAssignment = mUtil.getSelectedAssignmentAllData(assignmentId, scEdmodoGroup, scTeacherId, scTitle, gradesGroupJSON, assignmentsUserJSON);
        request.setAttribute(Constants.ATT_CURRENT_ASSIGNMENT, mAssignment);
        final List<EvaluableItem> mEvaluableItems = mPersistence.getEvaluableItemsAssignment(assignmentId);
        request.setAttribute(Constants.ATT_EVALUABLE_ITEM_LIST_ASSIGNMENT, mEvaluableItems);
        try {
            String eiName;
            int eiWeight;
            for (final EvaluableItem mEvaluableItem : mEvaluableItems) {
                eiName = mEvaluableItem.getName();
                eiWeight = mEvaluableItem.getAssociatedWeight();
                htmlTableData.append("<th data-content=\"").append(eiName).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                        .append(eiWeight).append(" %</th>");
                if (htmlWorker != null) {
                    htmlWorker.parse(new StringReader("<b>" + eiName + ": </b>" + eiWeight + " %.<br/>"));
                }
            }
        } catch (final Exception ex) {
        }
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        htmlTableData.append("<th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_TH, request)).append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_BONUS_PENALIZATION_TH, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_EXTRA_TH, request)).append("</th><th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_REASON_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_FINAL_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_COMMENT_TH, request))
                .append("</th>");

        if (notStudent) {
            htmlTableData.append("<th data-content=\"").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_VISIBLE_PARENT_TH, request)).
                    append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(
                    CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_VISIBLE_PARENT_P_TH, request)).append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_VISIBLE_STUDENT_TH, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_VISIBLE_PARENT_S_TH, request))
                    .append("</th>");
        }
        htmlTableData.append("</tr></thead><tbody>");
        final double MAX_GRADE = mAssignment.getMaxGrade();
        Student mAuxStudent;
        String studentNameAux;
        int sizeStudentNameAux;
        final List<StudentQualificationReport> mData = mUtil.getAssignmentQualifications(mPersistence.getEvaluableItemStudentQualification(scTeacherId, scTitle), assignmentId, scEdmodoGroup, subjectCompetenceMembers);
        List<EvaluableItemStudent> myEvaluableItemqualificationAux;
        EvaluableItemStudent evaluableItemStudentAux;
        boolean findEvaluableItem;
        int counter;
        Qualification auxqualification;
        int auxEvaluableItemsStudentSize;
        double firstqualification;
        double bonusPenalization;
        double lastqualification;
        double qualificationAux;
        String auxText;
        String visibilityParent;
        String visibilityStudent;
        final String VISIBILITY_YES = CurrentLanguage.getString(Text.QUALIFICATION_VISIBLE_YES, request).toUpperCase();
        final DecimalFormat df = ConstantsForm.appDecimalFormat();
        for (final StudentQualificationReport mStudentqualificationReport : mData) {
            mAuxStudent = mStudentqualificationReport.getStudent();
            if (notStudent || mAuxStudent.getIdStudent() == studentId) {
                studentNameAux = mAuxStudent.getFullName();
                studentNameAux = studentNameAux == null ? "" : studentNameAux;
                sizeStudentNameAux = studentNameAux.length();
                htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + mAuxStudent.getIdEdmodo() + "</td><td>" : "")
                        .append(studentNameAux.substring(0, sizeStudentNameAux > Constants.MAX_NAME_NAV_BAR ? Constants.MAX_NAME_NAV_BAR : sizeStudentNameAux)).append("</td>");
                myEvaluableItemqualificationAux = mStudentqualificationReport.getMyEvaluableItemQualification();
                auxEvaluableItemsStudentSize = myEvaluableItemqualificationAux.size();
                firstqualification = 0;
                for (final EvaluableItem evaluableItem : mEvaluableItems) {
                    findEvaluableItem = false;
                    counter = 0;
                    qualificationAux = 0;
                    while (!findEvaluableItem && counter < auxEvaluableItemsStudentSize) {
                        evaluableItemStudentAux = myEvaluableItemqualificationAux.get(counter);
                        if (evaluableItemStudentAux != null && evaluableItemStudentAux.getName().compareTo(evaluableItem.getName()) == 0) {
                            findEvaluableItem = true;
                            qualificationAux = evaluableItemStudentAux.getScore();
                        }
                        counter++;
                    }
                    htmlTableData.append("<td>").append(df.format(qualificationAux)).append("</td>");
                    firstqualification += qualificationAux * evaluableItem.getAssociatedWeight() * 0.01;
                }
                firstqualification = firstqualification > MAX_GRADE ? MAX_GRADE : firstqualification < 0 ? 0 : firstqualification;
                htmlTableData.append("<td>").append(df.format(firstqualification)).append("</td>");
                auxqualification = mStudentqualificationReport.getQualification();
                bonusPenalization = auxqualification.getBonusPenalization();
                auxText = auxqualification.getReasonBonusPenalization();
                htmlTableData.append("<td>").append(df.format(bonusPenalization)).append("</td><td>").append(auxText == null ? "" : auxText).append("</td>");
                lastqualification = firstqualification + bonusPenalization;
                lastqualification = lastqualification > MAX_GRADE ? MAX_GRADE : lastqualification < 0 ? 0 : lastqualification;
                visibilityParent = QualificationUtil.getVisibility(auxqualification.isVisibleParent(), request).toUpperCase();
                visibilityStudent = QualificationUtil.getVisibility(auxqualification.isVisibleStudent(), request).toUpperCase();
                auxText = auxqualification.getOptionalComment();
                htmlTableData.append("<td><b>").append(df.format(lastqualification)).
                        append("</b></td>");
                htmlTableData.append("<td>").append(auxText == null ? ""
                        : roleRequest == Constants.SESSION_ID_ROLE_TEACHER
                        || (roleRequest == Constants.SESSION_ID_ROLE_PARENT && visibilityParent.compareTo(VISIBILITY_YES) == 0)
                        || (roleRequest == Constants.SESSION_ID_ROLE_STUDENT && visibilityStudent.compareTo(VISIBILITY_YES) == 0)
                        ? auxText : "").append("</td>");
                if (notStudent) {
                    htmlTableData.append("<td>").append(visibilityParent).
                            append("</td><td>").append(visibilityStudent).append("</td>");
                }
                htmlTableData.append("</tr>");
            }
        }
        return htmlTableData.append("</tbody></table>");
    }

    /**
     * Returns a HTML table with an evaluation information report for a subject
     * competence. See parameters for more details.
     *
     * @param sc Subject competence's to get evaluation report data.
     * @param request Current session request.
     * @param scUtil Subject competence's util.
     * @param showID If table must contain a column with edmodo idetificator.
     * @param initialDate Restricts results from this date.
     * @param endDate Restricts results to this date.
     * @param studentId If it is provided (must be greater than
     * {@link ConstantsDB#TABLE_NULL_ID}, table returned will only contain data
     * for this student (if exists in table data).
     * @param subjectCompetenceMembers All subject competence's members. param
     * @param gradesGroupJSON String result of {@link EdmodoAPI#gradesSetByAppForGroup(java.lang.String, java.lang.String
     * }
     * @
     * param assignmentsUserJSON String result of {@link EdmodoAPI#assignmentsByAppForUser(java.lang.String, java.lang.String)   *
     * }
     * @
     * param htmlWorker Optioanl HTMLWorker that thit method use to parse Each
     * evaluable item and its weigth. return a HTML table with an attend
     * information report. See parameters for more details.
     * @throws ControllerException If some problem happened.
     */
    public static StringBuilder getEvaluationReport(final SubjectCompetence sc, final HttpServletRequest request, final SubjectCompetenceUtil scUtil, final boolean showID, final Date initialDate, final Date endDate, final int studentId, final List<Student> subjectCompetenceMembers, final String gradesGroupJSON, final String assignmentsUserJSON, final HTMLWorker htmlWorker) throws ControllerException {
        final StringBuilder htmlTableData = new StringBuilder("<table border=\"1\" id=\"").append(ConstantsForm.TABLE_NAME)
                .append("\" style=\"margin-bottom: 20px;\" class=\"display table-hover table-bordered table-condensed\" cellspacing=\"0\" width=\"100%\"><thead><tr>").append("<th>").append(showID ? ConstantsForm.TABLE_HIDDE_COLUMN + "</th><th>" : "")
                .append(CurrentLanguage.getString(Text.REPORTS_NAME, request)).append("</th>");
        final DecimalFormat df = ConstantsForm.appDecimalFormat();
        final SimpleDateFormat sdf = ConstantsForm.DATE_SIMPLE_DATE_FORMAT;
        final String periodText = CurrentLanguage.getString(Text.PERIOD, request);
        // List students-assignment's data.
        final String scTitle = sc.getTitle();
        final int teacherId = sc.getTeacherId();
        final StudentEvaluationPeriod mData = scUtil.evaluationReport(sc.getEdmodoGroup(), teacherId, scTitle, subjectCompetenceMembers, gradesGroupJSON, assignmentsUserJSON);
        final List<EvaluationPeriodAssignment> evaluationPeriodAssignment = mData.getEvaluationPeriodAssignments();
        final List<EvaluationPeriodqualification> evaluationperiodsList = new ArrayList<EvaluationPeriodqualification>();
        List<Assignment> scAssignmentsAux;
        final List<AssignmentEvaluationPeriod> scAssignments = new ArrayList<AssignmentEvaluationPeriod>();
        EvaluationPeriod evaluationPeriodAux;
        final String toText = CurrentLanguage.getString(Text.TO, request);
        int counter = 1;
        try {
            final boolean htmlWorkerNotNull = htmlWorker != null;
            for (final EvaluationPeriodAssignment current : evaluationPeriodAssignment) {
                evaluationPeriodAux = current.getMyEvaluationPeriod();
                if (htmlWorkerNotNull) {
                    htmlWorker.parse(new StringReader("<br/><b>" + periodText + ' ' + counter + " (" + sdf.format(evaluationPeriodAux.getInitialDate()) + ' ' + toText + ' ' + sdf.format(evaluationPeriodAux.getFinalDate()) + ") " + evaluationPeriodAux.getPercentage() + "%: </b>"));
                }
                evaluationperiodsList.add(new EvaluationPeriodqualification(evaluationPeriodAux, 0));
                scAssignmentsAux = current.getMyAssignmentsList();
                for (final Assignment assCurrent : scAssignmentsAux) {
                    scAssignments.add(new AssignmentEvaluationPeriod(assCurrent, evaluationPeriodAux.getEvaluationPeriodId()));//
                    if (htmlWorkerNotNull) {
                        htmlWorker.parse(new StringReader("- " + assCurrent.getTitle() + ": " + assCurrent.getAssociatedWeight() + "% ("+sdf.format(assCurrent.getDate())+")."));
                    }
                }
                counter++;
            }
        } catch (final Exception ex) {
        }
        final List<Integer> evaluationPeriodRemoveIndex = new ArrayList<Integer>();
        final boolean possibleRemove = initialDate != null && endDate != null;
        //final List<Integer> evaluationPeriodOldIndex = new ArrayList<Integer>();
        if (possibleRemove) {
            int count = 0;
            for (final EvaluationPeriodqualification evaluationPeriod : evaluationperiodsList) {
                evaluationPeriodAux = evaluationPeriod.mEvaluationPeriod;
                if (evaluationPeriodAux.getInitialDate().before(initialDate) || evaluationPeriodAux.getFinalDate().after(endDate)) {
                    evaluationPeriodRemoveIndex.add(0, count);
                }
                count++;
            }
        }
        for (final Integer indexToRemove : evaluationPeriodRemoveIndex) {
            evaluationperiodsList.remove((int) indexToRemove);
        }

        final int SIZE_ASSIGNMENTS = scAssignments.size();
        counter = 1;
        for (final EvaluationPeriodqualification current : evaluationperiodsList) {
            evaluationPeriodAux = current.mEvaluationPeriod;
            htmlTableData.append("<th title=\"").append(periodText).append(" ").append(counter).append("\" data-content=\"").append(sdf.format(evaluationPeriodAux.getInitialDate()))
                    .append(' ').append(toText).append(' ').append(sdf.format(evaluationPeriodAux.getFinalDate()))
                    .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                    .append(evaluationPeriodAux.getPercentage()).append(" %</th>");
            counter++;
        }
        final int MAX_POSITIVE = sc.getMaxPositiveWeigth();
        final int MAX_NEGATIVE = sc.getMaxNegativeWeigth();
        final int EACH_POSITIVE = sc.getEachPositiveWeigth();
        final int EACH_NEGATIVE = sc.getEachNegativeWeigth();
        final String EACH_TEXT = CurrentLanguage.getString(Text.EVALUATION_PERCENTAGES_EACH, request);
        htmlTableData.append("<th data-content=\"")
                .append(EACH_TEXT).append(": +").append(EACH_POSITIVE).append(" %")
                .append("\" title=\"").append(CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_POSITIVE, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(MAX_POSITIVE)
                .append(" % (+)</th><th data-content=\"")
                .append(EACH_TEXT).append(": -").append(sc.getEachNegativeWeigth()).append(" %")
                .append("\" title=\"").append(CurrentLanguage.getString(Text.S_C_B_A_NEW_ASPECT_NEGATIVE, request)).append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">").append(MAX_NEGATIVE).append(" % (-)</th><th>")
                .append(CurrentLanguage.getString(Text.EVALUATION_INFORM_AVERAGE, request))
                .append("</th><th data-content=\"").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_BONUS_PENALIZATION_TH, request))
                .append("\" rel=\"popover\" data-placement=\"top\" data-trigger=\"hover\">")
                .append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_EXTRA_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_REASON_TH, request))
                .append("</th><th>").append(CurrentLanguage.getString(Text.QUALIFICATION_QUALIFICATION_FINAL_TH, request))
                .append("</th></tr></thead><tbody>");
        BonusPenalization mBonusPenalizationAux;
        List<StudentQualificationReport> mStudentqualificationReport;
        Qualification qualification;
        List<EvaluableItemStudent> myEvaluableItemqualifications;
        Student auxStudent;
        double currentqualificationAux, finalqualificationAux,
                bonusPenalizationAux,
                averageEvaluableItems, maxGrade, evaluationPeriodWeight, positiveAspectsAux, negativeAspectsAux;
        AssignmentEvaluationPeriod auxAssignment;
        int idStudentAux, idAux, counterAssignment, evaluationPeriodIdAux;
        boolean find, findAssignment;
        Assignment mAssignment;
        // Max qualification to show in the view.
        final int NORMALIZE = ConstantsForm.NORMALIZE;
        final byte POSITIVE_ASPECT = ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_TYPE_TYPES[ConstantsDB.TABLE_BEHAVIOUR_ATTITUDE_ASPECT_ATT_POSITIVE_INDEX];
        // 3. Pase all data
        BehaviourAttitudeAspect aux;
        String currentName;
        final SubjectCompetenceEvaluation mDataSC = new Persistence().getEvaluationData(teacherId, scTitle);
        final List<EvaluableItem> mEvaluableItemsSC = mDataSC.getmEvaluableItemsSC();
        EvaluableItem mEvaluableItemAux;
        final List<StudentAspect> aspectsApplied = mDataSC.getAspectsApplied();
        final List<BehaviourAttitudeAspect> mySubjectCompetenceAspects = mDataSC.getMySubjectCompetenceAspects();
        final int SIZE_EVALUABLE_ITEMS = mEvaluableItemsSC.size();
        final int SIZE_B_A_ASPECTS = mySubjectCompetenceAspects.size();
        EvaluationPeriodqualification mEPqualificationAux;
        final List<StudentEvaluation> mStudentEvaluation = mData.getStudentEvaluationList();
        // 1. For each student
        final boolean notStudent = studentId == ConstantsDB.TABLE_NULL_ID;
        final int SIZE_EVALUATION_PERIODS = evaluationperiodsList.size();
        for (final StudentEvaluation mStudentEvaluationCurrent : mStudentEvaluation) {
            auxStudent = mStudentEvaluationCurrent.getStudent();
            idStudentAux = auxStudent.getIdStudent();
            if (notStudent || idStudentAux == studentId) {
                htmlTableData.append("<tr class=\"info\"><td>").append(showID ? "" + auxStudent.getIdEdmodo() + "</td><td>" : "")
                        .append(auxStudent.getFullName()).append("</td>");
                mStudentqualificationReport = mStudentEvaluationCurrent.getStudentQualificationReport();
                // Clear possible evaluation period data:
                for (final EvaluationPeriodqualification current : evaluationperiodsList) {
                    current.qualification = 0;
                }
                // 2. Each student's assignment
                for (final StudentQualificationReport mCurrent : mStudentqualificationReport) {
                    // 2.1. Average evaluable items + bonus penalization
                    qualification = mCurrent.getQualification();
                    // Find assignment
                    findAssignment = false;
                    counterAssignment = 0;
                    while (!findAssignment && counterAssignment < SIZE_ASSIGNMENTS) {
                        auxAssignment = scAssignments.get(counterAssignment);
                        mAssignment = auxAssignment.assignment;
                        idAux = mAssignment.getIdAssignment();
                        if (idAux == qualification.getIdAssignment()) {
                            maxGrade = mAssignment.getMaxGrade();
                            evaluationPeriodIdAux = auxAssignment.evaluationPeriodId;
                            findAssignment = true;
                            // List of all evaluable item's calfication of this assignment.
                            averageEvaluableItems = 0;
                            if (findAssignment) {
                                // Student's evaluable item qualifications
                                myEvaluableItemqualifications = mCurrent.getMyEvaluableItemQualification();
                                for (final EvaluableItemStudent mEvaluableItemStudent : myEvaluableItemqualifications) {
                                    find = false;
                                    counter = 0;
                                    // 1. Find EvaluableItems assignment's weight
                                    while (!find && counter < SIZE_EVALUABLE_ITEMS) {
                                        mEvaluableItemAux = mEvaluableItemsSC.get(counter);
                                        if (mEvaluableItemStudent.getName().compareTo(mEvaluableItemAux.getName())
                                                == 0 && mEvaluableItemAux.getIdAssignment() == idAux) {
                                            averageEvaluableItems += mEvaluableItemAux.getAssociatedWeight() * 0.01 * mEvaluableItemStudent.getScore();
                                            find = true;
                                        }
                                        counter++;
                                    }
                                }
                            }
                            averageEvaluableItems += qualification.getBonusPenalization();
                            // Final assignment's qualification
                            averageEvaluableItems = averageEvaluableItems > maxGrade ? maxGrade : averageEvaluableItems;
                            // Normalize
                            averageEvaluableItems *= (NORMALIZE / maxGrade);
                            averageEvaluableItems = Double.isNaN(averageEvaluableItems) ? 0 : averageEvaluableItems;
                            // 2.2. Evaluation period qualification's average, add the average qualification to evaluation period
                            // Find evaluation period
                            find = false;
                            counter = 0;
                            while (!find && counter < SIZE_EVALUATION_PERIODS) {
                                mEPqualificationAux = evaluationperiodsList.get(counter);
                                evaluationPeriodAux = mEPqualificationAux.mEvaluationPeriod;
                                if (evaluationPeriodAux.getEvaluationPeriodId() == evaluationPeriodIdAux) {
                                    // Normalized
                                    mEPqualificationAux.qualification += mAssignment.getAssociatedWeight() * 0.01 * averageEvaluableItems; //*0.01 == /100
                                    find = true;
                                }
                                counter++;
                            }
                        }
                        counterAssignment++;
                    }
                }
                // Show Evaluation Period's qualification
                // Average:
                evaluationPeriodWeight = 0;
                for (final EvaluationPeriodqualification current : evaluationperiodsList) {
                    // It is already normalized.
                    htmlTableData.append("<td>").append(df.format(current.qualification)).append("</td>");
                    evaluationPeriodWeight += current.mEvaluationPeriod.getPercentage() * 0.01 * current.qualification;
                }
                positiveAspectsAux = 0;
                negativeAspectsAux = 0;

                for (final StudentAspect mAspect : aspectsApplied) {
                    if (mAspect.getIdStudent() == idStudentAux) {
                        counter = 0;
                        find = false;
                        while (!find && counter < SIZE_B_A_ASPECTS) {
                            aux = mySubjectCompetenceAspects.get(counter);
                            currentName = aux.getName();
                            if (currentName.compareTo(mAspect.getName()) == 0) {
                                find = true;
                                if (aux.getType() == POSITIVE_ASPECT) {
                                    positiveAspectsAux++;
                                } else {
                                    negativeAspectsAux++;
                                }
                            }
                            counter++;
                        }
                    }
                }
                positiveAspectsAux *= EACH_POSITIVE;
                positiveAspectsAux = positiveAspectsAux > MAX_POSITIVE ? MAX_POSITIVE : positiveAspectsAux;
                // Normalize
                positiveAspectsAux = (positiveAspectsAux * NORMALIZE) / MAX_POSITIVE;
                positiveAspectsAux = Double.isNaN(positiveAspectsAux) ? 0 : positiveAspectsAux;
                htmlTableData.append("<td>").
                        append(df.format(positiveAspectsAux)).
                        append("</td><td>");
                negativeAspectsAux *= EACH_NEGATIVE;
                negativeAspectsAux = negativeAspectsAux > MAX_NEGATIVE ? MAX_NEGATIVE : negativeAspectsAux;
                // Normalize
                negativeAspectsAux = (negativeAspectsAux * NORMALIZE) / MAX_NEGATIVE;
                negativeAspectsAux = Double.isNaN(negativeAspectsAux) ? 0 : negativeAspectsAux;
                mBonusPenalizationAux = mStudentEvaluationCurrent.getBonusPenalization();
                bonusPenalizationAux = mBonusPenalizationAux.getScore();
                currentqualificationAux = evaluationPeriodWeight + (positiveAspectsAux * MAX_POSITIVE * 0.01) - (negativeAspectsAux * MAX_NEGATIVE * 0.01);
                finalqualificationAux = currentqualificationAux + bonusPenalizationAux;
                // Normalize
                finalqualificationAux = finalqualificationAux > NORMALIZE ? NORMALIZE : finalqualificationAux < 0 ? 0 : finalqualificationAux;
                htmlTableData.append(df.format(negativeAspectsAux))
                        .append("</td><td>")
                        .append(df.format(currentqualificationAux))// * 0.01 == /100 In JAVA /100 has problems
                        .append("</td><td>").append(df.format(bonusPenalizationAux)).append("</td><td>")
                        .append(mBonusPenalizationAux.getReason()).append("</td><td><b>")
                        .append(df.format(finalqualificationAux))
                        .append("</b></td></tr>");
            }
        }
        request.setAttribute(Constants.ATT_N_EVALUATION_PERIODS, evaluationperiodsList.size());
        return htmlTableData.append("</tbody></table>");
    }

    /**
     * Models a Evaluation Period - qualification pair.
     */
    private static final class EvaluationPeriodqualification {

        private EvaluationPeriod mEvaluationPeriod;
        private double qualification;

        public EvaluationPeriodqualification(final EvaluationPeriod mEvaluationPeriod, final double qualification) {
            this.mEvaluationPeriod = mEvaluationPeriod;
            this.qualification = qualification;
        }
    }

    /**
     * Models an Assignment - Evaluation Period pair.
     */
    private static class AssignmentEvaluationPeriod {

        private Assignment assignment;
        private int evaluationPeriodId;

        public AssignmentEvaluationPeriod(final Assignment assignment, final int evaluationPeriodId) {
            this.assignment = assignment;
            this.evaluationPeriodId = evaluationPeriodId;
        }
    }
}