package classcontrol.dao;

import classcontrol.entity.Assignment;
import classcontrol.utils.Constants;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * Handles all assignments' database connections.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
final class AssignmentDAO {

    /**
     * Returns an all sbuject competence's assignments list order by ascendent
     * dates.
     *
     * @param teacherId
     * @param title
     * @return
     * @throws IllegalArgumentException
     */
    static List<Assignment> getAssignments(final int teacherId, final String title) throws IllegalArgumentException {
        final List<Assignment> myAssignmentsList = new ArrayList<Assignment>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_ASSIGNMENT).append(" WHERE ").
                    //.append(ConstantsDB.TABLE_NAME_ASSIGNMENT).append(" WHERE ").
                    append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE).append("=? AND ").append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID)
                    .append("=? ORDER BY DATE(").
                    append(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE).append(") ASC").toString());
            ps.setString(1, title);
            ps.setInt(2, teacherId);
            final ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                myAssignmentsList.add(new Assignment(
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT),
                        null, null,
                        rs.getByte(ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT),
                        rs.getDouble(ConstantsDB.TABLE_ASSIGNMENT_ATT_MAX_GRADE),
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT),
                        rs.getDate(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE),
                        title, teacherId));
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAssignmentsList;
        }
    }

    static Assignment getAssignment(final int idAssignment) throws IllegalArgumentException {
        Assignment myAssignment = null;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.TABLE_NAME_ASSIGNMENT).append(" WHERE ").
                    append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT).append("=?")
                    .toString());
            ps.setInt(1, idAssignment);
            final ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                myAssignment = new Assignment(
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT),
                        null, null,
                        rs.getByte(ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT),
                        rs.getDouble(ConstantsDB.TABLE_ASSIGNMENT_ATT_MAX_GRADE),
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT),
                        rs.getDate(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE),
                        rs.getString(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE), rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID));
            }
        } catch (final Exception e) {
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAssignment;
        }
    }

    static Assignment getAssignment(final String idEdmodoAssignment) throws IllegalArgumentException {
        Assignment myAssignment = null;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.TABLE_NAME_ASSIGNMENT).append(" WHERE ").
                    append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT).append("=?")
                    .toString());
            ps.setString(1, idEdmodoAssignment);
            final ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                myAssignment = new Assignment(
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT),
                        null, null,
                        rs.getByte(ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE),
                        rs.getString(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT),
                        rs.getDouble(ConstantsDB.TABLE_ASSIGNMENT_ATT_MAX_GRADE),
                        rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT),
                        rs.getDate(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE),
                        rs.getString(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE), rs.getInt(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID));

            }
        } catch (final Exception e) {
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return myAssignment;
        }
    }

    /**
     * Delete a subject competence assignment.
     *
     * @param idAssignment
     * @return value higher than {@link Constants#NO_RESULT} if all ok, value
     * {@link Constants#NO_RESULT} otherwise.
     * @throws IllegalArgumentException If idAssignment is invalid.
     */
    static byte deleteAssignment(final int idAssignment) throws IllegalArgumentException {
        if (idAssignment <= ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid idAssignment");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("DELETE FROM ")
                    .append(ConstantsDB.TABLE_NAME_ASSIGNMENT).append(" WHERE ").
                    append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT).append("=?")
                    .toString());
            ps.setInt(1, idAssignment);
            ps.executeQuery();
        } catch (final Exception e) {
            result = Constants.NO_RESULT;
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }

    static byte insertAssignment(final Assignment myAssignment) {
        if (myAssignment == null) {
            throw new IllegalArgumentException("Invalid assignment");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                    .append(ConstantsDB.TABLE_NAME_ASSIGNMENT).
                    append('(')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_MAX_GRADE).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE).append(',')
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID).append(") VALUES (?,?,?,?,?,?,?);").toString());
            ps.setString(1, myAssignment.getEdmodoId());
            ps.setInt(2, myAssignment.getAssociatedWeight());
            ps.setByte(3, myAssignment.getType());
            ps.setDate(4, new java.sql.Date(myAssignment.getDate().getTime()));
            ps.setDouble(5, myAssignment.getMaxGrade());
            ps.setString(6, myAssignment.getAssociatedSCTitle());
            ps.setInt(7, myAssignment.getAssociatedSCTeacherId());
            ps.executeUpdate();
        } catch (final Exception e) {
            result = Constants.NO_RESULT;
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }

    static byte updateAssignment(final ArrayList<Assignment> myAssignmentList) {
        if (myAssignmentList == null) {
            throw new IllegalArgumentException("Invalid assignment");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            // Transaction
            con.setAutoCommit(false);
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("UPDATE ")
                    .append(ConstantsDB.TABLE_NAME_ASSIGNMENT)
                    .append(" SET ")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_EDMODO_ASSIGNMENT).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ASSOCIATED_WEIGHT).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_DATE).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_MAX_GRADE).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TEACHER_ID).append("=?,")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_S_C_TITLE).append("=? WHERE ")
                    .append(ConstantsDB.TABLE_ASSIGNMENT_ATT_ID_ASSIGNMENT).append("=?")
                    .toString());
            int currentAssignmentId;
            for (final Assignment current : myAssignmentList) {
                currentAssignmentId = current.getIdAssignment();
                ps.setInt(1, currentAssignmentId);
                ps.setString(2, current.getEdmodoId());
                ps.setInt(3, current.getAssociatedWeight());
                ps.setByte(4, current.getType());
                ps.setDate(5, new java.sql.Date(current.getDate().getTime()));
                ps.setDouble(6, current.getMaxGrade());
                ps.setInt(7, current.getAssociatedSCTeacherId());
                ps.setString(8, current.getAssociatedSCTitle());
                ps.setInt(9, currentAssignmentId);
                ps.executeUpdate();
            }
            con.commit();
        } catch (final Exception e) {
            result = Constants.NO_RESULT;
            con.rollback();
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }
}