package classcontrol.dao;

import classcontrol.entity.BonusPenalization;
import classcontrol.utils.Constants;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

/**
 * Handles all bonus penalizations' database connections.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class BonusPenalizationDAO {

    /**
     * Returns all subject competence's bonus penalizations.
     *
     * @param subjectCompetence Subject competence to get all its bonus
     * penalizations.
     * @return All subject competence's bonus penalizations.
     * @throws IllegalArgumentException If any argument is null.
     */
    static List<BonusPenalization> getBonusPenalizations(final int teacherId, final String subjectCompetenceTitle) throws IllegalArgumentException {
        if (teacherId < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid teacherId");
        }
        if (subjectCompetenceTitle == null) {
            throw new IllegalArgumentException("Invalid subjectCompetenceTitle");
        }
        final List<BonusPenalization> mBonusPenalizationList = new ArrayList<BonusPenalization>();
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("SELECT * FROM ")
                    .append(ConstantsDB.VIEW_BONUS_PENALIZATION)
                    //.append(ConstantsDB.TABLE_NAME_BONUS_PENALIZATION)
                    .append(" WHERE ").append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE).
                    append("=? AND ").append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TEACHER_ID).
                    append("=?").toString());
            ps.setString(1, subjectCompetenceTitle);
            ps.setInt(2, teacherId);
            final ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                mBonusPenalizationList.add(new BonusPenalization(
                        rs.getDouble(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_SCORE),
                        rs.getString(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_REASON),
                        rs.getInt(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_STUDENT_ID),
                        rs.getString(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE),
                        rs.getInt(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TEACHER_ID)));
            }
        } catch (final Exception e) {
            // e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return mBonusPenalizationList;
        }
    }

    /**
     * Inserts a new Bonus Penalization or updates and existent one.
     *
     * @param mBonusPenalization
     * @return
     * @throws IllegalArgumentException
     */
    static byte insertBonusPenalization(final List<BonusPenalization> mBonusPenalizationList) throws IllegalArgumentException {
        if (mBonusPenalizationList == null) {
            throw new IllegalArgumentException("Invalid bonus penalization");
        }
        byte result = Constants.NO_RESULT + 1;
        final ConnectionPool pool = ConnectionPool.getInstance();
        final Connection con = pool.getConnection();
        try {
            final PreparedStatement ps = con.prepareStatement(new StringBuilder("INSERT INTO ")
                    .append(ConstantsDB.TABLE_NAME_BONUS_PENALIZATION).
                    append('(')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TEACHER_ID).append(',')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE).append(',')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_STUDENT_ID).append(',')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_SCORE).append(',')
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_REASON)
                    .append(") VALUES (?,?,?,?,?) ON DUPLICATE KEY UPDATE ")
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_SCORE).append("=?,")
                    .append(ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_REASON).append("=?")
                    .toString());
            for (final BonusPenalization mBonusPenalization : mBonusPenalizationList) {
                final double SCORE = mBonusPenalization.getScore();
                final String REASON = mBonusPenalization.getReason();
                int count = 1;
                ps.setInt(count, mBonusPenalization.getIdTeacherSC());
                count++;
                ps.setString(count, mBonusPenalization.getTitleSC());
                count++;
                ps.setInt(count, mBonusPenalization.getIdStudent());
                count++;
                ps.setDouble(count, SCORE);
                count++;
                ps.setString(count, REASON);
                count++;
                ps.setDouble(count, SCORE);
                count++;
                ps.setString(count, REASON);
                ps.executeUpdate();
            }
        } catch (final Exception e) {
            result = Constants.NO_RESULT;
            //e.printStackTrace();
        } finally {
            if (con != null) {
                pool.freeConnection(con);
            }
            return result;
        }
    }
}