package classcontrol.edmodo;

import classcontrol.dao.ConstantsDB;
import classcontrol.dao.ConstantsForm;
import classcontrol.utils.Constants;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import org.codehaus.jettison.json.JSONArray;

/**
 *
 * Edmodo's API caller-client with String-JSON responses. All POST connections
 * have their parameters encoded in URL.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class EdmodoAPI {

    /**
     * Class Control Edmodo's API key.
     */
    private final static String API_KEY = "aecbe062fb1d7d9eca76b68d0d11706c65b70c08";
    /**
     * First part of Edmodo URL to make calls.
     */
    private final static String URL_API = "https://appsapi.edmodobox.com/v1.1/";
    /**
     * Default parameter's encoding.
     */
    private final static String API_UTF_8_KEY = "UTF-8";
    /**
     * Whenever Class Control is launched in Edmodo, a launch_key will be
     * included with App URL. Note: only in first app launch, each launch
     * provides a new launch_key.
     */
    public final static String API_LAUNCH_KEY_KEY = "launch_key";
    /**
     * Edmodo's API succes key.
     */
    public final static String API_SUCCESS_KEY = "success";
    /**
     * Edmodo's API status key.
     */
    public final static String API_STATUS_KEY = "status";
    /**
     * Edmodo's API api key key.
     */
    public final static String API_KEY_KEY = "api_key";
    /**
     * Edmodo's API user type key.
     */
    public final static String API_USER_TYPE_KEY = "user_type";
    /**
     * Edmodo's API first name key.
     */
    public final static String API_FIRST_NAME_KEY = "first_name";
    /**
     * Edmodo's API avatar url key.
     */
    public final static String API_AVATAR_URL_KEY = "avatar_url";
    /**
     * Edmodo's API last name key.
     */
    public final static String API_LAST_NAME_KEY = "last_name";
    /**
     * Edmodo's API ln key.
     */
    public final static String API_LANGUAGE_KEY = "ln";
    /**
     * Edmodo's API badge id key.
     */
    public final static String API_BADGE_ID_KEY = "badge_id";
    /**
     * Edmodo's API badge title key.
     */
    public final static String API_BADGE_TITLE_KEY = "badge_title";
    /**
     * Edmodo's API title key.
     */
    public final static String API_TITLE_KEY = "title";
    /**
     * Edmodo's API times awarded key.
     */
    public final static String API_BADGE_TIMES_AWARDED_KEY = "times_awarded";
    /**
     * Edmodo's API description key.
     */
    public final static String API_BADGE_DESCRIPTION_KEY = "description";
    /**
     * Edmodo's API image url key.
     */
    public final static String API_BADGE_IMAGE_URL_KEY = "image_url";
    /**
     * Edmodo's API times awarded key.
     */
    public final static String API_TIMES_AWARED_KEY = "times_awarded";
    /**
     * Edmodo's API description key.
     */
    public final static String API_DESCRIPTION_KEY = "description";
    /**
     * Edmodo's API due date key.
     */
    public final static String API_ASSIGNMENT_DUE_DATE_KEY = "due_date";
    /**
     * Edmodo's API grade total key.
     */
    public final static String API_ASSIGNMENT_GRADE_TOTAL_KEY = "grade_total";
    /**
     * Edmodo's API total key.
     */
    public final static String API_GRADE_TOTAL_KEY = "total";
    /**
     * Edmodo's API grade id key.
     */
    public final static String API_GRADE_ID_KEY = "grade_id";
    /**
     * Edmodo's API recipients key.
     */
    public final static String API_ASSIGNMENT_RECIPIENTS_KEY = "recipients";
    /**
     * Edmodo's API user token key.
     */
    public final static String API_USER_TOKEN_KEY = "user_token";
    /**
     * Edmodo's API content key.
     */
    public final static String API_CONTENT_KEY = "content";
    /**
     * Edmodo's API access token key.
     */
    public final static String API_ACCESS_TOKEN_KEY = "access_token";
    /**
     * Edmodo's API user tokens key.
     */
    public final static String API_USERS_TOKEN_KEY = "user_tokens";
    /**
     * Edmodo's API update data key.
     */
    public final static String API_UPDATE_DATA_KEY = "update_data";
    /**
     * Edmodo's API title key.
     */
    public final static String API_GROUP_TITLE_KEY = "title";
    /**
     * Edmodo's API group id key.
     */
    public final static String API_GROUP_ID_KEY = "group_id";
    /**
     * Edmodo's API update type key.
     */
    public final static String API_UPDATE_TYPE_KEY = "update_type";
    /**
     * Edmodo's API group member created key.
     */
    public final static String API_UPDATE_TYPE_NEW_GROUP_MEMBER_KEY = "group_member_created";
    /**
     * Edmodo's API is owner key.
     */
    public final static String API_IS_OWNER_GRUOP_KEY = "is_owner";
    /**
     * Edmodo's API owners key.
     */
    public final static String API_OWNERS_GROUP_KEY = "owners";
    /**
     * Edmodo's API new group members key.
     */
    public final static String API_UPDATE_NEW_GROUP_MEMBER_ARRAY_KEY = "new_group_members";
    /**
     * Edmodo's API members key.
     */
    public final static String API_UPDATE_NEW_GROUP_MEMBER_GROUP_ARRAY_KEY = "members";
    /**
     * Edmodo's API assignment id key.
     */
    public final static String API_ASSIGNMENT_ID_KEY = "assignment_id";
    /**
     * Edmodo's API assignment title key.
     */
    public final static String API_ASSIGNMENT_TITLE_KEY = "assignment_title";
    /**
     * Edmodo's API score key.
     */
    public final static String API_SCORE_KEY = "score";
    /**
     * Edmodo's API parent role.
     */
    public final static String API_USER_TYPE_PARENT_VALUE = "PARENT";
    /**
     * Edmodo's API student role.
     */
    public final static String API_USER_TYPE_STUDENT_VALUE = "STUDENT";
    /**
     * Edmodo's API teacher role.
     */
    public final static String API_USER_TYPE_TEACHER_VALUE = "TEACHER";

    /**
     * Makes an http connection to get a String response. If any error ocurrs it
     * is not throwed.
     *
     * @param url URL to make the http connection.
     * @param method Standard connection:GET, POST.
     * @return String returned after making the http call.
     */
    private static StringBuilder edmodoCall(final String url, final String method) {
        if (method.compareTo("GET") != 0 && method.compareTo("POST") != 0) {
            throw new IllegalArgumentException("GET or POST method are only valid.");
        }
        final StringBuilder sb = new StringBuilder();
        try {
            final HttpURLConnection c = (HttpURLConnection) new URL(url).openConnection();
            c.setRequestMethod(method);
            c.connect();
            final BufferedReader br = new BufferedReader(new InputStreamReader(
                    c.getInputStream()));
            String line;
            while ((line = br.readLine()) != null) {
                sb.append(line);
            }
            br.close();
        } catch (final MalformedURLException ex) {
            //ex.printStackTrace();
        } catch (final IOException e) {
            //e.printStackTrace();
        }
        return sb;
    }

    /**
     * Returns user data for the user that requested the application launch.
     * JSON format.
     *
     * @param launchKey Obtained from first application's launch.
     * @return User data for the user that requested the application launch.
     */
    public static String launchRequests(final String launchKey) {
        return edmodoCall(URL_API + "launchRequests?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_LAUNCH_KEY_KEY + '=' + launchKey, "GET").toString();
    }

    /**
     * Returns the data for groups a user belongs to given a user token.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param idUser User token.
     * @return the data for groups a user belongs to given a user token.
     */
    public static String groupsForUser(final String accessToken, final String idUser) {
        return edmodoCall(URL_API + "groupsForUser?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + idUser, "GET").toString();
    }

    /**
     * Returns an array of user data for members of a group, specified by group
     * id.
     *
     * @param idGroups Integer Array Group ID.
     * @return An array of user data for members of a group, specified by group
     * id.
     */
    public static String members(final String accessToken, final String[] idGroups) {
        if (idGroups == null || idGroups.length == 0) {
            return "";
        }
        final StringBuilder sb = new StringBuilder(URL_API).append("members?").append(API_KEY_KEY).append('=')
                .append(API_KEY).append('&').append(API_ACCESS_TOKEN_KEY).append('=').append(accessToken).append('&').append(API_GROUP_ID_KEY).append('=');
        for (final String current : idGroups) {
            sb.append(current).append(',');
        }
        // -1 Because of last ',' char in previous for loop.
        return edmodoCall(sb.substring(0, sb.length() - 1), "GET").toString();
    }

    /**
     * Returns an array of data for students, given a specified parent user
     * token.
     *
     * @param accessToken Obtained from /launchRequests endpoint.
     * @param edmodoParentId User token of the parent.
     * @return An array of data for students, given a specified parent user
     * token.
     */
    public static String children(final String accessToken, final String edmodoParentId) {
        return edmodoCall(URL_API + "children?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + edmodoParentId, "GET").toString();
    }

    /**
     * Registers a badge (a Class Control's behaviour attitude aspect) at
     * Edmodo, returning a badge id that can be used to award a badge that will
     * display on an Edmodo user's profile.
     *
     * @param title limit 50 characters
     * @param description limit 140 characters
     * @param imageUrl url to badge image, should be 114x114 pixels Accepted
     * image types: jpg, gif, png
     * @return badge id.
     * @throws IllegalArgumentException If any argument was bad indicated.
     */
    public static String registerBadge(final String title, final String description, final String imageUrl) throws IllegalArgumentException, UnsupportedEncodingException {
        if (title == null || (title.length() == 0 || title.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_NAME_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        if (description == null || (description.length() == 0 || description.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_DESCRIPTION_MAX)) {
            throw new IllegalArgumentException("Invalid description");
        }
        if (imageUrl == null || (imageUrl.length() == 0 || imageUrl.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_URL_MAX)) {
            throw new IllegalArgumentException("Invalid imgage url");
        }
        return edmodoCall(URL_API + "registerBadge?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_BADGE_TITLE_KEY + '=' + URLEncoder.encode(title, API_UTF_8_KEY) + '&'
                + API_BADGE_DESCRIPTION_KEY + '=' + URLEncoder.encode(description, API_UTF_8_KEY)
                + '&' + API_BADGE_IMAGE_URL_KEY + '=' + URLEncoder.encode(imageUrl, API_UTF_8_KEY), "POST").toString();
    }

    /**
     * Updates an existing registered badge.
     *
     * @param idEdmodoBadge The registered badge id.
     * @param title limit 50 characters.
     * @param description limit 140 characters.
     * @param imageUrl Optional: If you wish to replace the image of the badge,
     * specify the url of the new badge image. Otherwise, to keep the old badge
     * image, you do not need to specify this parameter. Badge images should be
     * 114x114 pixels. Accepted image types: jpg, gif, png
     * @return Status "success" or "failed"
     * @throws IllegalArgumentException
     * @throws UnsupportedEncodingException
     */
    public static String updateBadge(final String idEdmodoBadge, final String title, final String description, final String imageUrl) throws IllegalArgumentException, UnsupportedEncodingException {
        if (idEdmodoBadge == null || (idEdmodoBadge.length() == 0 || idEdmodoBadge.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_ID_EDMODO_MAX)) {
            throw new IllegalArgumentException("Invalid idEdmodoBadge");
        }
        if (title == null || (title.length() == 0 || title.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_NAME_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        if (description == null || (description.length() == 0 || description.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_DESCRIPTION_MAX)) {
            throw new IllegalArgumentException("Invalid description");
        }
        if (imageUrl != null && (imageUrl.length() == 0 || imageUrl.length() > ConstantsForm.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_URL_MAX)) {
            throw new IllegalArgumentException("Invalid imgage url");
        }
        return edmodoCall(URL_API + "updateBadge?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_BADGE_ID_KEY + '=' + idEdmodoBadge
                + '&' + API_BADGE_TITLE_KEY + '=' + URLEncoder.encode(title, API_UTF_8_KEY)
                + '&' + API_BADGE_DESCRIPTION_KEY + '=' + URLEncoder.encode(description, API_UTF_8_KEY)
                + (imageUrl != null ? '&' + API_BADGE_IMAGE_URL_KEY + '=' + URLEncoder.encode(imageUrl, API_UTF_8_KEY) : ""), "POST").toString();
    }

    /**
     * Returns an array of badges (behaviour attitude aspects) awarded by the
     * app to the given user token.
     *
     * @param edmodoId The user to get badges awarded for.
     * @return an array of badges awarded by the app to the given user token.
     */
    public static String badgesAwarded(final String accessToken, final String edmodoId) {
        return edmodoCall(URL_API + "badgesAwarded?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + edmodoId, "GET").toString();
    }

    /**
     * Awards a badge (behaviour attitude aspect) to a given user.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param idEdmodoBadge Badge ID of the badge to be awarded.
     * @param idEdmodoUser User token of the user receiving the badge.
     * @return a JSON with {@link EdmodoAPI#API_SUCCESS_KEY}=value 1 if all ok
     * and {@link EdmodoAPI#API_TIMES_AWARED_KEY}.
     */
    public static String awardBadge(final String accessToken, final String idEdmodoBadge, final String idEdmodoUser) {
        return edmodoCall(URL_API + "awardBadge?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + idEdmodoUser
                + '&' + API_BADGE_ID_KEY + '=' + idEdmodoBadge, "POST").toString();
    }

    /**
     * Revokes a badge that has been awarded to a given user.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param idEdmodoBadge Badge ID of the badge to be revoked.
     * @param idEdmodoUser User token of the user revoking the badge.
     * @return a JSON with {@link EdmodoAPI#API_SUCCESS_KEY}=value 1 if all ok
     * and {@link EdmodoAPI#API_TIMES_AWARED_KEY}.
     */
    public static String revokeBadge(final String accessToken, final String idEdmodoBadge, final String idEdmodoUser) {
        return edmodoCall(URL_API + "revokeBadge?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + idEdmodoUser
                + '&' + API_BADGE_ID_KEY + '=' + idEdmodoBadge, "POST").toString();
    }

    /**
     * Returns an array of assignments created by the app for the user specified
     * by the token. Includes assignments due at any time in the future, and
     * assignments the user has already turned in.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param idEdmodoUser User token of the user.
     * @return JSON array of assignment created by the app for the user
     * specified by the token.
     */
    public static String assignmentsByAppForUser(final String accesToken, final String idEdmodoUser) {
        return edmodoCall(URL_API + "assignmentsByAppForUser?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accesToken
                + '&' + API_USER_TOKEN_KEY + '=' + idEdmodoUser, "GET").toString();

    }

    /**
     * Returns an array of statuses for the user recipients of the given
     * assignment.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param userEdmodoId User's Edmodo Id.
     * @param assignmentId Assignment Id for the assignment to get statuses for.
     * @return Returns an array of statuses for the user recipients of the given
     * assignment.
     */
    public static String assignmentStatus(final String accesToken, final String assignmentId, final String userEdmodoId) {
        return edmodoCall(URL_API + "assignmentStatus?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accesToken
                + '&' + API_USER_TOKEN_KEY + '=' + userEdmodoId
                + '&' + API_ASSIGNMENT_ID_KEY + '=' + assignmentId, "GET").toString();
    }

    /**
     * Returns an array of grades set by the app for the given group.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param idEdmodoGroup The group to get grades for.
     * @return an array of grades set (with total score) by the app for the
     * given group.
     */
    public static String gradesSetByAppForGroup(final String accesToken, final String idEdmodoGroup) {
        return edmodoCall(URL_API + "gradesSetByAppForGroup?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accesToken
                + '&' + API_GROUP_ID_KEY + '=' + idEdmodoGroup, "GET").toString();
    }

    /**
     * Create an assignment for the given users and groups.<br/>
     *
     * This method only works for teacher users.
     *
     * @param accessToken Obtained from /launchRequests endpoint.
     * @param idEdmodoUser The user token for the user creating the assignment.
     * Must be a teacher.
     * @param title The title of the assignment.
     * @param description The description of the assignment.
     * @param dueDate The due date of the assignment (specified in the format
     * YYYY-MM-DD).
     * @param totalGrade Optional total default grade for this assignment.
     * @param edmodoGroup Edmodo group id to create assignment for.
     * @return New assignment's id.
     * @throws IllegalArgumentException If any parameter is null except
     * description.
     * @throws UnsupportedEncodingException If characters are not possible to
     * encode.
     */
    public static String createAssignment(final String accessToken, final String idEdmodoUser, final String title, String description, final Date dueDate,
            final int totalGrade, final String edmodoGroup) throws IllegalArgumentException, UnsupportedEncodingException {
        if (accessToken == null || idEdmodoUser == null || edmodoGroup == null) {
            throw new IllegalArgumentException();
        }
        if (title != null && (title.length() == 0 || title.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_NAME_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        if (dueDate == null) {
            throw new IllegalArgumentException("Invalid due date");
        }
        return edmodoCall(URL_API + "createAssignment?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_USER_TOKEN_KEY + '=' + idEdmodoUser
                + '&' + API_TITLE_KEY + '=' + URLEncoder.encode(title, API_UTF_8_KEY)
                + '&' + API_DESCRIPTION_KEY + '=' + URLEncoder.encode(description == null ? " " : description, API_UTF_8_KEY)
                + '&' + API_ASSIGNMENT_DUE_DATE_KEY + '=' + new SimpleDateFormat("yyyy-MM-dd").format(dueDate)
                + '&' + API_ASSIGNMENT_GRADE_TOTAL_KEY + '=' + totalGrade
                + '&' + API_ASSIGNMENT_RECIPIENTS_KEY + "=[{\"" + API_GROUP_ID_KEY + "\":" + edmodoGroup + "}]", "POST").toString();
    }

    /**
     * Add a new grade to the gradebook for a given group.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param title The title for this grade
     * @param totalGrade The total grade possible for this grade
     * @param edmodoGroup The group this grade will be created in
     * @return New grade's id.
     * @throws IllegalArgumentException If any argument is null or totalGrade is
     * lower than 0.
     * @throws UnsupportedEncodingException
     */
    public static String newGrade(final String accessToken, final String title, final int totalGrade, final String edmodoGroup) throws IllegalArgumentException, UnsupportedEncodingException {
        if (accessToken == null || edmodoGroup == null) {
            throw new IllegalArgumentException("Invalid title");
        }
        if (totalGrade < 0) {
            throw new IllegalArgumentException("Total Grade must be greater than 0.");
        }
        if (title != null && (title.length() == 0 || title.length() > ConstantsDB.CREATE_BEHAVIOUR_ATTITUDE_ASPECT_NAME_MAX)) {
            throw new IllegalArgumentException("Invalid title");
        }
        return edmodoCall(URL_API + "newGrade?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + API_TITLE_KEY + '=' + URLEncoder.encode(title, API_UTF_8_KEY)
                + '&' + API_GROUP_ID_KEY + '=' + edmodoGroup
                + '&' + API_GRADE_TOTAL_KEY + '=' + totalGrade, "POST").toString();
    }

    /**
     * Submits a response to the specified assignment for the given user.
     *
     * @param accesToken Obtained from /launchRequests endpoint.
     * @param assignmentId Assignment Id for the assignment to turn in.
     * @param studentEdmodoId The user token for the user turning in the
     * assignment..
     * @param content Text of the submission.
     * @return Data submiited.
     * @throws UnsupportedEncodingException If
     */
    public static String turnInAssignment(final String accesToken, final String assignmentId, final String studentEdmodoId, final String content) throws UnsupportedEncodingException {
        return edmodoCall(URL_API + "turnInAssignment?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accesToken
                + '&' + API_ASSIGNMENT_ID_KEY + '=' + assignmentId
                + '&' + API_USER_TOKEN_KEY + '=' + studentEdmodoId
                + '&' + API_CONTENT_KEY + '=' + URLEncoder.encode(content, API_UTF_8_KEY), "POST").toString();
    }

    /**
     * Set a score for a grade or assignment given a specific user token.
     *
     * @param accessToken Obtained from /launchRequests endpoint.
     * @param studentEdmodoId Student token to set grade.
     * @param score The score to set for this grade or assignment. In String
     * format for performance.
     * @param total Optional total to set for this grade or assignment (if not
     * provided, the default total will be used).
     * @param gradeAssignmentEdmodoId Grade or assignment the score is being set
     * upon.
     * @param type See {@link ConstantsDB#TABLE_ASSIGNMENT_ATT_TYPE_TYPES} for
     * more details.
     * @return JSON with score, total and assignment/grade id.
     * @throws IllegalArgumentException If any argument is null.
     */
    public static String setGrade(final String accessToken,
            final String studentEdmodoId, final String score,
            final double total, final String gradeAssignmentEdmodoId,
            final byte type, final String content) throws IllegalArgumentException, UnsupportedEncodingException {
        if (accessToken == null || studentEdmodoId == null || gradeAssignmentEdmodoId == null) {
            throw new IllegalArgumentException("All argument must be != null.");
        }
        final boolean isGrade = type == ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_ONLINE_INDEX]
                || type == ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_TYPES[ConstantsDB.TABLE_ASSIGNMENT_ATT_TYPE_OFFLINE_INDEX];
        if (!isGrade) {
            turnInAssignment(accessToken, gradeAssignmentEdmodoId, studentEdmodoId, content);
        }
        return edmodoCall(URL_API + "setGrade?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken
                + '&' + (isGrade ? EdmodoAPI.API_GRADE_ID_KEY : EdmodoAPI.API_ASSIGNMENT_ID_KEY) + '=' + gradeAssignmentEdmodoId
                + '&' + API_USER_TOKEN_KEY + '=' + studentEdmodoId
                + '&' + API_SCORE_KEY + '=' + score
                + '&' + API_GRADE_TOTAL_KEY + '=' + total, "POST").toString();
    }

    /**
     * Returns user data for a given user token or array of user tokens.
     *
     * @param users Assignment user token or array of user tokens.
     * @return user data for a given user token or array of user tokens.
     */
    public static String users(final String accessToken, final String[] users) {
        return edmodoCall(URL_API + "users?" + API_KEY_KEY + '=' + API_KEY
                + '&' + API_ACCESS_TOKEN_KEY + '=' + accessToken + '&'
                + API_USERS_TOKEN_KEY + '=' + new JSONArray(Arrays.asList(users)), "GET").toString();
    }

    public static byte getClassControlUserRole(final String edmodoUserType) {
        return edmodoUserType.compareTo(API_USER_TYPE_TEACHER_VALUE) == 0
                ? Constants.SESSION_ID_ROLE_TEACHER : edmodoUserType.compareTo(API_USER_TYPE_PARENT_VALUE) == 0 ? Constants.SESSION_ID_ROLE_PARENT
                : edmodoUserType.compareTo(API_USER_TYPE_STUDENT_VALUE) == 0 ? Constants.SESSION_ID_ROLE_STUDENT : null;
    }
}