package classcontrol.entity;

import classcontrol.dao.ConstantsDB;

/**
 * Models a subject competence's evaluation bonus penalization.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 0.1-ALPHA
 */
public final class BonusPenalization {

    private double score;
    private String reason;
    private int idStudent;
    private String titleSC;
    private int idTeacherSC;

    /**
     *
     * @param score
     * @param reason
     * @param idStudent
     * @param titleSC
     * @param idTeacherSC
     * @throws IllegalArgumentException
     */
    public BonusPenalization(final double score, final String reason, final int idStudent, String titleSC, final int idTeacherSC) throws IllegalArgumentException {
        if (reason != null && reason.length() > ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_REASON_MAX) {
            throw new IllegalArgumentException("Invalid reason");
        }
        if (idStudent < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid student id");
        }
        if (titleSC == null || titleSC.length() > ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_S_C_TITLE_MAX) {
            throw new IllegalArgumentException("Invalid subject competence title");
        }
        if (idTeacherSC < ConstantsDB.TABLE_ID_MIN) {
            throw new IllegalArgumentException("Invalid teacher id");
        }
        this.score = score;
        this.reason = reason;
        this.idStudent = idStudent;
        this.titleSC = titleSC;
        this.idTeacherSC = idTeacherSC;
    }

    /**
     *
     * @return
     */
    public double getScore() {
        return score;
    }

    /**
     *
     * @return
     */
    public String getReason() {
        return reason;
    }

    /**
     *
     * @return
     */
    public int getIdStudent() {
        return idStudent;
    }

    /**
     *
     * @return
     */
    public String getTitleSC() {
        return titleSC;
    }

    /**
     *
     * @return
     */
    public int getIdTeacherSC() {
        return idTeacherSC;
    }

    /**
     *
     * @param score
     */
    public void setScore(final double score) {
        this.score = score;
    }

    /**
     *
     * @param reason
     */
    public void setReason(final String reason) {
        if (reason != null && reason.length() > ConstantsDB.TABLE_BONUS_PENALIZATION_ATT_REASON_MAX) {
            throw new IllegalArgumentException("Invalid reason");
        }
        this.reason = reason;
    }
}