package classcontrol.entity;

import classcontrol.dao.ConstantsDB;

/**
 * Models a student.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class Student implements Comparable {

    private int idStudent;
    private String idEdmodo;
    private String fullName;

    private Student() {
    }

    /**
     * Basic constructor.
     *
     * @param idStudent Class Control database student id.
     * @param idEdmodo Edmodo's student id.
     * @param fullName Edmodo's student full name.
     * @throws IllegalArgumentException If idEdmodo is null.
     */
    public Student(final int idStudent, final String idEdmodo, final String fullName) throws IllegalArgumentException {
        if (idEdmodo == null || idEdmodo.length() > ConstantsDB.TABLE_STUDENT_ATT_ID_EDMODO_MAX) {
            throw new IllegalArgumentException("Invalid edmodo id");
        }
        this.idStudent = idStudent;
        this.idEdmodo = idEdmodo;
        this.fullName = fullName;
    }

    /**
     * Returns Class Control database student id.
     * @return Class Control database student id.
     */
    public int getIdStudent() {
        return idStudent;
    }

    /**
     * Returns Edmodo's student id.
     * @return Edmodo's student id.
     */
    public String getIdEdmodo() {
        return idEdmodo;
    }

    /**
     * Returns Edmodo's student full name.
     * @return Edmodo's student full name.
     */
    public String getFullName() {
        return fullName;
    }

    /**
     * Compares two student's full name
     *
     * @param o Other student to compare.
     * @return 0 If they are equal, 1 if this student is alphabetically greater
     * thant the new one, or -1 otherwise.
     */
    @Override
    public int compareTo(final Object o) {
        final String otherFullName = ((Student) o).getFullName();
        final String otherFullNameFinal = otherFullName == null ? "" : otherFullName;
        final String thisFullName = this.fullName == null ? "" : this.fullName;
        return thisFullName.compareToIgnoreCase(otherFullNameFinal);
    }
}