package classcontrol.utils;

import classcontrol.edmodo.EdmodoAPI;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONObject;

/**
 * Handles all business logic to get current user's name and last name.
 *
 * @author Cristian TG
 * @since 0.1-ALPHA
 * @version 1.0-INITIAL
 */
public final class Login {

    /**
     * Returns current Edmodo user name and last name with pic for nav bar view.
     * Saves it in a session attribute to avoid Edmodo's call.
     *
     * @param request Current request session.
     * @return Current Edmodo user name and lastname.
     */
    public static String getNameLastPic(final HttpServletRequest request) {
        final StringBuilder firstNameRole = new StringBuilder("<img width=\"50px\" class=\"hidden-xs\"");
        final HttpSession session = request.getSession();
        try {
            final String previousName = (String) session.getAttribute(Constants.SESSION_NAME_USER);
            if (previousName != null) {
                return previousName;
            }
            // 1 Analyze data
            final JSONObject mJSONObject = new JSONArray(EdmodoAPI.users((String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), new String[]{(String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER)})).getJSONObject(0);
            firstNameRole.append("src=\"").append(mJSONObject.optString(EdmodoAPI.API_AVATAR_URL_KEY))
                    .append("\"><a class=\"navbar-brand\" style=\"margin-right: 5px; margin-left: 3px\" align=\"center\">");

            final String name = mJSONObject.optString(EdmodoAPI.API_FIRST_NAME_KEY) + ' ' + mJSONObject.optString(EdmodoAPI.API_LAST_NAME_KEY);
            // Since 1.0-INITIAL version, only name (with picture) is displayed.
            // 2. Role
            //final Byte roleUser = (Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE);
            // 3. Finish return String with role.
//            name.append(" - ").append(roleUser == Constants.SESSION_ID_ROLE_TEACHER
//                    ? CurrentLanguage.getString(Text.TEACHER, request)
//                    : roleUser == Constants.SESSION_ID_ROLE_STUDENT
//                    ? CurrentLanguage.getString(Text.STUDENT, request) : roleUser == Constants.SESSION_ID_ROLE_PARENT
//                    ? CurrentLanguage.getString(Text.PARENT, request) : "");
            // 3.1 Nav bar appearance: {@link Constants#MAX_NAME_NAV_BAR}
            firstNameRole.append(name.length() > Constants.MAX_NAME_NAV_BAR ? name.substring(0, Constants.MAX_NAME_NAV_BAR - 1).trim().concat(".") : name).append("</a>");
            session.setAttribute(Constants.SESSION_NAME_USER, firstNameRole.toString());
            return firstNameRole.toString();
        } catch (final Exception ex) {
            return "";
        }
    }

    /**
     * Returns full current Edmodo user name and last name with role name.
     *
     * @param request Current request session.
     * @return Current Edmodo user name and lastname.
     */
    public static String getNameLastFull(final HttpServletRequest request) {
        final StringBuilder firstNameRole = new StringBuilder();
        final HttpSession session = request.getSession();
        try {
            // 1 Analyze data
            final JSONObject mJSONObject = new JSONArray(EdmodoAPI.users((String) session.getAttribute(EdmodoAPI.API_ACCESS_TOKEN_KEY), new String[]{(String) session.getAttribute(Constants.SESSION_ID_EDMODO_USER)})).getJSONObject(0);
            final Byte roleUser = (Byte) session.getAttribute(Constants.SESSION_ID_WEB_ROLE);
            // 2. Finish return String with role.
            return firstNameRole.append(mJSONObject.optString(EdmodoAPI.API_FIRST_NAME_KEY)).append(' ').append(mJSONObject.optString(EdmodoAPI.API_LAST_NAME_KEY)).append(" - ").append(roleUser == Constants.SESSION_ID_ROLE_TEACHER
                    ? CurrentLanguage.getString(Text.TEACHER, request)
                    : roleUser == Constants.SESSION_ID_ROLE_STUDENT
                    ? CurrentLanguage.getString(Text.STUDENT, request) : roleUser == Constants.SESSION_ID_ROLE_PARENT
                    ? CurrentLanguage.getString(Text.PARENT, request) : "").toString();
        } catch (final Exception ex) {
            return "";
        }
    }
}